@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = ["Guilhem Marchand"]
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -74,7 +74,6 @@ from trackme_libs import (
     trackme_register_tenant_object_summary_gen_non_persistent,
     trackme_register_tenant_object_summary_gen_persistent,
     run_splunk_search,
-    is_reachable_with_retry,
 )
 
 # import trackme licensing libs
@@ -298,18 +297,13 @@ class SplunkRemoteSearch(GeneratingCommand):
         except Exception as e:
             return False, str(e)
 
-    def select_url(self, session, splunk_url, timeout=15, retry_config=None):
+    def select_url(self, session, splunk_url, timeout=15):
         splunk_urls = splunk_url.split(",")
         unreachable_errors = []
 
         reachable_urls = []
         for url in splunk_urls:
-            if retry_config:
-                # Use shared retry function, passing self.is_reachable as the function to use
-                reachable, error = is_reachable_with_retry(session, url, timeout, retry_config, self.is_reachable)
-            else:
-                reachable, error = self.is_reachable(session, url, timeout)
-            
+            reachable, error = self.is_reachable(session, url, timeout)
             if reachable:
                 reachable_urls.append(url)
             else:
@@ -394,7 +388,7 @@ class SplunkRemoteSearch(GeneratingCommand):
         start,
         earliest,
         latest,
-        timeout=600,
+        timeout=300,
     ):
         try:
             service = client.connect(
@@ -453,8 +447,8 @@ class SplunkRemoteSearch(GeneratingCommand):
                 kwargs_oneshot["sample_ratio"] = sample_ratio
 
             # If the search is a raw search but doesn't start with the search keyword, fix this automatically
-            if not re.search(r"^search\s", searchStr) and not re.search(
-                r"^\s{0,}\|", searchStr
+            if not re.search("^search\s", searchStr) and not re.search(
+                "^\s{0,}\|", searchStr
             ):
                 searchStr = f"search {searchStr}"
 
@@ -575,7 +569,6 @@ class SplunkRemoteSearch(GeneratingCommand):
 
         except Exception as e:
             license_is_valid = 0
-            license_subscription_class = "free"
             logging.error(f'function check_license exception="{str(e)}"')
 
         # try and return
@@ -618,15 +611,6 @@ class SplunkRemoteSearch(GeneratingCommand):
                 f"timeout_search_check is not an integer, received value: {timeout_search_check}, setting to 300"
             )
 
-        # retry configuration
-        retry_config = {
-            "retry_enabled": account_dict.get("retry_enabled", "1"),
-            "retry_max_total_time": account_dict.get("retry_max_total_time", "30"),
-            "retry_initial_delay": account_dict.get("retry_initial_delay", "2"),
-            "retry_backoff_multiplier": account_dict.get("retry_backoff_multiplier", "2.0"),
-            "retry_max_attempts": account_dict.get("retry_max_attempts", "10"),
-        }
-
         # Get user's direct roles
         user_roles = self.get_user_roles()
 
@@ -734,7 +718,7 @@ class SplunkRemoteSearch(GeneratingCommand):
         else:
             # original behavior: select one working URL
             selected_url, errors = self.select_url(
-                session, splunk_url, timeout_connect_check, retry_config
+                session, splunk_url, timeout_connect_check
             )
 
             if not selected_url:
