@@ -91,7 +91,7 @@ def process_event(helper, *args, **kwargs):
                     }
                 ),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             ack_response.raise_for_status()
             ack_response_json = ack_response.json()
@@ -130,7 +130,7 @@ def process_event(helper, *args, **kwargs):
         #
 
         # endpoint url
-        endpoint_url = "/services/trackme/v2/ack/write/ack_manage"
+        endpoint_url = "/services/trackme/v2/ack/ack_manage"
 
         # test
         anomaly_reason = event.get("anomaly_reason")
@@ -164,7 +164,7 @@ def process_event(helper, *args, **kwargs):
                 headers=header,
                 verify=False,
                 data=json.dumps(body),
-                timeout=600,
+                timeout=300,
             )
             if response.status_code == 200:
                 helper.log_info(
