@@ -9,7 +9,6 @@ from datetime import datetime
 import splunklib.client as client
 import urllib3
 from urllib.parse import urlparse, urlencode, urlunparse, parse_qs
-import requests
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
@@ -21,7 +20,11 @@ sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))
 
 from trackme_libs import trackme_reqinfo, trackme_idx_for_tenant, trackme_state_event
 
-from splunktaucclib.cim_actions import parse_mv
+# import cim_modactions
+modaction_path = os.path.join(
+    splunkhome, "etc", "apps", "Splunk_SA_CIM", "lib", "cim_actions.py"
+)
+import cim_actions
 
 
 def get_splunk_service(helper, session_key, server_uri):
@@ -31,7 +34,7 @@ def get_splunk_service(helper, session_key, server_uri):
         app="trackme",
         port=reqinfo["server_rest_port"],
         token=session_key,
-        timeout=600,
+        timeout=300,
     )
 
 
@@ -54,7 +57,7 @@ def process_event(helper, *args, **kwargs):
             # Check if there is a multi-value field and parse it if present
             mv_field = f"__mv_{field}"
             if mv_field in event:
-                parsed_value = parse_mv(event[mv_field])
+                parsed_value = cim_actions.parse_mv(event[mv_field])
                 # If the parsed multi-value field is empty, use the single-value field
                 if parsed_value:
                     value = parsed_value
@@ -66,45 +69,6 @@ def process_event(helper, *args, **kwargs):
             helper.log_warn(f'Failed to extract field "{field}" from record="{event}"')
             return default
 
-    def normalize_tenants_scope(tenants_scope):
-        try:
-            if isinstance(tenants_scope, list):
-                scope_list = tenants_scope
-            elif isinstance(tenants_scope, str):
-                ts = tenants_scope.strip()
-                if ts == "" or ts == "*":
-                    scope_list = ["*"]
-                else:
-                    scope_list = [s.strip() for s in ts.split(",") if s.strip()]
-            else:
-                scope_list = ["*"]
-        except Exception:
-            scope_list = ["*"]
-        return scope_list
-
-    def get_maintenance_status(helper, server_uri, session_key):
-        try:
-            header = {
-                "Authorization": f"Splunk {session_key}",
-                "Content-Type": "application/json",
-            }
-            endpoint = f"{server_uri}/services/trackme/v2/maintenance/check_global_maintenance_status"
-            response = requests.get(endpoint, headers=header, verify=False, timeout=60)
-            response.raise_for_status()
-            data = response.json()
-            data["tenants_scope"] = normalize_tenants_scope(data.get("tenants_scope", "*"))
-            helper.log_info(f"maintenance_check response={json.dumps(data)}")
-            return data
-        except Exception as e:
-            helper.log_error(f"maintenance_check failed exception=\"{str(e)}\"")
-            return None
-
-    def tenant_in_scope(tenant_id, tenants_scope):
-        scope_list = normalize_tenants_scope(tenants_scope)
-        if "*" in scope_list:
-            return True
-        return tenant_id in scope_list
-
     def create_notable_record(event, drilldown_link, helper):
 
         # get properties
@@ -140,27 +104,6 @@ def process_event(helper, *args, **kwargs):
             "properties": properties,
         }
 
-        # include score and score_definition in the record if available from event
-        # Score is always an integer
-        score_raw = event.get("score")
-        score_definition = event.get("score_definition")
-        
-        # Convert score to integer (score is always an integer)
-        score = None
-        if score_raw is not None:
-            try:
-                score = int(float(score_raw))  # Convert to float first to handle string "100.0", then to int
-            except (ValueError, TypeError):
-                helper.log_warning(
-                    f"Failed to convert score to integer: score_raw={score_raw}, tenant_id={event.get('tenant_id')}, object={event.get('object')}"
-                )
-                score = None
-        
-        if score is not None:
-            notable_record["score"] = score
-        if score_definition is not None:
-            notable_record["score_definition"] = score_definition
-
         # calculate the event_id as the sha-256 sum of the notable_record
         event_id = hashlib.sha256(json.dumps(notable_record).encode()).hexdigest()
 
@@ -198,25 +141,10 @@ def process_event(helper, *args, **kwargs):
     # drilldown_earliest
     drilldown_earliest = helper.get_param("drilldown_earliest") or "-24h"
 
-    # Maintenance status (queried once)
-    maintenance_info = get_maintenance_status(helper, server_uri, session_key)
-
     # Loop through the events
     for event in helper.get_events():
 
         tenant_id = event["tenant_id"]
-
-        # If maintenance is active and the tenant is in scope, skip this event
-        try:
-            if maintenance_info and maintenance_info.get("maintenance"):
-                if tenant_in_scope(tenant_id, maintenance_info.get("tenants_scope", ["*"])):
-                    helper.log_info(
-                        f"maintenance active for tenant_id={tenant_id}, skipping trackme_notable event"
-                    )
-                    continue
-        except Exception:
-            # Fail-open per event
-            pass
         tenant_idx = trackme_idx_for_tenant(session_key, server_uri, tenant_id)
         tenant_trackme_notable_idx = tenant_idx["trackme_notable_idx"]
 
@@ -231,7 +159,7 @@ def process_event(helper, *args, **kwargs):
             base_url += f":{server_port}"
 
         # Path and query parameters
-        path = "/app/trackme/TenantHome"
+        path = "/app/trackme/trackMe_home"
         query_params = {
             "tenant_id": tenant_id,
             "component": component_suffix,
