@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_configuration.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -38,10 +38,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.alerting_admin", "trackme_rest_api_alerting_admin.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -146,7 +143,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -419,7 +416,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
         )
         try:
             response = requests.post(
-                record_url, headers=header, data=kwargs, verify=False, timeout=600
+                record_url, headers=header, data=kwargs, verify=False, timeout=300
             )
             logger.info(
                 f'tenant_id="{tenant_id}", action="success", alert_name="{alert_name}"'
@@ -620,7 +617,7 @@ class TrackMeHandlerAlertingWriteOps_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
