@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_audit.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -32,10 +32,7 @@ import import_declare_test
 from trackme_libs_logging import setup_logger
 
 logger = setup_logger("trackme.rest.audit", "trackme_rest_api_audit.log")
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -428,7 +425,7 @@ class TrackMeHandlerAudit_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # Register the new audit event using libs
@@ -563,7 +560,7 @@ class TrackMeHandlerAudit_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # add event_id and convert
