@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_licensing.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -34,10 +34,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.licensing_admin", "trackme_rest_api_licensing_admin.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -61,9 +58,9 @@ from licensing.models import *
 from licensing.methods import Key, Helpers
 
 
-class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerLicensing_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerLicensingAdmin_v2, self).__init__(
+        super(TrackMeHandlerLicensing_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -121,7 +118,7 @@ class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -235,7 +232,7 @@ class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -340,7 +337,7 @@ class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -452,7 +449,7 @@ class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -572,7 +569,7 @@ class TrackMeHandlerLicensingAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
