@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_licensing.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,17 +33,14 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.licensing_user", "trackme_rest_api_licensing_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
 import trackme_rest_handler
 
 # import trackme libs
-from trackme_libs import trackme_getloglevel, trackme_get_version
+from trackme_libs import trackme_getloglevel
 
 # import trackme licensing libs
 from trackme_libs_licensing import (
@@ -62,9 +59,9 @@ from licensing.models import *
 from licensing.methods import Key, Helpers
 
 
-class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerLicensing_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerLicensingRead_v2, self).__init__(
+        super(TrackMeHandlerLicensing_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -115,7 +112,7 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -129,7 +126,14 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
         #
 
         # TrackMe version
-        trackme_version = trackme_get_version(service)
+        trackme_version = None
+        app_confs = service.confs["app"]
+
+        for stanza in app_confs:
+            if stanza.name == "id":
+                for stanzakey, stanzavalue in stanza.content.items():
+                    if stanzakey == "version":
+                        trackme_version = stanzavalue
 
         # get the schema_version_required
         schema_version_required = trackme_schema_format_version(trackme_version)
@@ -281,6 +285,20 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                             ):
                                 wlk_trackers.append(report)
 
+        # Count the number of active cim trackers
+        cim_trackers = []
+        splk_components = ["tenant_cim_objects"]
+
+        for kvrecord in collection.data.query(query=json.dumps(query_string)):
+            for splk_component in splk_components:
+                cim_tracker = kvrecord.get(splk_component)
+                if cim_tracker:
+                    cim_tracker = json.loads(cim_tracker)
+                    cim_reports = cim_tracker.get("reports")
+                    if cim_reports:
+                        for report in cim_reports:
+                            cim_trackers.append(report)
+
         #
         # check license
         #
@@ -412,6 +430,12 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
+                    # cim
+                    # add to response
+                    response["license_active_cim_trackers"] = len(cim_trackers)
+                    # add to response
+                    response["license_active_cim_trackers_list"] = cim_trackers
+
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
@@ -481,6 +505,12 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
+                    # cim
+                    # add to response
+                    response["license_active_cim_trackers"] = len(cim_trackers)
+                    # add to response
+                    response["license_active_cim_trackers_list"] = cim_trackers
+
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
@@ -549,6 +579,12 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
+                    # cim
+                    # add to response
+                    response["license_active_cim_trackers"] = len(cim_trackers)
+                    # add to response
+                    response["license_active_cim_trackers_list"] = cim_trackers
+
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
