@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_maintenance.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ import import_declare_test
 from trackme_libs_logging import setup_logger
 
 logger = setup_logger("trackme.rest.maintenance", "trackme_rest_api_maintenance.log")
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -102,7 +99,7 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -223,7 +220,7 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                                 data=json.dumps(data),
                                 headers=header,
                                 verify=False,
-                                timeout=600,
+                                timeout=300,
                             ) as response:
                                 response.raise_for_status()  # This will raise an HTTPError if the HTTP request returned an unsuccessful status code
                                 response_json = response.json()
@@ -434,10 +431,8 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                 # maintenance_mode_end
                 try:
                     maintenance_mode_end = resp_dict["maintenance_mode_end"]
-                    logger.info(f'Received maintenance_mode_end from request: "{maintenance_mode_end}" (type: {type(maintenance_mode_end).__name__})')
                 except Exception as e:
                     maintenance_mode_end = 0
-                    logger.warning(f'Failed to get maintenance_mode_end from request, defaulting to 0, exception="{str(e)}"')
 
                 # maintenance_duration
                 try:
@@ -461,19 +456,10 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                 # Add a knowledge record
                 try:
                     add_knowledge_record = resp_dict["add_knowledge_record"]
-                    # Handle both boolean and string values
-                    if isinstance(add_knowledge_record, bool):
-                        # Already a boolean, use as-is
-                        pass
-                    elif isinstance(add_knowledge_record, str):
-                        # String value, convert to boolean
-                        if add_knowledge_record.lower() in ("true", "1", "yes"):
-                            add_knowledge_record = True
-                        else:
-                            add_knowledge_record = False
-                    else:
-                        # Default to True for other types
+                    if add_knowledge_record in ("true", "True"):
                         add_knowledge_record = True
+                    else:
+                        add_knowledge_record = False
                 except Exception as e:
                     add_knowledge_record = True
 
@@ -510,78 +496,26 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
         # Calculates start and end
         time_updated = round(time.time())
 
-        # Get service early to check for existing record before processing start time
-        service = client.connect(
-            owner="nobody",
-            app="trackme",
-            port=request_info.server_rest_port,
-            token=request_info.system_authtoken,
-            timeout=600,
-        )
-
-        # get current user
-        username = request_info.user
-
-        # set loglevel
-        loglevel = trackme_getloglevel(
-            request_info.system_authtoken, request_info.server_rest_port
-        )
-        logger.setLevel(loglevel)
-
-        # Set the collection
-        collection_name = "kv_trackme_maintenance_mode"
-        collection = service.kvstore[collection_name]
-
-        # Get the current record early to check if we need to preserve start time
-        # Notes: the record is returned as an array, as we search for a specific record, we expect one record only
-        existing_start_time = None
-        try:
-            records = collection.data.query()
-            key = records[0].get("_key")
-            # Get existing start time to preserve it when extending
-            existing_start_time = records[0].get("maintenance_mode_start")
-        except Exception as e:
-            key = None
-
-        # Check if we need to preserve existing start time BEFORE applying defaults
-        # This must happen before the default logic that converts 0 to current time
-        should_preserve_start = False
-        try:
-            start_time_int = int(maintenance_mode_start) if maintenance_mode_start is not None else 0
-            if start_time_int <= 0 and existing_start_time:
-                should_preserve_start = True
-                maintenance_mode_start = str(existing_start_time)
-        except:
-            pass
-
         if time_format == "datestring":
             # convert maintenance start
-            # Skip datestring conversion if we're preserving an existing start time (it's already an epoch timestamp)
-            if not should_preserve_start:
-                try:
-                    maintenance_mode_start_dt = datetime.datetime.strptime(
-                        str(maintenance_mode_start), "%Y-%m-%dT%H:%M"
-                    )
-                    # Make the datetime timezone-aware as UTC
-                    maintenance_mode_start_dt = maintenance_mode_start_dt.replace(
-                        tzinfo=datetime.timezone.utc
-                    )
-                    maintenance_mode_start = int(
-                        round(float(maintenance_mode_start_dt.timestamp()))
-                    )
-                except Exception as e:
-                    return {
-                        "payload": {
-                            "response": f'Exception while trying to convert the input datestring, exception="{str(e)}"'
-                        },
-                        "status": 500,
-                    }
-            else:
-                # When preserving, maintenance_mode_start is already an epoch timestamp string, convert to int
-                try:
-                    maintenance_mode_start = int(maintenance_mode_start)
-                except:
-                    pass
+            try:
+                maintenance_mode_start_dt = datetime.datetime.strptime(
+                    str(maintenance_mode_start), "%Y-%m-%dT%H:%M"
+                )
+                # Make the datetime timezone-aware as UTC
+                maintenance_mode_start_dt = maintenance_mode_start_dt.replace(
+                    tzinfo=datetime.timezone.utc
+                )
+                maintenance_mode_start = int(
+                    round(float(maintenance_mode_start_dt.timestamp()))
+                )
+            except Exception as e:
+                return {
+                    "payload": {
+                        "response": f'Exception while trying to convert the input datestring, exception="{str(e)}"'
+                    },
+                    "status": 500,
+                }
 
             # convert maintenance end
             try:
@@ -604,8 +538,8 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                 }
 
         else:
-            # if maintenance start is not specified and we're not preserving existing, starts at now
-            if not should_preserve_start and ((maintenance_mode_start is None) or (maintenance_mode_start <= 0)):
+            # if maintenance start is not specified, starts at now
+            if (maintenance_mode_start is None) or (maintenance_mode_start <= 0):
                 maintenance_mode_start = str(round(time_updated))
 
             # if maintenance end is not specified, and maintenance duration is not specified either, defaults to now + 24 hours
@@ -617,18 +551,45 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
             maintenance_mode_end = str(round(time.time() + maintenance_duration))
 
         # control: the start of the maintenance cannot be in the past (allow 5 min margin)
-        # Exception: if we're preserving an existing start time from an existing record, allow it
-        if not should_preserve_start:
-            try:
-                if int(maintenance_mode_start) - time.time() < -300:
-                    return {
-                        "payload": {
-                            "response": f"The maintenance start cannot be in the past, it is in past of {round(int(maintenance_mode_start) - time.time())} seconds"
-                        },
-                        "status": 500,
-                    }
-            except:
-                pass
+        if int(maintenance_mode_start) - time.time() < -300:
+            return {
+                "payload": {
+                    "response": f"The maintenance start cannot be in the past, it is in past of {round(int(maintenance_mode_start) - time.time())} seconds"
+                },
+                "status": 500,
+            }
+
+        # Get service
+        service = client.connect(
+            owner="nobody",
+            app="trackme",
+            port=request_info.server_rest_port,
+            token=request_info.system_authtoken,
+            timeout=300,
+        )
+
+        # get current user
+        username = request_info.user
+
+        # set loglevel
+        loglevel = trackme_getloglevel(
+            request_info.system_authtoken, request_info.server_rest_port
+        )
+        logger.setLevel(loglevel)
+
+        # Set the collection
+        collection_name = "kv_trackme_maintenance_mode"
+        collection = service.kvstore[collection_name]
+
+        # Get the current record
+        # Notes: the record is returned as an array, as we search for a specific record, we expect one record only
+
+        try:
+            records = collection.data.query()
+            key = records[0].get("_key")
+
+        except Exception as e:
+            key = None
 
         # set count down
         maintenance_countdown = round(int(maintenance_mode_end) - time.time(), 0)
@@ -639,12 +600,8 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
         except:
             pass
         try:
-            maintenance_mode_end_before = maintenance_mode_end
             maintenance_mode_end = int(round(float(maintenance_mode_end), 0))
-            if maintenance_mode_end_before != maintenance_mode_end:
-                logger.info(f'Converted maintenance_mode_end from "{maintenance_mode_end_before}" to "{maintenance_mode_end}"')
-        except Exception as e:
-            logger.warning(f'Failed to convert maintenance_mode_end to int, exception="{str(e)}"')
+        except:
             pass
 
         # is this a scheduled maintenance?
@@ -694,25 +651,6 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                 "src_user": username,
             }
 
-        # Get existing knowledge_record_id before updating (if extending)
-        existing_knowledge_record_id = None
-        if key:
-            try:
-                existing_record = collection.data.query_by_id(key)
-                existing_knowledge_record_id = existing_record.get("knowledge_record_id")
-                # Handle empty string or None
-                if existing_knowledge_record_id == "" or existing_knowledge_record_id is None:
-                    existing_knowledge_record_id = None
-                # Preserve knowledge_record_id in the response when updating
-                if existing_knowledge_record_id:
-                    maintenance_mode_response["knowledge_record_id"] = existing_knowledge_record_id
-                logger.info(
-                    f'Found existing maintenance record, key="{key}", knowledge_record_id="{existing_knowledge_record_id}", add_knowledge_record="{add_knowledge_record}" (type: {type(add_knowledge_record).__name__})'
-                )
-            except Exception as e:
-                logger.warning(f'Failed to get existing record, key="{key}", exception="{str(e)}"')
-                pass
-
         if key:
             # Update the record
             collection.data.update(str(key), json.dumps(maintenance_mode_response))
@@ -721,100 +659,6 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
             kv_response = collection.data.insert(json.dumps(maintenance_mode_response))
             key = kv_response.get("_key")
 
-        # Update existing knowledge record if extending (not creating new one)
-        logger.info(
-            f'Checking knowledge record update conditions: key="{key}", existing_knowledge_record_id="{existing_knowledge_record_id}", add_knowledge_record="{add_knowledge_record}" (type: {type(add_knowledge_record).__name__}), not add_knowledge_record="{not add_knowledge_record}"'
-        )
-        if key and existing_knowledge_record_id and not add_knowledge_record:
-            # We're extending an existing maintenance period, update the knowledge record's end time
-            logger.info(
-                f'Attempting to update knowledge record for extended maintenance period, record_id="{existing_knowledge_record_id}", new_end_time="{maintenance_mode_end}"'
-            )
-            try:
-                kdb_collection_name = "kv_trackme_maintenance_kdb"
-                kdb_collection = service.kvstore[kdb_collection_name]
-                
-                # Get the existing knowledge record
-                kdb_record = kdb_collection.data.query_by_id(existing_knowledge_record_id)
-                if kdb_record:
-                    # Store old end time for logging
-                    old_end_time = kdb_record.get("time_end")
-                    logger.info(
-                        f'Retrieved knowledge record before update: record_id="{existing_knowledge_record_id}", current_time_end="{old_end_time}", target_time_end="{maintenance_mode_end}"'
-                    )
-                    
-                    # Update the end time to the new extended end time
-                    # Ensure we're using the integer value
-                    new_end_time = int(maintenance_mode_end)
-                    kdb_record["time_end"] = new_end_time
-                    kdb_record["mtime"] = round(time.time(), 0)
-                    if update_comment:
-                        kdb_record["add_info"] = update_comment
-                    
-                    # Log the record we're about to update
-                    logger.info(
-                        f'Updating knowledge record with: time_end="{new_end_time}", mtime="{kdb_record["mtime"]}", add_info="{kdb_record.get("add_info", "")}"'
-                    )
-                    
-                    # Update the knowledge record - ensure we're updating with the correct key format
-                    update_result = kdb_collection.data.update(str(existing_knowledge_record_id), json.dumps(kdb_record))
-                    logger.info(f'KVStore update result: {update_result}')
-                    
-                    # Verify the update was persisted by querying the record again
-                    try:
-                        updated_record = kdb_collection.data.query_by_id(existing_knowledge_record_id)
-                        verified_end_time = updated_record.get("time_end") if updated_record else None
-                        logger.info(
-                            f'Success updating knowledge record end time for extended maintenance period, record_id="{existing_knowledge_record_id}", old_end_time="{old_end_time}", new_end_time="{maintenance_mode_end}", verified_end_time="{verified_end_time}"'
-                        )
-                        if verified_end_time != int(maintenance_mode_end):
-                            logger.error(
-                                f'VERIFICATION FAILED: Knowledge record update did not persist correctly! Expected end_time="{maintenance_mode_end}", but verified_end_time="{verified_end_time}"'
-                            )
-                    except Exception as verify_error:
-                        logger.warning(
-                            f'Could not verify knowledge record update, record_id="{existing_knowledge_record_id}", exception="{str(verify_error)}"'
-                        )
-                        logger.info(
-                            f'Success updating knowledge record end time for extended maintenance period, record_id="{existing_knowledge_record_id}", old_end_time="{old_end_time}", new_end_time="{maintenance_mode_end}"'
-                        )
-                    
-                    # Record audit change
-                    trackme_audit_event(
-                        request_info.system_authtoken,
-                        request_info.server_rest_uri,
-                        "all",
-                        request_info.user,
-                        "success",
-                        "extend maintenance period - update knowledge record",
-                        "all",
-                        "all",
-                        str(json.dumps(kdb_record, indent=1)),
-                        f'The knowledge record end time was updated for extended maintenance period by user="{username}"',
-                        str(update_comment),
-                    )
-                else:
-                    logger.warning(
-                        f'Knowledge record not found for record_id="{existing_knowledge_record_id}", cannot update end time'
-                    )
-            except Exception as e:
-                # Log error but don't fail the extend operation
-                import traceback
-                error_message = f'Failed to update knowledge record end time, record_id="{existing_knowledge_record_id}", exception="{str(e)}", traceback="{traceback.format_exc()}"'
-                logger.error(error_message)
-        else:
-            # Log why knowledge record update was skipped
-            reasons = []
-            if not key:
-                reasons.append("no key (new record)")
-            if not existing_knowledge_record_id:
-                reasons.append("no existing knowledge_record_id")
-            if add_knowledge_record:
-                reasons.append(f"add_knowledge_record is {add_knowledge_record}")
-            logger.info(
-                f'Skipping knowledge record update: {", ".join(reasons) if reasons else "unknown reason"}'
-            )
-
         # record an audit change
         trackme_audit_event(
             request_info.system_authtoken,
@@ -873,7 +717,7 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                     data=json.dumps(data),
                     headers=header,
                     verify=False,
-                    timeout=600,
+                    timeout=300,
                 ) as response:
                     response.raise_for_status()  # This will raise an HTTPError if the HTTP request returned an unsuccessful status code
                     response_json = response.json()
@@ -970,7 +814,7 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # get current user
@@ -1062,7 +906,7 @@ class TrackMeHandlerMaintenance_v2(trackme_rest_handler.RESTHandler):
                             data=json.dumps(data),
                             headers=header,
                             verify=False,
-                            timeout=600,
+                            timeout=300,
                         ) as response:
                             response.raise_for_status()  # This will raise an HTTPError if the HTTP request returned an unsuccessful status code
                             response_json = response.json()
