@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_maintenance.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.maintenance_kdb_admin", "trackme_rest_api_maintenance_kdb_admin.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -49,9 +46,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerMaintenanceKdbAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerMaintenanceKdb_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerMaintenanceKdbAdmin_v2, self).__init__(
+        super(TrackMeHandlerMaintenanceKdb_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -273,7 +270,7 @@ class TrackMeHandlerMaintenanceKdbAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -448,7 +445,7 @@ class TrackMeHandlerMaintenanceKdbAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -780,7 +777,7 @@ class TrackMeHandlerMaintenanceKdbAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -964,7 +961,7 @@ class TrackMeHandlerMaintenanceKdbAdmin_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
