@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_maintenance_kdb_user.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -32,10 +32,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.maintenance_kdb_user", "trackme_rest_api_maintenance_kdb_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -48,9 +45,9 @@ from trackme_libs import trackme_getloglevel
 import splunklib.client as client
 
 
-class TrackMeHandlerMaintenanceKdbRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerMaintenanceKdb_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerMaintenanceKdbRead_v2, self).__init__(
+        super(TrackMeHandlerMaintenanceKdb_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -126,7 +123,7 @@ class TrackMeHandlerMaintenanceKdbRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=request_info.server_rest_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
