@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_allowlist.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -31,10 +31,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_blocklist_power", "trackme_rest_api_splk_blocklist_power.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 import trackme_rest_handler
@@ -53,9 +50,9 @@ from trackme_libs_utils import update_wildcard
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkBlocklist_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkBlocklistWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkBlocklist_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -203,7 +200,7 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -380,10 +377,7 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
                     keys_list = resp_dict["keys_list"]
                     # Handle as a CSV list of keys if not a list already
                     if not isinstance(keys_list, list):
-                        keys_list = [x.strip() for x in keys_list.split(",") if x.strip()]
-                    else:
-                        # Filter out empty strings from existing list
-                        keys_list = [x.strip() if isinstance(x, str) else x for x in keys_list if (x.strip() if isinstance(x, str) else bool(x))]
+                        keys_list = keys_list.split(",")
                 except Exception as e:
                     return {
                         "payload": "keys_list is required, please provide a valid keys_list",
@@ -426,7 +420,7 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -636,9 +630,8 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
 
                 try:
                     records_list = resp_dict["records_list"]
-                    # Handle as an object list if needed
-                    if not isinstance(records_list, list):
-                        records_list = json.loads(records_list)
+                    # Handle as a CSV list of keys
+                    records_list = json.loads(records_list)
                 except Exception as e:
                     return {
                         "payload": "records_list is required, please provide a valid records_list",
@@ -682,7 +675,7 @@ class TrackMeHandlerSplkBlocklistWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
