@@ -34,10 +34,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_cim_power", "trackme_rest_api_splk_cim_power.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -62,9 +59,9 @@ from trackme_libs_bulk_edit import post_bulk_edit, generic_batch_update
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkCimTracking_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkCimTrackingWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkCimTracking_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -112,7 +109,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -221,7 +218,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -331,7 +328,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -496,7 +493,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -612,7 +609,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -756,7 +753,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -983,7 +980,7 @@ class TrackMeHandlerSplkCimTrackingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
