@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_data_sampling.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_data_sampling_power",
     "trackme_rest_api_splk_data_sampling_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # improt rest handler
@@ -49,9 +46,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDataSampling_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDataSamplingWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkDataSampling_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -65,7 +62,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
 
     # Add new model
     def post_data_sampling_models_add(self, request_info, **kwargs):
-        r"""
+        """
         | trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\sNetScreen\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"
         """
 
@@ -118,7 +115,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint creates a new data sampling custom model, it requires a POST call with the following data:",
                 "resource_desc": "Add new Data Sampling custom model",
-                "resource_spl_example": r"| trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\\\sNetScreen\\\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"",
+                "resource_spl_example": "| trackme mode=post url=\"/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add\" body=\"{'tenant_id':'mytenant', 'model_name':'Netscreen', 'model_type':'inclusive', 'model_regex':':\\\sNetScreen\\\sdevice_id=', 'sourcetype_scope': 'netscreen:firewall'}\"",
                 "options": [
                     {
                         "model_name": "name of the custom model",
@@ -146,7 +143,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -283,9 +280,8 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 models_list = resp_dict["models_list"]
-                # if not a list already, convert to a list from comma separated string
-                if not isinstance(models_list, list):
-                    models_list = models_list.split(",")
+                # Handle as a CSV list of keys
+                models_list = models_list.split(",")
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -322,7 +318,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -347,7 +343,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
 
         # loop
         for item in models_list:
-            # Try to find the record by _key first (for backward compatibility)
+            # Define the KV query
             query_string = {
                 "_key": item,
             }
@@ -357,21 +353,9 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             try:
                 kvrecord = collection.data.query(query=json.dumps(query_string))[0]
                 key = kvrecord.get("_key")
+
             except Exception as e:
                 key = None
-                kvrecord = None
-
-            # If not found by _key, try model_id (for new UI calls)
-            if not key:
-                query_string = {
-                    "model_id": item,
-                }
-                try:
-                    kvrecord = collection.data.query(query=json.dumps(query_string))[0]
-                    key = kvrecord.get("_key")
-                except Exception as e:
-                    key = None
-                    kvrecord = None
 
             # Render result
             if key:
@@ -520,15 +504,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 records_list = resp_dict["records_list"]
-                # handle records_list, if not an object attempt json loads
-                if not isinstance(records_list, list) and not isinstance(records_list, dict):
-                    try:
-                        records_list = json.loads(records_list)
-                    except Exception as e:
-                        return {
-                            "payload": f"records_list is not a valid JSON: {str(e)}",
-                            "status": 500,
-                        }
+                records_list = json.loads(records_list)
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -565,7 +541,7 @@ class TrackMeHandlerSplkDataSamplingWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
