@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_deleted_entities_power.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -31,10 +31,7 @@ logger = setup_logger(
     "trackme.rest.splk_deleted_entities_power",
     "trackme_rest_api_splk_deleted_entities_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -51,9 +48,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDeletedEntitiesPower_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDeletedEntities_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDeletedEntitiesPower_v2, self).__init__(
+        super(TrackMeHandlerSplkDeletedEntities_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -183,7 +180,7 @@ class TrackMeHandlerSplkDeletedEntitiesPower_v2(trackme_rest_handler.RESTHandler
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
