@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dhm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -30,10 +30,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dhm_power", "trackme_rest_api_splk_dhm_power.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 import trackme_rest_handler
@@ -66,9 +63,9 @@ from trackme_libs_bulk_edit import post_bulk_edit, generic_batch_update
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDhmWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkDhm_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -123,7 +120,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -237,7 +234,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -350,7 +347,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -478,7 +475,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -555,6 +552,19 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                         "status": 500,
                     }
 
+                try:
+                    data_lag_alert_kpis = resp_dict[
+                        "data_lag_alert_kpis"
+                    ]  # all_kpis / lag_ingestion_kpi / lag_event_kpi
+                    if not data_lag_alert_kpis in (
+                        "all_kpis",
+                        "lag_ingestion_kpi",
+                        "lag_event_kpi",
+                    ):
+                        data_lag_alert_kpis = None
+                except Exception as e:
+                    data_lag_alert_kpis = None
+
                 try:
                     data_max_lag_allowed = resp_dict["data_max_lag_allowed"]
                     data_max_lag_allowed = convert_time_to_seconds(data_max_lag_allowed)
@@ -603,36 +613,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                 try:
                     future_tolerance = resp_dict["future_tolerance"]
                 except Exception as e:
-                    future_tolerance = None
-
-                try:
-                    impact_score_weights = resp_dict.get("impact_score_weights")
-                    if impact_score_weights:
-                        # Validate it's a dict or can be parsed as JSON
-                        if isinstance(impact_score_weights, str):
-                            impact_score_weights = json.loads(impact_score_weights)
-                        if isinstance(impact_score_weights, dict):
-                            # Validate keys are 'delay' and/or 'latency' with integer values 0-100
-                            validated_weights = {}
-                            for key in ["delay", "latency"]:
-                                if key in impact_score_weights:
-                                    try:
-                                        weight_value = int(impact_score_weights[key])
-                                        if 0 <= weight_value <= 100:
-                                            validated_weights[key] = weight_value
-                                    except (ValueError, TypeError):
-                                        pass
-                            # Only set if we have at least one valid weight
-                            if validated_weights:
-                                impact_score_weights = json.dumps(validated_weights)
-                            else:
-                                impact_score_weights = None
-                        else:
-                            impact_score_weights = None
-                    else:
-                        impact_score_weights = None
-                except (json.JSONDecodeError, TypeError, ValueError) as e:
-                    impact_score_weights = None
+                    future_tolerance = "system"
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -642,19 +623,19 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint resets (removal of index and sourcetype knowledge) an existing data host by the data host name (object), it requires a POST call with the following information:",
                 "resource_desc": "Update lag policies for a comma separated list of entities",
-                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_dhm/write/dh_update_lag_policy\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'remote|account:lab|firewall.pan.amer.design.node1','data_max_lag_allowed':'900','data_max_delay_allowed':'1600','data_override_lagging_class':'false','splk_dhm_alerting_policy': 'global'}\"",
+                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_dhm/write/dh_update_lag_policy\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'remote|account:lab|firewall.pan.amer.design.node1','data_max_lag_allowed':'900','data_max_delay_allowed':'1600','data_lag_alert_kpis':'all_kpis','data_override_lagging_class':'false','splk_dhm_alerting_policy': 'global'}\"",
                 "options": [
                     {
                         "tenant_id": "The tenant identifier",
                         "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
-                        "data_max_lag_allowed": "OPTIONAL, maximal accepted lagging value in seconds or with unit suffix (m/h/d/w), e.g. 3600 or '15m' or '1h' or '1d' or '1w'",
-                        "data_max_delay_allowed": "OPTIONAL, maximal accepted delay value in seconds or with unit suffix (m/h/d/w), e.g. 3600 or '15m' or '1h' or '1d' or '1w'",
+                        "data_lag_alert_kpis": "OPTIONAL, KPIs policy to be applied, valid options are all_kpis / lag_ingestion_kpi / lag_event_kpi",
+                        "data_max_lag_allowed": "OPTIONAL, maximal accepted lagging value in seconds or with unit suffix (h/d/w), e.g. 3600 or '1h' or '1d' or '1w'",
+                        "data_max_delay_allowed": "OPTIONAL, maximal accepted delay value in seconds or with unit suffix (h/d/w), e.g. 3600 or '1h' or '1d' or '1w'",
                         "data_override_lagging_class": "OPTIONAL, overrides lagging classes, valid options are true / false",
                         "splk_dhm_alerting_policy": "OPTIONAL, the policy, valid options are: global_policy / track_per_sourcetype / track_per_host",
                         "future_tolerance": "OPTIONAL, the negative value for future tolerance, specify system to rely on the system level setting, disabled to allow data in the future up to 7 days without affecting the status of the entity",
                         "allow_adaptive_delay": "OPTIONAL, allow adaptive delay, valid options are true / false",
-                        "impact_score_weights": "OPTIONAL, JSON object with custom impact score weights for delay and/or latency (0-100), e.g. {'delay': 100, 'latency': 48}. If not set, tenant-level defaults are used.",
                         "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
                 ],
@@ -677,7 +658,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -704,6 +685,8 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             update_fields["data_max_lag_allowed"] = data_max_lag_allowed
         if data_max_delay_allowed:
             update_fields["data_max_delay_allowed"] = data_max_delay_allowed
+        if data_lag_alert_kpis:
+            update_fields["data_lag_alert_kpis"] = data_lag_alert_kpis
         if data_override_lagging_class:
             update_fields["data_override_lagging_class"] = data_override_lagging_class
         if splk_dhm_alerting_policy:
@@ -712,8 +695,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             update_fields["allow_adaptive_delay"] = allow_adaptive_delay
         if future_tolerance:
             update_fields["future_tolerance"] = future_tolerance
-        if impact_score_weights:
-            update_fields["impact_score_weights"] = impact_score_weights
         if not update_fields:
             return {
                 "payload": {"error": "no valid fields to update"},
@@ -814,7 +795,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -930,7 +911,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -970,267 +951,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
 
         return {"payload": response, "status": status_code}
 
-    # Update monitoring time policy and rules by object name
-    def post_dh_update_monitoring_time(self, request_info, **kwargs):
-        # Retrieve from data
-        try:
-            resp_dict = json.loads(str(request_info.raw_args["payload"]))
-        except Exception as e:
-            resp_dict = None
-
-        if resp_dict is not None:
-            try:
-                describe = resp_dict["describe"]
-                if describe in ("true", "True"):
-                    describe = True
-            except Exception as e:
-                describe = False
-            if not describe:
-                tenant_id = resp_dict["tenant_id"]
-
-                # handle object_list / keys_list
-                object_list = resp_dict.get("object_list", None)
-                if object_list:
-                    if not isinstance(object_list, list):
-                        object_list = object_list.split(",")
-
-                keys_list = resp_dict.get("keys_list", None)
-                if keys_list:
-                    if not isinstance(keys_list, list):
-                        keys_list = keys_list.split(",")
-
-                if not object_list and not keys_list:
-                    return {
-                        "payload": {
-                            "error": "either object_list or keys_list must be provided"
-                        },
-                        "status": 500,
-                    }
-
-                # Get monitoring_time_policy (optional)
-                monitoring_time_policy = resp_dict.get("monitoring_time_policy", None)
-                
-                # Get monitoring_time_rules (optional, takes precedence over policy)
-                monitoring_time_rules = resp_dict.get("monitoring_time_rules", None)
-
-                # Validate that at least one is provided
-                if not monitoring_time_policy and not monitoring_time_rules:
-                    return {
-                        "payload": {
-                            "error": "either monitoring_time_policy or monitoring_time_rules must be provided"
-                        },
-                        "status": 500,
-                    }
-
-                # Validate monitoring_time_rules format if provided
-                if monitoring_time_rules is not None:
-                    if isinstance(monitoring_time_rules, str):
-                        try:
-                            monitoring_time_rules = json.loads(monitoring_time_rules)
-                        except Exception as e:
-                            return {
-                                "payload": {
-                                    "error": f"monitoring_time_rules must be a valid JSON object, error: {str(e)}"
-                                },
-                                "status": 500,
-                            }
-                    
-                    if not isinstance(monitoring_time_rules, dict):
-                        return {
-                            "payload": {
-                                "error": "monitoring_time_rules must be a dictionary with week day keys (0-6) and hour lists as values"
-                            },
-                            "status": 500,
-                        }
-                    
-                    # Validate each day entry
-                    for day_key, hours_list in monitoring_time_rules.items():
-                        try:
-                            day_int = int(day_key)
-                            if day_int < 0 or day_int > 6:
-                                return {
-                                    "payload": {
-                                        "error": f"monitoring_time_rules: day key must be 0-6 (Sunday-Saturday), got {day_int}"
-                                    },
-                                    "status": 500,
-                                }
-                        except (ValueError, TypeError):
-                            return {
-                                "payload": {
-                                    "error": f"monitoring_time_rules: day key must be an integer 0-6, got {day_key}"
-                                },
-                                "status": 500,
-                            }
-                        
-                        if not isinstance(hours_list, list):
-                            return {
-                                "payload": {
-                                    "error": f"monitoring_time_rules: hours for day {day_key} must be a list"
-                                },
-                                "status": 500,
-                            }
-                        
-                        # Validate hours (0-23, with optional decimals like 0.5, 0.25)
-                        for hour in hours_list:
-                            try:
-                                hour_float = float(hour)
-                                if hour_float < 0 or hour_float >= 24:
-                                    return {
-                                        "payload": {
-                                            "error": f"monitoring_time_rules: hours must be between 0-23.99, got {hour_float}"
-                                        },
-                                        "status": 500,
-                                    }
-                                # Check for valid decimal increments (0.25, 0.5, 0.75)
-                                if hour_float != int(hour_float):
-                                    decimal_part = hour_float - int(hour_float)
-                                    if decimal_part not in [0.25, 0.5, 0.75]:
-                                        return {
-                                            "payload": {
-                                                "error": f"monitoring_time_rules: decimal hours must be .25, .5, or .75, got {hour_float}"
-                                            },
-                                            "status": 500,
-                                        }
-                            except (ValueError, TypeError):
-                                return {
-                                    "payload": {
-                                        "error": f"monitoring_time_rules: hour value must be numeric, got {hour}"
-                                    },
-                                    "status": 500,
-                                }
-
-                # Validate monitoring_time_policy format if provided
-                if monitoring_time_policy is not None:
-                    valid_policies = [
-                        "all_time",
-                        "business_days_all_hours",
-                        "monday_saturday_all_hours",
-                        "business_days_08h_20h",
-                        "monday_saturday_08h_20h",
-                    ]
-                    
-                    # Check if it's a string/list of predefined rules
-                    if isinstance(monitoring_time_policy, str):
-                        if monitoring_time_policy not in valid_policies:
-                            # Try to parse as JSON (might be dictionary format)
-                            try:
-                                monitoring_time_policy = json.loads(monitoring_time_policy)
-                            except Exception:
-                                return {
-                                    "payload": {
-                                        "error": f"monitoring_time_policy must be one of {valid_policies} or a valid JSON dictionary"
-                                    },
-                                    "status": 500,
-                                }
-                    elif isinstance(monitoring_time_policy, list):
-                        # Validate all items in list are valid policies
-                        for policy in monitoring_time_policy:
-                            if policy not in valid_policies:
-                                return {
-                                    "payload": {
-                                        "error": f"monitoring_time_policy list contains invalid policy: {policy}, valid options are {valid_policies}"
-                                    },
-                                    "status": 500,
-                                }
-                    elif isinstance(monitoring_time_policy, dict):
-                        # Dictionary format is allowed (same as monitoring_time_rules)
-                        pass
-                    else:
-                        return {
-                            "payload": {
-                                "error": "monitoring_time_policy must be a string, list of strings, or dictionary"
-                            },
-                            "status": 500,
-                        }
-
-        else:
-            # body is required in this endpoint, if not submitted describe the usage
-            describe = True
-
-        if describe:
-            response = {
-                "describe": "This endpoint configures the monitoring time policy and rules for an existing data host, it requires a POST call with the following information:",
-                "resource_desc": "Update monitoring time policy/rules for a comma separated list of entities",
-                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_dhm/write/dh_update_monitoring_time\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'remote|account:lab|firewall.pan.amer.design.node1','monitoring_time_policy':'business_days_08h_20h'}\"",
-                "options": [
-                    {
-                        "tenant_id": "The tenant identifier",
-                        "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
-                        "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
-                        "monitoring_time_policy": "OPTIONAL: predefined policy name (all_time, business_days_all_hours, monday_saturday_all_hours, business_days_08h_20h, monday_saturday_08h_20h) or dictionary format like monitoring_time_rules",
-                        "monitoring_time_rules": "OPTIONAL: dictionary with week day keys (0-6 for Sunday-Saturday) and hour lists as values, e.g. {0: [8,9,10], 1: [8,9,10]}. Hours can be 0-23 or decimals like 0.5 (00:30), 0.25 (00:15), 0.75 (00:45). Takes precedence over monitoring_time_policy if both provided.",
-                        "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
-                    }
-                ],
-            }
-
-            return {"payload": response, "status": 200}
-
-        # Update comment is optional and used for audit changes
-        try:
-            update_comment = resp_dict["update_comment"]
-        except Exception as e:
-            update_comment = "API update"
-
-        # Get splunkd port
-        splunkd_port = request_info.server_rest_port
-
-        # Get service
-        service = client.connect(
-            owner="nobody",
-            app="trackme",
-            port=splunkd_port,
-            token=request_info.session_key,
-            timeout=600,
-        )
-
-        # set loglevel
-        loglevel = trackme_getloglevel(
-            request_info.system_authtoken, request_info.server_rest_port
-        )
-        logger.setLevel(loglevel)
-
-        # Data collection
-        collection_name = f"kv_trackme_dhm_tenant_{tenant_id}"
-        collection = service.kvstore[collection_name]
-
-        # Prepare the request_info with the necessary data
-        update_request_info = {
-            "tenant_id": tenant_id,
-            "component": "dhm",
-            "object_list": object_list,
-            "keys_list": keys_list,
-        }
-
-        # Prepare the update fields
-        # monitoring_time_rules takes precedence over monitoring_time_policy
-        update_fields = {}
-        if monitoring_time_rules is not None:
-            # Convert dict keys to strings if they're integers (for JSON serialization)
-            if isinstance(monitoring_time_rules, dict):
-                monitoring_time_rules = {str(k): v for k, v in monitoring_time_rules.items()}
-            update_fields["monitoring_time_rules"] = json.dumps(monitoring_time_rules) if isinstance(monitoring_time_rules, dict) else monitoring_time_rules
-        if monitoring_time_policy is not None:
-            if isinstance(monitoring_time_policy, dict):
-                monitoring_time_policy = {str(k): v for k, v in monitoring_time_policy.items()}
-            update_fields["monitoring_time_policy"] = json.dumps(monitoring_time_policy) if isinstance(monitoring_time_policy, (dict, list)) else monitoring_time_policy
-
-        # Call the generic update function
-        response, status_code = generic_batch_update(
-            self,
-            request_info,
-            update_request_info=update_request_info,
-            collection=collection,
-            update_fields=update_fields,
-            persistent_fields=persistent_fields_dhm,
-            component="dhm",
-            update_comment=update_comment,
-            audit_context="update monitoring time policy/rules",
-            audit_message="Monitoring time policy/rules were updated successfully",
-        )
-
-        return {"payload": response, "status": status_code}
-
     # Remove entities
     def post_dh_delete(self, request_info, **kwargs):
         # Retrieve from data
@@ -1322,7 +1042,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1390,30 +1110,16 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                 collection.data.delete(json.dumps({"_key": key}))
 
                 if deletion_type == "permanent":
-                    # Register a new permanently deleted object, if not already present
-                    try:
-                        record_perm_deleted = collection_perm_deleted.data.query(
-                            query=json.dumps({"object": object_value, "object_category": "splk-dhm"})
-                        )[0]
-                        pass
-                    except Exception as e:
-                        record_perm_deleted = None
-
-                    if not record_perm_deleted:
-                        try:
-                            collection_perm_deleted.data.insert(
-                                json.dumps(
-                                    {
-                                        "ctime": str(time.time()),
-                                        "object": str(object_value),
-                                        "object_category": "splk-dhm",
-                                    }
-                                )
-                            )
-                        except Exception as e:
-                            logger.error(
-                                f'tenant_id="{tenant_id}", failed to register a new permanently deleted object, object="{object_value}", exception="{str(e)}"'
-                            )
+                    # Register a new permanently deleted object
+                    collection_perm_deleted.data.insert(
+                        json.dumps(
+                            {
+                                "ctime": str(time.time()),
+                                "object": str(object_value),
+                                "object_category": "splk-dhm",
+                            }
+                        )
+                    )
 
                 # try deleting outliers records for rules and data, there might be nothing to delete
                 try:
@@ -1619,7 +1325,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1817,7 +1523,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                         "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "tags_manual": "A comma seperated list of tags to be applied to the entities, to purge all manual tags, send an empty string",
-                        "operation": "OPTIONAL: operation mode - 'replace' (default, replaces all manual tags), 'add' (adds tags to existing), 'remove' (removes specified tags)",
                         "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
                 ],
@@ -1848,7 +1553,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1865,11 +1570,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
         collection_tags_policies_name = f"kv_trackme_dhm_tags_tenant_{tenant_id}"
         collection_tags_policies = service.kvstore[collection_tags_policies_name]
 
-        # Store original tags_manual input before loop to prevent mutation issues
-        original_tags_manual = tags_manual
-        # Get operation mode (default: "replace" for backward compatibility)
-        operation = resp_dict.get("operation", "replace")
-
         # loop and proceed
         if object_list:
             keys_list = []
@@ -1909,35 +1609,11 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                 if tags:
                     tags = tags.split(",")
 
-                # Get existing tags_manual before updating
-                existing_tags_manual = kvrecord.get("tags_manual", "")
-                existing_tags_manual_list = existing_tags_manual.split(",") if existing_tags_manual else []
-                # Filter out empty strings
-                existing_tags_manual_list = [x for x in existing_tags_manual_list if x]
-
-                # Process tags_manual based on operation using original input (not mutated)
-                original_tags_manual_list = original_tags_manual.split(",") if original_tags_manual else []
-                original_tags_manual_list = [x for x in original_tags_manual_list if x]  # Filter out empty strings
-
-                if operation == "add":
-                    # Merge: combine existing and new tags, deduplicate (lowercase before deduplication for case-insensitive matching)
-                    all_tags = list(set([x.lower() for x in existing_tags_manual_list + original_tags_manual_list if x]))
-                    tags_manual = ",".join(sorted(all_tags))
-                elif operation == "remove":
-                    # Remove: filter out tags to remove
-                    original_tags_manual_list_lower = [x.lower() for x in original_tags_manual_list]
-                    remaining_tags = [x for x in existing_tags_manual_list if x.lower() not in original_tags_manual_list_lower]
-                    tags_manual = ",".join(sorted([x.lower() for x in remaining_tags if x]))
-                else:  # "replace" (default)
-                    # Replace: use new tags as-is (current behavior)
-                    tags_manual = original_tags_manual  # Use original input
-
-                # update the record with our manual tags
+                # update the record with ours manual tags
                 kvrecord["tags_manual"] = tags_manual
 
-                # make tags_manual_list (list from tags_manual CSV) for merging with tags_auto
-                tags_manual_list = tags_manual.split(",") if tags_manual else []
-                tags_manual_list = [x for x in tags_manual_list if x]  # Filter out empty strings
+                # make tags_manual_list (list from tags_manual CSV)
+                tags_manual_list = tags_manual.split(",")
 
                 # merged them all: define the tags field as the deduplicated, lowercase and sorted list of tags based on the tags_auto and tags_manual_list
                 tags = ",".join(
@@ -2104,7 +1780,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
