@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dhm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -29,10 +29,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dhm_user", "trackme_rest_api_splk_dhm_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 import trackme_rest_handler
@@ -53,9 +50,9 @@ from trackme_libs_utils import remove_leading_spaces
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDhm_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDhmRead_v2, self).__init__(
+        super(TrackMeHandlerSplkDhm_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -151,7 +148,7 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -246,9 +243,6 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
                 entity_info["splk_dhm_raw_search"] = entity_searches.get(
                     "splk_dhm_raw_search"
                 )
-                entity_info["splk_dhm_metrics_populate_search"] = entity_searches.get(
-                    "splk_dhm_metrics_populate_search"
-                )
 
                 # single stats: manage both splunk query and trackme metric based query
                 entity_info["splk_dhm_overview_splunk_single_stats"] = (
@@ -268,7 +262,7 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
                     entity_searches.get("splk_dhm_overview_pie_root_search")
                 )
                 entity_info["splk_dhm_overview_trackme_pie_root_search"] = (
-                    f'| mstats latest(trackme.splk_dhm.last_eventcount) as count where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-dhm" object_id="{key}" by object, idx, st | rename idx as index, st as sourcetype | where [ | inputlookup trackme_dhm_tenant_{tenant_id} where _key="{key}" | table data_index, data_sourcetype | eval data_index=split(data_index, ","), data_sourcetype=split(data_sourcetype, ",") | rename data_index as index, data_sourcetype as sourcetype | format | return $search ]'
+                    f'| mstats latest(trackme.splk_dhm.last_eventcount) as count where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-dhm" object="{object_value}" by object, idx, st | rename idx as index, st as sourcetype'
                 )
 
                 # timechart view
@@ -421,7 +415,7 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -522,7 +516,7 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
