@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_disruption_user.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -29,10 +29,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_disruption_user", "trackme_rest_api_splk_disruption_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 import trackme_rest_handler
 
@@ -46,9 +43,9 @@ from trackme_libs_utils import remove_leading_spaces
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDisruptionRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDisruption_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDisruptionRead_v2, self).__init__(
+        super(TrackMeHandlerSplkDisruption_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -130,7 +127,7 @@ class TrackMeHandlerSplkDisruptionRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
