@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dsm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -31,10 +31,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_dsm_user", "trackme_rest_api_splk_dsm_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -57,9 +54,9 @@ from trackme_libs_utils import remove_leading_spaces
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkDsm_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkDsmRead_v2, self).__init__(
+        super(TrackMeHandlerSplkDsm_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -155,7 +152,7 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -389,9 +386,6 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
                 entity_info["splk_dsm_sampling_search"] = entity_searches.get(
                     "splk_dsm_sampling_search"
                 )
-                entity_info["splk_dsm_metrics_populate_search"] = entity_searches.get(
-                    "splk_dsm_metrics_populate_search"
-                )
 
                 # add object and key
                 entity_info["object"] = object_value
@@ -521,7 +515,7 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -609,7 +603,7 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 data=json.dumps({"tenant_id": tenant_id}),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code == 200:
                 response_json = response.json()
@@ -708,7 +702,7 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # Data collections
@@ -1078,7 +1072,7 @@ class TrackMeHandlerSplkDsmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
