@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_elastic_sources.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_elastic_sources_admin",
     "trackme_rest_api_splk_elastic_sources_admin.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -57,9 +54,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkElasticSources_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkElasticSourcesAdmin_v2, self).__init__(
+        super(TrackMeHandlerSplkElasticSources_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -216,7 +213,7 @@ class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -479,7 +476,7 @@ class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -581,7 +578,7 @@ class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
         collection = service.kvstore[collection_name]
 
@@ -795,12 +792,8 @@ class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler)
                         "status": 500,
                     }
 
-                # Handle as a CSV list of keys, if not a list already
-                if not isinstance(elastic_entities_list, list):
-                    elastic_entities_list = [x.strip() for x in elastic_entities_list.split(",") if x.strip()]
-                else:
-                    # Filter out empty strings from existing list
-                    elastic_entities_list = [x.strip() if isinstance(x, str) else x for x in elastic_entities_list if (x.strip() if isinstance(x, str) else bool(x))]
+                # Handle as a CSV list of keys
+                elastic_entities_list = elastic_entities_list.split(",")
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -858,7 +851,7 @@ class TrackMeHandlerSplkElasticSourcesAdmin_v2(trackme_rest_handler.RESTHandler)
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=600,
+                timeout=300,
             )
 
             # set loglevel
