@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_fqm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -35,10 +35,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.splk_fqm_user", "trackme_rest_api_splk_fqm_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -60,9 +57,9 @@ from trackme_libs_decisionmaker import convert_epoch_to_datetime
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkFqmTracking_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkFqmTrackingRead_v2, self).__init__(
+        super(TrackMeHandlerSplkFqmTracking_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -123,7 +120,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -261,7 +258,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -344,7 +341,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -355,7 +352,6 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
 
         # Declare
         trackers_list = []
-        seen_tracker_ids = set()  # Track seen tracker_ids for deduplication
 
         try:
             # Data collection
@@ -364,13 +360,6 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
 
             for entity in collection.data.query():
                 tracker_id = entity.get("tracker_id")
-                
-                # Skip if we've already seen this tracker_id
-                if tracker_id in seen_tracker_ids:
-                    continue
-                
-                # Add tracker_id to seen set
-                seen_tracker_ids.add(tracker_id)
                 tracker_name = entity.get("tracker_name")
                 knowledge_objects = entity.get("knowledge_objects")
                 # try to load as a json
@@ -528,7 +517,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -738,7 +727,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -777,16 +766,6 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
                     else:
                         mtime = "N/A"
 
-                    # Get score, default to 100 if not present (for backward compatibility)
-                    score = kvrecord.get("score")
-                    if score is None:
-                        score = 100
-                    else:
-                        try:
-                            score = int(score)
-                        except (TypeError, ValueError):
-                            score = 100
-                    
                     return_records.append(
                         {
                             "_key": kvrecord.get("_key"),
@@ -797,7 +776,6 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
                             "condition_true": kvrecord.get("condition_true"),
                             "mtime": mtime,
                             "comment": kvrecord.get("comment"),
-                            "score": score,
                         }
                     )
             except:
@@ -979,7 +957,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1118,7 +1096,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1225,7 +1203,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1378,7 +1356,7 @@ class TrackMeHandlerSplkFqmTrackingRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
