@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_identity_cards.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -32,10 +32,7 @@ logger = setup_logger(
     "trackme.rest.splk_identity_cards_power",
     "trackme_rest_api_splk_identity_cards_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -48,9 +45,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkIdentityCardsWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkIdentityCards_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkIdentityCardsWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkIdentityCards_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -142,7 +139,7 @@ class TrackMeHandlerSplkIdentityCardsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -357,7 +354,7 @@ class TrackMeHandlerSplkIdentityCardsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -597,7 +594,7 @@ class TrackMeHandlerSplkIdentityCardsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
