@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_lagging_classes.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_lagging_classes_power",
     "trackme_rest_api_splk_lagging_classes_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -49,9 +46,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkLaggingClasses_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkLaggingClassesWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkLaggingClasses_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -196,7 +193,7 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -405,7 +402,7 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -549,18 +546,8 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
 
                 try:
                     keys_list = resp_dict["keys_list"]
-                    # Handle as a CSV list of keys, if not already a list
-                    if not isinstance(keys_list, list):
-                        keys_list = [x.strip() for x in keys_list.split(",") if x.strip()]
-                    else:
-                        # Filter out empty strings from existing list
-                        keys_list = [x.strip() if isinstance(x, str) else x for x in keys_list if (x.strip() if isinstance(x, str) else bool(x))]
-                    # if is empty, return an error
-                    if not keys_list or len(keys_list) == 0:
-                        return {
-                            "payload": "Error: keys_list is required",
-                            "status": 400,
-                        }
+                    # Handle as a CSV list of keys
+                    keys_list = keys_list.split(",")
                 except Exception as e:
                     return {
                         "payload": "Error: keys_list is required",
@@ -603,7 +590,7 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -884,7 +871,7 @@ class TrackMeHandlerSplkLaggingClassesWrite_v2(trackme_rest_handler.RESTHandler)
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
