@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_logical_groups.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_logical_groups_power",
     "trackme_rest_api_splk_logical_groups_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -49,9 +46,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkLogicalGroups_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkLogicalGroupsWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkLogicalGroups_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -131,7 +128,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -404,7 +401,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.session_key,
-                timeout=600,
+                timeout=300,
             )
             collection = service.kvstore[collection_name]
 
@@ -661,7 +658,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
         collection = service.kvstore[collection_name]
 
@@ -846,7 +843,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.session_key,
-                timeout=600,
+                timeout=300,
             )
             collection = service.kvstore[collection_name]
 
@@ -1115,7 +1112,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
         collection = service.kvstore[collection_name]
 
@@ -1286,7 +1283,7 @@ class TrackMeHandlerSplkLogicalGroupsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
         collection = service.kvstore[collection_name]
 
