@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_mhm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_mhm_user",
     "trackme_rest_api_splk_mhm_user.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -55,9 +52,9 @@ from trackme_libs_splk_feeds import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkMhmRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkMhm_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkMhmRead_v2, self).__init__(
+        super(TrackMeHandlerSplkMhm_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -153,7 +150,7 @@ class TrackMeHandlerSplkMhmRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -405,7 +402,7 @@ class TrackMeHandlerSplkMhmRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
