@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_priority_policies.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -34,10 +34,7 @@ logger = setup_logger(
     "trackme.rest.splk_priority_policies_power",
     "trackme_rest_api_splk_priority_policies_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -50,9 +47,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event, get_kv_collec
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkPriorityPolicies_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkPriorityPoliciesWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkPriorityPolicies_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -109,12 +106,13 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -206,11 +204,11 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             response = {
                 "describe": "This endpoint creates a new priority policy or updates a policy if it exists already, it requires a POST call with the following data:",
                 "resource_desc": "Add or update a priority policy",
-                "resource_spl_example": r"| trackme mode=post url=\"/services/trackme/v2/splk_priority_policies/write/priority_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'priority_policy_id': 'linux_secure', 'priority_policy_id': 'linux_secure', 'priority_policy_value': 'Linux,OS,CIM', 'priority_policy_regex': '\:linux_secure$'}\"",
+                "resource_spl_example": "| trackme mode=post url=\"/services/trackme/v2/splk_priority_policies/write/priority_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'priority_policy_id': 'linux_secure', 'priority_policy_id': 'linux_secure', 'priority_policy_value': 'Linux,OS,CIM', 'priority_policy_regex': '\:linux_secure$'}\"",
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "priority_policy_id": "(required) ID of the priority policy",
                         "priority_policy_regex": "(required) The regular expression to be used by the priority policy, special characters should be escaped.",
                         "priority_policy_value": "(required) priority value (low/medium/high/critical/pending) to be applied.",
@@ -241,7 +239,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -416,12 +414,13 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -461,7 +460,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "priority_policy_id_list": "(required) Comma separated list of priority policies",
                         "update_comment": "(optional) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -485,7 +484,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -727,12 +726,13 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -779,7 +779,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "records_list": "(required) JSON records to be updated",
                         "update_comment": "(option) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -803,7 +803,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1070,12 +1070,13 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -1158,7 +1159,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1338,12 +1339,13 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -1368,7 +1370,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                     }
                 ],
             }
@@ -1384,7 +1386,7 @@ class TrackMeHandlerSplkPriorityPoliciesWrite_v2(trackme_rest_handler.RESTHandle
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
