@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_replica_trackers_admin.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -36,10 +36,7 @@ logger = setup_logger(
     "trackme.rest.splk_replica_trackers_admin",
     "trackme_rest_api_splk_replica_trackers_admin.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -61,9 +58,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkReplicaTracker_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkReplicaTrackerAdmin_v2, self).__init__(
+        super(TrackMeHandlerSplkReplicaTracker_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -111,10 +108,10 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
 
                 # component
                 component = resp_dict["component"]
-                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "wlk"):
+                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "cim", "wlk"):
                     return {
                         "payload": {
-                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|fqm|wlk'
+                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|cim|fqm|wlk'
                         },
                         "status": 500,
                     }
@@ -160,7 +157,7 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
                     {
                         "tenant_id": "The tenant identifier",
                         "source_tenant_id": "The source tenant identifier",
-                        "component": "The component, valid options are: dsm | dhm | mhm | flx | fqm | wlk",
+                        "component": "The component, valid options are: dsm | dhm | mhm | flx | fqm | cim | wlk",
                         "root_constraint": "the tracker report root search constraint, to define search filters scoping the data set",
                         "owner": "Optional, the Splunk user owning the objects to be created, defaults to the owner set for the tenant",
                         "cron_schedule": "Optional, the cron schedule, defaults to every 5 minutes",
@@ -182,7 +179,7 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=600,
+                timeout=300,
             )
 
             # set loglevel
@@ -554,18 +551,14 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 replica_trackers_list = resp_dict["replica_trackers_list"]
-                # Handle as a CSV list of keys, it not already a list
-                if not isinstance(replica_trackers_list, list):
-                    replica_trackers_list = [x.strip() for x in replica_trackers_list.split(",") if x.strip()]
-                else:
-                    # Filter out empty strings from existing list
-                    replica_trackers_list = [x.strip() if isinstance(x, str) else x for x in replica_trackers_list if (x.strip() if isinstance(x, str) else bool(x))]
+                # Handle as a CSV list of keys
+                replica_trackers_list = replica_trackers_list.split(",")
                 # get component
                 component = resp_dict["component"]
-                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "wlk"):
+                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "cim", "wlk"):
                     return {
                         "payload": {
-                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|fqm|wlk'
+                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|cim|fqm|wlk'
                         },
                         "status": 500,
                     }
@@ -625,7 +618,7 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=600,
+                timeout=300,
             )
 
             # set loglevel
