@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_sla_policies.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -34,10 +34,7 @@ logger = setup_logger(
     "trackme.rest.splk_sla_policies_power",
     "trackme_rest_api_splk_sla_policies_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -55,9 +52,9 @@ from trackme_libs import (
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkSlaPolicies_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkSlaPoliciesWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkSlaPolicies_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -114,12 +111,13 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -209,11 +207,11 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint creates a new sla class policy or updates a policy if it exists already, it requires a POST call with the following data:",
                 "resource_desc": "Add or update a sla class policy",
-                "resource_spl_example": r"| trackme mode=post url=\"/services/trackme/v2/splk_sla_policies/write/sla_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'sla_policy_id': 'linux_secure', 'sla_policy_id': 'linux_secure', 'sla_policy_value': 'Linux,OS,CIM', 'sla_policy_regex': '\:linux_secure$'}\"",
+                "resource_spl_example": "| trackme mode=post url=\"/services/trackme/v2/splk_sla_policies/write/sla_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'sla_policy_id': 'linux_secure', 'sla_policy_id': 'linux_secure', 'sla_policy_value': 'Linux,OS,CIM', 'sla_policy_regex': '\:linux_secure$'}\"",
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "sla_policy_id": "(required) ID of the sla class policy",
                         "sla_policy_regex": "(required) The regular expression to be used by the sla class policy, special characters should be escaped.",
                         "sla_policy_value": "(required) SLA class to be applied.",
@@ -244,7 +242,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -462,12 +460,13 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -507,7 +506,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "sla_policy_id_list": "(required) Comma separated list of sla policies",
                         "update_comment": "(optional) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -531,7 +530,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -743,12 +742,13 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -795,7 +795,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                         "records_list": "(required) JSON records to be updated",
                         "update_comment": "(option) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -819,7 +819,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1112,12 +1112,13 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -1202,7 +1203,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1400,12 +1401,13 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         "mhm",
                         "wlk",
                         "flx",
+                        "cim",
                         "fqm",
                     ):
                         return {
                             "payload": {
                                 "action": "failure",
-                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/fqm",
+                                "response": f"invalid component {component}, valid options are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                             },
                             "status": 400,
                         }
@@ -1430,7 +1432,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/fqm",
+                        "component": "(required) The component identifier, valid values are: dsm/dhm/mhm/wlk/flx/cim/fqm",
                     }
                 ],
             }
@@ -1446,7 +1448,7 @@ class TrackMeHandlerSplkSlaPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
