@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_smart_status.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -31,10 +31,7 @@ logger = setup_logger(
     "trackme.rest.splk_smart_status",
     "trackme_rest_api_splk_smart_status.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # TrackMe REST handler
@@ -142,7 +139,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -165,7 +162,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
                 },
                 data=json.dumps({"tenant_id": tenant_id}),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -691,7 +688,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -714,7 +711,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
                 },
                 data=json.dumps({"tenant_id": tenant_id}),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -1077,7 +1074,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1145,6 +1142,191 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
 
         return {"payload": smartstatus_response, "status": 200}
 
+    # Get smart status for splk-cim
+    def post_cim_smart_status(self, request_info, **kwargs):
+        # define
+        tenant_id = None
+        object_value = None
+
+        # Retrieve from data
+        try:
+            resp_dict = json.loads(str(request_info.raw_args["payload"]))
+        except Exception as e:
+            resp_dict = None
+
+        if resp_dict is not None:
+            try:
+                describe = resp_dict["describe"]
+                if describe in ("true", "True"):
+                    describe = True
+            except Exception as e:
+                describe = False
+            if not describe:
+                tenant_id = resp_dict["tenant_id"]
+                object_value = resp_dict["object"]
+
+        else:
+            # body is required in this endpoint, if not submitted describe the usage
+            describe = True
+
+        if describe:
+            response = {
+                "describe": "This endpoints runs the smart status for a given data source, it requires a POST call with the following options:",
+                "resource_desc": "Run Smart Status for a given entity",
+                "resource_spl_example": "| trackme mode=\"post\" url=\"/services/trackme/v2/splk_smart_status/cim_smart_status\" body=\"{'tenant_id': 'mytenant', 'object': 'auth001'}\"",
+                "options": [
+                    {
+                        "tenant_id": "the tenant identifier",
+                        "object": "name of the data source",
+                    }
+                ],
+            }
+
+            return {"payload": response, "status": 200}
+
+        # Define the KV query
+        query_string = {
+            "object": object_value,
+        }
+
+        # Get splunkd port
+        splunkd_port = request_info.server_rest_port
+
+        # Get service
+        service = client.connect(
+            owner="nobody",
+            app="trackme",
+            port=splunkd_port,
+            token=request_info.session_key,
+            timeout=300,
+        )
+
+        # set loglevel
+        loglevel = trackme_getloglevel(
+            request_info.system_authtoken, request_info.server_rest_port
+        )
+        logger.setLevel(loglevel)
+
+        # Get the object record
+        try:
+            collection_name = "kv_" + "trackme_cim_tenant_" + str(tenant_id)
+            collection = service.kvstore[collection_name]
+
+            records = collection.data.query(query=json.dumps(query_string))
+            record = records[0]
+            key = record.get("_key")
+
+        except Exception as e:
+            response = {
+                "action": "failure",
+                "response": f'object="{object_value}" not found',
+            }
+            logger.error(json.dumps(response))
+            return {"payload": response, "status": 404}
+
+        #
+        # object is known, proceed
+        #
+
+        # set the initial empty smartstatus_response
+        smartstatus_response = {}
+
+        # get anomaly_reason
+        anomaly_reason = record.get("anomaly_reason")
+
+        # turn into list from pipe delimited string if not already a list
+        if not isinstance(anomaly_reason, list):
+            anomaly_reason = anomaly_reason.split("|")
+
+        # retrieve flipping correlation
+        try:
+            flipping_correlation = smartstatus_flipping_correlation(
+                request_info, tenant_id, "splk-dsm", object_value
+            )
+        except Exception as e:
+            response = {
+                "action": "failure",
+                "response": f'an exception was encountered with smartstatus_flipping_correlation, exception="{str(e)}"',
+            }
+            logger.error(json.dumps(response))
+            return {"payload": response, "status": 500}
+
+        #################################
+        # Greem: happiness is in da house
+        #################################
+
+        # if anomaly_reason (which is a list) only contains "none", then there are no anomalies
+        if anomaly_reason == ["none"]:
+            smartstatus_response["_time"] = time.time()
+            smartstatus_response["tenant_id"] = tenant_id
+            smartstatus_response["object_category"] = "splk-cim"
+            smartstatus_response["object"] = object_value
+            smartstatus_response["alias"] = record.get("alias")
+            smartstatus_response["object_state"] = record.get("object_state")
+            smartstatus_response["anomaly_reason"] = anomaly_reason
+            smartstatus_response["flipping_correlations"] = flipping_correlation
+            smartstatus_response["smart_result"] = (
+                "The entity is currently in a normal state, therefore further investigations are not required at this stage."
+            )
+
+            return {"payload": smartstatus_response, "status": 200}
+
+        ##############################################################
+        # use case investigations: Machine Learning Outliers Detection
+        ##############################################################
+
+        if "ml_outliers_detection" in anomaly_reason:
+            logger.info(
+                f'performing investigations use case: Machine Learning Outliers, tenant_id="{tenant_id}", object="{object_value}"'
+            )
+            use_case_desc = "The use case investigates ML Outliers for this object by executing the ML monitor process for enabled models"
+
+            try:
+                uc_results = smartstatus_investigations_uc_ml_outliers(
+                    request_info, record, "cim"
+                )
+                # append to response
+                use_case_desc = (
+                    "The use case investigates ML Outliers detection for the entity"
+                )
+                search1_results_label = "results_ml_outliers"
+                search1_info_label = "search_info_ml_outliers"
+
+                smartstatus_response["smartstatus_investigations_uc_ml_outliers"] = {
+                    "action": "success",
+                    "use_case_desc": use_case_desc,
+                    search1_results_label: uc_results.get("results_1"),
+                    search1_info_label: uc_results.get("search_info_1"),
+                    "smart_function": "smartstatus_investigations_uc_ml_outliers",
+                }
+
+            except Exception as e:
+                logger.error(
+                    f'smartstatus, tenant_id="{tenant_id}", object="{object_value}", exception encountered while running uc function smartstatus_investigations_uc_ml_outliers, exception="{str(e)}"'
+                )
+                smartstatus_response["smartstatus_investigations_uc_ml_outliers"] = {
+                    "action": "failure",
+                    "use_case_desc": use_case_desc,
+                    "response": "an exception was encountered while attempting to run the use case investigation, review REST Api logs: index=_internal sourcetype=trackme:rest_api smartstatus_investigations_uc_ml_outliers CASE(ERROR)",
+                    "smart_function": "smartstatus_investigations_uc_ml_outliers",
+                    "exception": str(e),
+                }
+
+        ##########
+        # response
+        ##########
+
+        smartstatus_response["_time"] = time.time()
+        smartstatus_response["tenant_id"] = tenant_id
+        smartstatus_response["object_category"] = "splk-cim"
+        smartstatus_response["object"] = object_value
+        smartstatus_response["alias"] = record.get("alias")
+        smartstatus_response["object_state"] = record.get("object_state")
+        smartstatus_response["anomaly_reason"] = anomaly_reason
+        smartstatus_response["flipping_correlations"] = flipping_correlation
+
+        return {"payload": smartstatus_response, "status": 200}
+
     # Get smart status for splk-flx
     def post_flx_smart_status(self, request_info, **kwargs):
         # define
@@ -1201,7 +1383,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1386,7 +1568,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1571,7 +1753,7 @@ class TrackMeHandlerSplkSmartStatus_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
