@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_soar_admin.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -35,10 +35,7 @@ logger = setup_logger(
     "trackme.rest.splk_soar_admin",
     "trackme_rest_api_splk_soar_admin.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -65,9 +62,9 @@ def handle_comma_separated_values(values):
     return [value.strip() for value in values.split(",")]
 
 
-class TrackMeHandlerSplkSoarAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkSoar_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkSoarAdmin_v2, self).__init__(
+        super(TrackMeHandlerSplkSoar_v2, self).__init__(
             command_line, command_arg, logger
         )
 
