@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_soar_user.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -32,10 +32,7 @@ logger = setup_logger(
     "trackme.rest.splk_soar_user",
     "trackme_rest_api_splk_soar_user.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -61,9 +58,9 @@ sys.path.append(
 from trackme_soar import SOARClient
 
 
-class TrackMeHandlerSplkSoarRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkSoar_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkSoarRead_v2, self).__init__(
+        super(TrackMeHandlerSplkSoar_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -120,7 +117,7 @@ class TrackMeHandlerSplkSoarRead_v2(trackme_rest_handler.RESTHandler):
             app="splunk_app_soar",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
