@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_tag_policies.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -34,10 +34,7 @@ logger = setup_logger(
     "trackme.rest.splk_tag_policies_power",
     "trackme_rest_api_splk_tag_policies_power.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -50,9 +47,9 @@ from trackme_libs import trackme_getloglevel, trackme_audit_event, get_kv_collec
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkTagPolicies_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkTagPoliciesWrite_v2, self).__init__(
+        super(TrackMeHandlerSplkTagPolicies_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -111,11 +108,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 400,
                     }
-                # value must be either: dsm,dhm,mhm,wlk,flx,fqm
-                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "fqm"):
+                # value must be either: dsm,dhm,mhm,wlk,flx,cim,fqm
+                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "cim", "fqm"):
                     return {
                         "payload": {
-                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                             "status": 400,
                         },
                         "status": 400,
@@ -181,11 +178,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint creates a new tag policy or updates a policy if it exists already, it requires a POST call with the following data:",
                 "resource_desc": "Add or update a tag policy",
-                "resource_spl_example": r"| trackme mode=post url=\"/services/trackme/v2/splk_tag_policies/write/tag_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'tags_policy_id': 'linux_secure', 'tags_policy_id': 'linux_secure', 'tags_policy_value': 'Linux,OS,CIM', 'tags_policy_regex': '\:linux_secure$'}\"",
+                "resource_spl_example": "| trackme mode=post url=\"/services/trackme/v2/splk_tag_policies/write/tag_policies_add\" body=\"{'tenant_id': 'mytenant', 'component': 'dsm', 'tags_policy_id': 'linux_secure', 'tags_policy_id': 'linux_secure', 'tags_policy_value': 'Linux,OS,CIM', 'tags_policy_regex': '\:linux_secure$'}\"",
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                         "tags_policy_id": "(required) ID of the tag policy",
                         "tags_policy_regex": "(required) The regular expression to be used by the tags policy, special characters should be escaped.",
                         "tags_policy_value": "(required) A comma separated list of tags",
@@ -216,7 +213,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -393,11 +390,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 400,
                     }
-                # value must be either: dsm,dhm,mhm,wlk,flx,fqm
-                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "fqm"):
+                # value must be either: dsm,dhm,mhm,wlk,flx,cim,fqm
+                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "cim", "fqm"):
                     return {
                         "payload": {
-                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                             "status": 400,
                         },
                         "status": 400,
@@ -430,7 +427,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                         "tags_policy_id_list": "(required) Comma separated list of tag policies",
                         "update_comment": "(optional) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -454,7 +451,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -668,11 +665,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 400,
                     }
-                # value must be either: dsm,dhm,mhm,wlk,flx,fqm
-                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "fqm"):
+                # value must be either: dsm,dhm,mhm,wlk,flx,cim,fqm
+                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "cim", "fqm"):
                     return {
                         "payload": {
-                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                             "status": 400,
                         },
                         "status": 400,
@@ -712,7 +709,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                         "records_list": "(required) JSON records to be updated",
                         "update_comment": "(option) Comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
@@ -736,7 +733,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -984,11 +981,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 400,
                     }
-                # value must be either: dsm,dhm,mhm,wlk,flx,fqm
-                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "fqm"):
+                # value must be either: dsm,dhm,mhm,wlk,flx,cim,fqm
+                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "cim", "fqm"):
                     return {
                         "payload": {
-                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                             "status": 400,
                         },
                         "status": 400,
@@ -1031,7 +1028,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                         "regex_value": "(required) The regex to be used for the simulation",
                         "tags_list": "(required) A comma separated list of tags",
                     }
@@ -1049,7 +1046,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -1242,11 +1239,11 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 400,
                     }
-                # value must be either: dsm,dhm,mhm,wlk,flx,fqm
-                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "fqm"):
+                # value must be either: dsm,dhm,mhm,wlk,flx,cim,fqm
+                if component not in ("dsm", "dhm", "mhm", "wlk", "flx", "cim", "fqm"):
                     return {
                         "payload": {
-                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                            "response": "The component must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                             "status": 400,
                         },
                         "status": 400,
@@ -1264,7 +1261,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "(required) The tenant identifier",
-                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,fqm",
+                        "component": "(required) The component identifier, must be either: dsm,dhm,mhm,wlk,flx,cim,fqm",
                     }
                 ],
             }
@@ -1280,7 +1277,7 @@ class TrackMeHandlerSplkTagPoliciesWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
