@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dsm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -35,10 +35,7 @@ logger = setup_logger(
     "trackme.rest.splk_wlk_admin",
     "trackme_rest_api_splk_wlk_admin.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -53,7 +50,6 @@ from trackme_libs import (
     trackme_reqinfo,
     trackme_send_to_tcm,
     run_splunk_search,
-    trackme_verify_report_available,
 )
 
 # import trackme libs utils
@@ -66,9 +62,9 @@ from trackme_libs_licensing import trackme_check_license
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkWlkAdmin_v2, self).__init__(
+        super(TrackMeHandlerSplkWlk_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -220,7 +216,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                     (index=_internal sourcetype=scheduler)
                     | eval alert_actions=if((isnull(alert_actions) OR (alert_actions == "")), "none", alert_actions)
                     ``` in some error cases, we need to manage extractions and status ```
-                    | rex field=savedsearch_id "^(?<user>[^\\;]*)\\;(?<app>[^\\;]*)\\;(?<savedsearch_name>.*)"
+                    | rex field=savedsearch_id "^(?<user>[^\;]*)\;(?<app>[^\;]*)\;(?<savedsearch_name>.*)"
                     | eval user=coalesce(user, user_alt), app=coalesce(app, app_alt), savedsearch_name=coalesce(savedsearch_name, savedsearch_name_alt)
                     | search {root_constraint}
                     | eval errmsg=case(len(errmsg)>0, errmsg, match(log_level, "(?i)error") AND len(message)>0, message)                    
@@ -238,7 +234,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
 
             elif tracker_type == "splunkcloud_svc":
                 tracker_search = f"""\
-                    ((index=_cmc_summary OR index=summary) source="splunk-svc-search-attribution") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint}
+                    ((index=_cmc_summary OR index=summary) source="splunk-svc-consumer") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint}
                     | fields _time svc_usage svc_consumer svc_consumption_score search_type search_app search_label search_user search_head_names unified_sid process_type
                     | fillnull value="" svc_consumer process_type search_provenances search_type search_app search_label search_user unified_sid search_modes labels search_head_names usage_source
                     | stats max(svc_usage) as svc_usage by _time svc_consumer search_type search_app search_label search_user search_head_names unified_sid process_type
@@ -258,7 +254,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                     | splunkremotesearch account="{account}" search="{tracker_search}" earliest="{earliest_time}" latest="{latest_time}"
                     tenant_id="{tenant_id}" register_component="False" component="splk-wlk" report="trackme_wlk_hybrid_{tracker_name}_wrapper_tenant_{tenant_id}"
                     """
-            logger.info("tracker_search={}" + tracker_search)
+            logger.info("tracker_search=\{}" + tracker_search)
 
             # finish the search
             if tracker_type == "introspection":
@@ -486,7 +482,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=600,
+                timeout=300,
             )
 
             # set loglevel
@@ -727,7 +723,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                     | eval orig_time=_time | bucket _time span=5m
                     | eval alert_actions=if((isnull(alert_actions) OR (alert_actions == "")), "none", alert_actions)
                     ``` in some error cases, we need to manage extractions and status ```
-                    | rex field=savedsearch_id "^(?<user_alt>[^\\;]*)\\;(?<app_alt>[^\\;]*)\\;(?<savedsearch_name_alt>.*)"
+                    | rex field=savedsearch_id "^(?<user_alt>[^\;]*)\;(?<app_alt>[^\;]*)\;(?<savedsearch_name_alt>.*)"
                     | eval user=coalesce(user, user_alt), app=coalesce(app, app_alt), savedsearch_name=coalesce(savedsearch_name, savedsearch_name_alt)
                     | search {root_constraint}
                     | eval errmsg=case(len(errmsg)>0, errmsg, match(log_level, "(?i)error") AND len(message)>0, message)
@@ -745,7 +741,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
 
             elif tracker_type == "splunkcloud_svc":
                 tracker_search = f"""\
-                    ((index=_cmc_summary OR index=summary) source="splunk-svc-search-attribution") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint} _index_earliest="{index_earliest_time}" _index_latest="{index_latest_time}"
+                    ((index=_cmc_summary OR index=summary) source="splunk-svc-consumer") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* {root_constraint} _index_earliest="{index_earliest_time}" _index_latest="{index_latest_time}"
                     | fields _time svc_usage svc_consumer svc_consumption_score search_type search_app search_label search_user search_head_names unified_sid process_type
                     | fillnull value="" svc_consumer process_type search_provenances search_type search_app search_label search_user unified_sid search_modes labels search_head_names usage_source
                     | stats max(svc_usage) as svc_usage by _time svc_consumer search_type search_app search_label search_user search_head_names unified_sid process_type
@@ -944,44 +940,8 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                     logger.error(json.dumps(burn_test_results_record, indent=2))
                     return {"payload": burn_test_results_record, "status": 200}
 
-                # Verify the report is available before executing
-                # In large SHC environments, knowledge objects may take time to propagate
-                logger.info(
-                    f'tenant_id="{tenant_id}", burn test report created, verifying availability before execution, report_name="{burn_test_report}"'
-                )
-                
-                report_available = trackme_verify_report_available(
-                    request_info.system_authtoken,
-                    request_info.server_rest_uri,
-                    tenant_id,
-                    burn_test_report,
-                    max_attempts=12,
-                    sleep_time=5,
-                )
-                
-                if not report_available:
-                    # return failure if report is not available after verification attempts
-                    burn_test_results_record = {
-                        "tenant_id": tenant_id,
-                        "report": burn_test_report,
-                        "burn_test_success": False,
-                        "message": "burn test report was created but is not yet available for execution after verification attempts, this may indicate a propagation delay in large SHC environments",
-                        "exception": f'report verification failed, report_name="{burn_test_report}"',
-                    }
-                    
-                    # attempt to remove the report
-                    try:
-                        service.saved_searches.delete(str(burn_test_report))
-                        logger.info(
-                            f'tenant_id="{tenant_id}", burn test, report="{burn_test_report}", action="success", the report was successfully removed after verification failure.'
-                        )
-                    except Exception as e:
-                        logger.error(
-                            f'tenant_id="{tenant_id}", burn test, report="{burn_test_report}", failed to remove the report after verification failure, exception="{str(e)}"'
-                        )
-                    
-                    logger.error(json.dumps(burn_test_results_record, indent=2))
-                    return {"payload": burn_test_results_record, "status": 200}
+                # sleep
+                time.sleep(5)
 
                 logger.info(
                     f'tenant_id="{tenant_id}", burn test was requested, starting abstract report burn test now'
@@ -1367,12 +1327,8 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 hybrid_trackers_list = resp_dict["hybrid_trackers_list"]
-                # Handle as a CSV list of keys, it not already a list
-                if not isinstance(hybrid_trackers_list, list):
-                    hybrid_trackers_list = [x.strip() for x in hybrid_trackers_list.split(",") if x.strip()]
-                else:
-                    # Filter out empty strings from existing list
-                    hybrid_trackers_list = [x.strip() if isinstance(x, str) else x for x in hybrid_trackers_list if (x.strip() if isinstance(x, str) else bool(x))]
+                # Handle as a CSV list of keys
+                hybrid_trackers_list = hybrid_trackers_list.split(",")
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -1428,7 +1384,7 @@ class TrackMeHandlerSplkWlkAdmin_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.system_authtoken,
-                timeout=600,
+                timeout=300,
             )
 
             # set loglevel
