@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_wlk_user.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -33,10 +33,7 @@ logger = setup_logger(
     "trackme.rest.splk_wlk_user",
     "trackme_rest_api_splk_wlk_user.log",
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -52,9 +49,9 @@ from trackme_libs_splk_wlk import splk_wlk_return_searches
 import splunklib.client as client
 
 
-class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerSplkWlk_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerSplkWlkRead_v2, self).__init__(
+        super(TrackMeHandlerSplkWlk_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -175,7 +172,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -255,7 +252,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -266,7 +263,6 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
 
         # Declare
         trackers_list = []
-        seen_tracker_names = set()  # Track seen tracker_names for deduplication
 
         try:
             # Data collection
@@ -275,13 +271,6 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
 
             for entity in collection.data.query():
                 tracker_name = entity.get("tracker_name")
-                
-                # Skip if we've already seen this tracker_name
-                if tracker_name in seen_tracker_names:
-                    continue
-                
-                # Add tracker_name to seen set
-                seen_tracker_names.add(tracker_name)
                 knowledge_objects = entity.get("knowledge_objects")
                 # try to load as a json
                 try:
@@ -436,7 +425,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -556,7 +545,6 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
     def post_wlk_entity_metadata(self, request_info, **kwargs):
         # init
         object_value = None
-        object_id = None
         query_string = None
 
         describe = False
@@ -576,32 +564,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
                 describe = False
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
-                    object_value = None
-                try:
-                    object_id = resp_dict["object_id"]
-                except Exception as e:
-                    object_id = None
-                
-                # object or object_id must be provided, but not both
-                if object_value and object_id:
-                    return {
-                        "payload": {
-                            "action": "failure",
-                            "response": "only object or object_id can be specified, not both",
-                        },
-                        "status": 500,
-                    }
-                if not object_value and not object_id:
-                    return {
-                        "payload": {
-                            "action": "failure",
-                            "response": "either object or object_id must be specified",
-                        },
-                        "status": 500,
-                    }
+                object_value = resp_dict["object"]
 
         else:
             # body is required in this endpoint, if not submitted describe the usage
@@ -615,8 +578,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
                 "options": [
                     {
                         "tenant_id": "Tenant identifier",
-                        "object": "The entity identifier, you can specify the object or the object_id, but not both",
-                        "object_id": "The entity key identifier (_key in KVstore), you can specify the object or the object_id, but not both",
+                        "object": "The entity identifier",
                     }
                 ],
             }
@@ -632,7 +594,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
@@ -646,11 +608,9 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
         collection = service.kvstore[collection_name]
 
         # Define the KV query
-        query_string = {}
-        if object_value:
-            query_string["object"] = object_value
-        elif object_id:
-            query_string["_key"] = object_id
+        query_string = {
+            "object": object_value,
+        }
 
         # Get the current record
         # Notes: the record is returned as an array, as we search for a specific record, we expect one record only
@@ -658,10 +618,6 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
         try:
             kvrecord = collection.data.query(query=json.dumps(query_string))[0]
             key = kvrecord.get("_key")
-            
-            # If we searched by object_id, get the object value for error messages
-            if not object_value:
-                object_value = kvrecord.get("object")
 
             # get the dict
             json_dict = json.loads(kvrecord.get("version_dict"))
@@ -678,10 +634,9 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
 
         except Exception as e:
             key = None
-            identifier = object_id if object_id else object_value
             return {
                 "payload": {
-                    "response": f'The entity with identifier="{identifier}" was not found, this might be expected in some cases (acceleration searches, etc)',
+                    "response": f'The entity with identifier="{object_value}" was not found, this might be expected in some cases (acceleration searches, etc)',
                 },
                 "status": 404,
             }
@@ -755,7 +710,7 @@ class TrackMeHandlerSplkWlkRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
