@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_vtenant.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -30,10 +30,7 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.vtenants_power", "trackme_rest_api_vtenants_power.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
@@ -46,9 +43,9 @@ from trackme_libs import trackme_getloglevel, run_splunk_search
 import splunklib.client as client
 
 
-class TrackMeHandlerVtenantsWrite_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerVtenants_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerVtenantsWrite_v2, self).__init__(
+        super(TrackMeHandlerVtenants_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -133,7 +130,7 @@ class TrackMeHandlerVtenantsWrite_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # set loglevel
