@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_vtenant.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -31,17 +31,14 @@ from trackme_libs_logging import setup_logger
 logger = setup_logger(
     "trackme.rest.vtenants_user", "trackme_rest_api_vtenants_user.log"
 )
-# Redirect global logging to use the same handler
-import logging
-logging.getLogger().handlers = logger.handlers
-logging.getLogger().setLevel(logger.level)
+# Redirect logger.module calls
 
 
 # import rest handler
 import trackme_rest_handler
 
 # import trackme libs
-from trackme_libs import trackme_getloglevel, trackme_reqinfo, trackme_vtenant_account, trackme_get_version
+from trackme_libs import trackme_getloglevel, trackme_reqinfo, trackme_vtenant_account
 
 # import trackme load libs
 from trackme_libs_load import trackmeload
@@ -52,17 +49,14 @@ from trackme_libs_schema import trackme_schema_format_version
 # import trackme decision maker
 from trackme_libs_decisionmaker import convert_epoch_to_datetime
 
-# import the collections dict
-from collections_data import vtenant_account_default
-
 # import Splunk SDK client
 import splunklib.client as client
 import splunklib.results as results
 
 
-class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
+class TrackMeHandlerVtenants_v2(trackme_rest_handler.RESTHandler):
     def __init__(self, command_line, command_arg):
-        super(TrackMeHandlerVtenantsRead_v2, self).__init__(
+        super(TrackMeHandlerVtenants_v2, self).__init__(
             command_line, command_arg, logger
         )
 
@@ -127,12 +121,19 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.session_key,
-                timeout=600,
+                timeout=300,
             )
             collection = service.kvstore[collection_name]
 
             # TrackMe version
-            trackme_version = trackme_get_version(service)
+            trackme_version = None
+            app_confs = service.confs["app"]
+
+            for stanza in app_confs:
+                if stanza.name == "id":
+                    for stanzakey, stanzavalue in stanza.content.items():
+                        if stanzakey == "version":
+                            trackme_version = stanzavalue
 
             # Get schema_version_required
             schema_version_required = trackme_schema_format_version(trackme_version)
@@ -145,22 +146,10 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 record["schema_version_required"] = schema_version_required
                 # Set the status of tenant_updated_status, if schema_version in the record is equal to schema_version_required,
                 # the status is "updated", otherwise it is "pending"
-                # If schema_version_required is 0 (version retrieval failed), treat all tenants as "updated"
-                # to align with graceful degradation when DB Connect causes permission issues
-                if schema_version_required == 0:
+                if int(record.get("schema_version")) == schema_version_required:
                     record["tenant_updated_status"] = "updated"
                 else:
-                    # Handle case where schema_version is missing from the record (e.g., tenant created when version retrieval failed)
-                    schema_version = record.get("schema_version")
-                    if schema_version is None:
-                        # If schema_version is missing, use "undetermined" to indicate we cannot determine the status
-                        # This is different from "pending" which implies an upgrade is in progress
-                        # "undetermined" should not block underlying logic like hybrid trackers
-                        record["tenant_updated_status"] = "undetermined"
-                    elif int(schema_version) == schema_version_required:
-                        record["tenant_updated_status"] = "updated"
-                    else:
-                        record["tenant_updated_status"] = "pending"
+                    record["tenant_updated_status"] = "pending"
 
                 schema_version_mtime = record.get("schema_version_mtime")
                 if schema_version_mtime:
@@ -241,7 +230,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.system_authtoken,
-            timeout=600,
+            timeout=300,
         )
 
         # Define an header for requests authenticated communications with splunkd
@@ -250,12 +239,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             "Content-Type": "application/json",
         }
 
-        # TrackMe reqinfo
-        reqinfo = trackme_reqinfo(
-            request_info.system_authtoken, request_info.server_rest_uri
-        )
-        trackmeconf = reqinfo["trackme_conf"]
-
         # get current user
         username = request_info.user
 
@@ -354,7 +337,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 record_url,
                 headers=header,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code == 200:
                 user_level = response.json().get("user_level")
@@ -373,14 +356,38 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         for key in user_theme_prefs:
             final_response[key] = user_theme_prefs.get(key)
 
+        # theme & user prefs
+        record_url = "%s/services/trackme/v2/configuration/vtenants_user_prefs" % (
+            request_info.server_rest_uri
+        )
+
+        # position
+        position_prefs = None
+        try:
+            response = requests.post(
+                record_url,
+                headers=header,
+                data=json.dumps({"target_user": username, "target_prefs": "position"}),
+                verify=False,
+                timeout=300,
+            )
+            if response.status_code == 200:
+                position_prefs = response.text
+                final_response["position_prefs"] = position_prefs
+        except Exception as e:
+            return {
+                "payload": {
+                    "response": f"An exception was encountered while retrieving the position preferences, exception={str(e)}",
+                    "exception": str(e),
+                },
+                "status": 500,
+            }
+
         # log perf only in debug
         logger.debug(
             f"function post_trackmeload has terminated, run_time={round(time.time() - start, 3)}"
         )
 
-        # add trackmeconf to the response
-        final_response["trackmeconf"] = trackmeconf
-
         # Return
         return {
             "payload": final_response,
@@ -444,7 +451,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # Define an header for requests authenticated communications with splunkd
@@ -453,12 +460,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             "Content-Type": "application/json",
         }
 
-        # TrackMe reqinfo
-        reqinfo = trackme_reqinfo(
-            request_info.system_authtoken, request_info.server_rest_uri
-        )
-        trackmeconf = reqinfo["trackme_conf"]
-
         # get current user
         username = request_info.user
 
@@ -521,7 +522,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 record_url,
                 headers=header,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code == 200:
                 user_level = response.json().get("user_level")
@@ -540,6 +541,33 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         for key in user_theme_prefs:
             final_response[key] = user_theme_prefs.get(key)
 
+        # theme & user prefs
+        record_url = "%s/services/trackme/v2/configuration/vtenants_user_prefs" % (
+            request_info.server_rest_uri
+        )
+
+        # position
+        position_prefs = None
+        try:
+            response = requests.post(
+                record_url,
+                headers=header,
+                data=json.dumps({"target_user": username, "target_prefs": "position"}),
+                verify=False,
+                timeout=300,
+            )
+            if response.status_code == 200:
+                position_prefs = response.text
+                final_response["position_prefs"] = position_prefs
+        except Exception as e:
+            return {
+                "payload": {
+                    "response": "An exception was encountered",
+                    "exception": str(e),
+                },
+                "status": 500,
+            }
+
         # active count
         trackmeload_response_tenants = final_response["tenants_json"].get("tenants", {})
 
@@ -572,9 +600,6 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         # update the final response
         final_response["tenants_json"] = {"tenants": virtual_tenants_list}
 
-        # add trackmeconf to the response
-        final_response["trackmeconf"] = trackmeconf
-
         # log perf only in debug
         logger.debug(
             f"function post_trackmeload_legacy has terminated, run_time={round(time.time() - start, 3)}"
@@ -657,7 +682,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.session_key,
-                timeout=600,
+                timeout=300,
             )
             collection = service.kvstore[collection_name]
 
@@ -795,7 +820,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 app="trackme",
                 port=splunkd_port,
                 token=request_info.session_key,
-                timeout=600,
+                timeout=300,
             )
             collection = service.kvstore[collection_name]
 
@@ -960,7 +985,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             app="trackme",
             port=splunkd_port,
             token=request_info.session_key,
-            timeout=600,
+            timeout=300,
         )
 
         # conf
@@ -1005,11 +1030,11 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
 
                     # outliers_allowlist
                     outliers_allowlist = trackme_vtenant_conf[stanza.name].get(
-                        "mloutliers_allowlist", "dsm,dhm,flx,wlk,fqm"
+                        "mloutliers_allowlist", "dsm,dhm,flx,wlk,cim,fqm"
                     )
 
                     # Define the components
-                    outliers_components = ["dsm", "dhm", "flx", "wlk", "fqm"]
+                    outliers_components = ["dsm", "dhm", "flx", "wlk", "cim", "fqm"]
 
                     # Convert the allowlist to a set for faster lookups
                     mloutliers_set = set(outliers_allowlist.split(","))
@@ -1038,6 +1063,9 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                     trackme_vtenant_conf[stanza.name]["mloutliers_wlk"] = (
                         mloutliers_dict["mloutliers_wlk"]
                     )
+                    trackme_vtenant_conf[stanza.name]["mloutliers_cim"] = (
+                        mloutliers_dict["mloutliers_cim"]
+                    )
 
             # response
             try:
@@ -1052,116 +1080,3 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
 
         else:
             return {"payload": trackme_vtenant_conf, "status": 200}
-
-    #
-    # Get tenant score configuration
-    #
-
-    def get_tenant_score_config(self, request_info, **kwargs):
-        """
-        | trackme url=/services/trackme/v2/vtenants/tenant_score_config mode=get params="{'tenant_id': 'mytenant'}"
-        """
-
-        # Declare main variables
-        tenant_id = None
-        describe = False
-
-        # Retrieve from query parameters
-        try:
-            params_dict = request_info.raw_args["query_parameters"]
-        except Exception as e:
-            params_dict = None
-
-        if params_dict is not None:
-            try:
-                tenant_id = params_dict.get("tenant_id")
-            except Exception as e:
-                tenant_id = None
-
-            # Check if describe is requested
-            try:
-                describe_param = params_dict.get("describe")
-                if describe_param in ("true", "True"):
-                    describe = True
-            except Exception as e:
-                describe = False
-        else:
-            describe = True
-
-        if describe or tenant_id is None:
-            response = {
-                "describe": "This endpoint retrieves the impact score configuration for a virtual tenant, it requires a GET call with the following query parameters:",
-                "resource_desc": "Get virtual tenant impact score configuration",
-                "resource_spl_example": "| trackme url=/services/trackme/v2/vtenants/tenant_score_config mode=get params=\"{'tenant_id': 'mytenant'}\"",
-                "options": [
-                    {
-                        "tenant_id": "The tenant identifier",
-                        "describe": "OPTIONAL: set to true to get endpoint description",
-                    }
-                ],
-            }
-
-            return {"payload": response, "status": 200}
-
-        # Get splunkd port
-        splunkd_port = request_info.server_rest_port
-
-        # set loglevel
-        loglevel = trackme_getloglevel(
-            request_info.system_authtoken, request_info.server_rest_port
-        )
-        logger.setLevel(loglevel)
-
-        # Get vtenant account configuration via REST call
-        url = f"{request_info.server_rest_uri}/servicesNS/nobody/trackme/trackme_vtenants/{tenant_id}"
-        vtenant_data = {}
-        vtenant_account_found = False
-
-        try:
-            # Get current vtenant account configuration
-            response = requests.get(
-                url,
-                headers={"Authorization": f"Splunk {request_info.system_authtoken}"},
-                verify=False,
-                params={"output_mode": "json"},
-                timeout=600,
-            )
-            if response.status_code in (200, 201, 204):
-                logger.info(f"successfully retrieved vtenant configuration")
-                vtenant_data_json = response.json()
-                vtenant_data_current = vtenant_data_json["entry"][0]["content"]
-                vtenant_account_found = True
-                vtenant_data = dict(vtenant_data_current)
-            else:
-                error_msg = f"failed to retrieve vtenant configuration, status_code={response.status_code}"
-                logger.error(error_msg)
-
-        except Exception as e:
-            error_msg = f"failed to retrieve vtenant configuration, exception={str(e)}"
-            logger.error(error_msg)
-
-        if not vtenant_account_found:
-            error_msg = f'tenant_id="{tenant_id}" cannot be found'
-            logger.error(error_msg)
-            return {
-                "payload": {
-                    "response": error_msg,
-                },
-                "status": 404,
-            }
-
-        # Extract all impact_score_* fields from the tenant account configuration
-        # If a field is not present, use the default from vtenant_account_default
-        score_config = {}
-        for field_name in vtenant_account_default.keys():
-            if field_name.startswith("impact_score_"):
-                score_config[field_name] = vtenant_data.get(
-                    field_name, vtenant_account_default[field_name]
-                )
-
-        response = {
-            "tenant_id": tenant_id,
-            "score_config": score_config,
-        }
-
-        return {"payload": response, "status": 200}
