@@ -15,15 +15,6 @@ util.remove_http_proxy_env_vars()
 
 
 fields_trackme_general = [
-    field.RestField(
-        'max_multi_thread_workers',
-        required=True,
-        encrypted=False,
-        default='16',
-        validator=validator.Pattern(
-            regex=r"""^[1-9][0-9]*$""", 
-        )
-    ), 
     field.RestField(
         'pagination_mode',
         required=True,
@@ -114,6 +105,15 @@ fields_trackme_general = [
             regex=r"""^[a-zA-Z0-9_\-,]+$""", 
         )
     ), 
+    field.RestField(
+        'allow_admin_operations',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(1|0)$""", 
+        )
+    ), 
     field.RestField(
         'enable_conf_manager_receiver',
         required=True,
@@ -132,15 +132,6 @@ fields_trackme_general = [
             regex=r"""^[0-9]*$""", 
         )
     ), 
-    field.RestField(
-        'trackme_stateful_charts_records_expiration_days',
-        required=True,
-        encrypted=False,
-        default='2',
-        validator=validator.Pattern(
-            regex=r"""^[0-9]*$""", 
-        )
-    ), 
     field.RestField(
         'trackme_ack_duration_default',
         required=True,
@@ -280,18 +271,36 @@ fields_index_settings = [
 model_index_settings = RestModel(fields_index_settings, name='index_settings')
 
 
-fields_trackme_ui_defaults = [
+fields_trackme_theme_default = [
     field.RestField(
-        'default_theme',
+        'tabulator_theme',
         required=True,
         encrypted=False,
-        default='dark',
+        default='dark_site',
         validator=validator.Pattern(
-            regex=r"""^(dark|light)$""", 
+            regex=r"""^(dark_site|dark_midnight|light|light_site|light_modern)$""", 
         )
     ), 
     field.RestField(
-        'auto_refresh',
+        'icons_state_mode',
+        required=True,
+        encrypted=False,
+        default='emoji',
+        validator=validator.Pattern(
+            regex=r"""^(emoji|bootstrap)$""", 
+        )
+    ), 
+    field.RestField(
+        'flex_width_default',
+        required=True,
+        encrypted=False,
+        default='350',
+        validator=validator.Pattern(
+            regex=r"""^\d*$""", 
+        )
+    ), 
+    field.RestField(
+        'flex_show_desc',
         required=True,
         encrypted=False,
         default='1',
@@ -300,25 +309,93 @@ fields_trackme_ui_defaults = [
         )
     ), 
     field.RestField(
-        'auto_refresh_interval_seconds',
+        'flex_show_summary',
         required=True,
         encrypted=False,
-        default='15',
+        default='1',
         validator=validator.Pattern(
-            regex=r"""^([5-9]|[1-9]\d|[12]\d{2}|300)$""", 
+            regex=r"""^(1|0)$""", 
         )
     ), 
     field.RestField(
-        'vtenants_card_detail_level',
+        'color_theme_default',
+        required=True,
+        encrypted=False,
+        default='dodgerblue',
+        validator=validator.Pattern(
+            regex=r"""^(dodgerblue|black|cadetblue|cornflowerblue|darkgreen|darkolivegreen|darkslateblue|grey|#31373e|lightslategray|royalblue|steelblue)$""", 
+        )
+    ), 
+    field.RestField(
+        'color_dyn_default',
         required=True,
         encrypted=False,
         default='0',
         validator=validator.Pattern(
             regex=r"""^(1|0)$""", 
         )
+    ), 
+    field.RestField(
+        'color_dyn_condition',
+        required=True,
+        encrypted=False,
+        default='high_priority',
+        validator=validator.Pattern(
+            regex=r"""^(any|critical_priority|high_priority|medium_priority)$""", 
+        )
+    ), 
+    field.RestField(
+        'color_theme_alert_default',
+        required=True,
+        encrypted=False,
+        default='red',
+        validator=validator.Pattern(
+            regex=r"""^(red|blue|yellow|orange|green)$""", 
+        )
+    ), 
+    field.RestField(
+        'show_tenants_mgmt_header',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(1|0)$""", 
+        )
+    ), 
+    field.RestField(
+        'trackmeload_mode',
+        required=True,
+        encrypted=False,
+        default='1',
+        validator=validator.Pattern(
+            regex=r"""^(rest|legacy)$""", 
+        )
     )
 ]
-model_trackme_ui_defaults = RestModel(fields_trackme_ui_defaults, name='trackme_ui_defaults')
+model_trackme_theme_default = RestModel(fields_trackme_theme_default, name='trackme_theme_default')
+
+
+fields_trackme_home_theme_default = [
+    field.RestField(
+        'tabulator_theme',
+        required=True,
+        encrypted=False,
+        default='dark_site',
+        validator=validator.Pattern(
+            regex=r"""^(dark_site|dark_midnight|light|light_site|light_modern)$""", 
+        )
+    ), 
+    field.RestField(
+        'icons_state_mode',
+        required=True,
+        encrypted=False,
+        default='brown',
+        validator=validator.Pattern(
+            regex=r"""^(emoji|bootstrap)$""", 
+        )
+    )
+]
+model_trackme_home_theme_default = RestModel(fields_trackme_home_theme_default, name='trackme_home_theme_default')
 
 
 fields_splk_general = [
@@ -466,6 +543,15 @@ fields_splk_general = [
             regex=r"""^.+$""", 
         )
     ), 
+    field.RestField(
+        'splk_general_cim_cmdb_search',
+        required=True,
+        encrypted=False,
+        default='| inputlookup my_cmdb where (object="$object$")',
+        validator=validator.Pattern(
+            regex=r"""^.+$""", 
+        )
+    ), 
     field.RestField(
         'splk_general_flx_cmdb_search',
         required=True,
@@ -914,7 +1000,8 @@ endpoint = MultipleModel(
     models=[
         model_trackme_general, 
         model_index_settings, 
-        model_trackme_ui_defaults, 
+        model_trackme_theme_default, 
+        model_trackme_home_theme_default, 
         model_splk_general, 
         model_splk_data_sampling, 
         model_splk_outliers_detection, 
