@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -75,190 +75,192 @@ from trackme_rest_handler_alerting_user import (
 from trackme_rest_handler_alerting_admin import (
     TrackMeHandlerAlertingWriteOps_v2 as handler_alerting_admin,
 )
-from trackme_rest_handler_ack_user import TrackMeHandlerAckReadOps_v2 as handler_ack_user
-from trackme_rest_handler_ack_power import TrackMeHandlerAckWriteOps_v2 as handler_ack_power
+from trackme_rest_handler_ack import TrackMeHandlerAck_v2 as handler_ack
 from trackme_rest_handler_audit import TrackMeHandlerAudit_v2 as handler_audit
 from trackme_rest_handler_backup_and_restore import (
     TrackMeHandlerBackupAndRestore_v2 as handler_backup_and_restore,
 )
 from trackme_rest_handler_configuration import (
-    TrackMeHandlerConfigurationRead_v2 as handler_configuration,
+    TrackMeHandlerConfiguration_v2 as handler_configuration,
 )
 from trackme_rest_handler_configuration_admin import (
-    TrackMeHandlerConfigurationAdmin_v2 as handler_configuration_admin,
+    TrackMeHandlerConfiguration_v2 as handler_configuration_admin,
 )
 from trackme_rest_handler_maintenance import (
     TrackMeHandlerMaintenance_v2 as handler_maintenance,
 )
 from trackme_rest_handler_maintenance_kdb_user import (
-    TrackMeHandlerMaintenanceKdbRead_v2 as handler_maintenance_kdb_user,
+    TrackMeHandlerMaintenanceKdb_v2 as handler_maintenance_kdb_user,
 )
 from trackme_rest_handler_maintenance_kdb_admin import (
-    TrackMeHandlerMaintenanceKdbAdmin_v2 as handler_maintenance_kdb_admin,
+    TrackMeHandlerMaintenanceKdb_v2 as handler_maintenance_kdb_admin,
 )
-from trackme_rest_handler_bank_holidays_user import (
-    TrackMeHandlerBankHolidaysRead_v2 as handler_bank_holidays_user,
+from trackme_rest_handler_splk_cim_user import (
+    TrackMeHandlerSplkCimTracking_v2 as handler_splk_cim_user,
 )
-from trackme_rest_handler_bank_holidays_admin import (
-    TrackMeHandlerBankHolidaysAdmin_v2 as handler_bank_holidays_admin,
+from trackme_rest_handler_splk_cim_power import (
+    TrackMeHandlerSplkCimTracking_v2 as handler_splk_cim_power,
+)
+from trackme_rest_handler_splk_cim_admin import (
+    TrackMeHandlerSplkCimTracking_v2 as handler_splk_cim_admin,
 )
 from trackme_rest_handler_splk_flx_user import (
-    TrackMeHandlerSplkFlxTrackingRead_v2 as handler_splk_flx_user,
+    TrackMeHandlerSplkFlxTracking_v2 as handler_splk_flx_user,
 )
 from trackme_rest_handler_splk_flx_power import (
-    TrackMeHandlerSplkFlxTrackingWrite_v2 as handler_splk_flx_power,
+    TrackMeHandlerSplkFlxTracking_v2 as handler_splk_flx_power,
 )
 from trackme_rest_handler_splk_flx_admin import (
-    TrackMeHandlerSplkFlxTrackingAdmin_v2 as handler_splk_flx_admin,
+    TrackMeHandlerSplkFlxTracking_v2 as handler_splk_flx_admin,
 )
 from trackme_rest_handler_splk_fqm_user import (
-    TrackMeHandlerSplkFqmTrackingRead_v2 as handler_splk_fqm_user,
+    TrackMeHandlerSplkFqmTracking_v2 as handler_splk_fqm_user,
 )
 from trackme_rest_handler_splk_fqm_power import (
-    TrackMeHandlerSplkFqmTrackingWrite_v2 as handler_splk_fqm_power,
+    TrackMeHandlerSplkFqmTracking_v2 as handler_splk_fqm_power,
 )
 from trackme_rest_handler_splk_fqm_admin import (
-    TrackMeHandlerSplkFqmTrackingAdmin_v2 as handler_splk_fqm_admin,
+    TrackMeHandlerSplkFqmTracking_v2 as handler_splk_fqm_admin,
 )
 from trackme_rest_handler_splk_wlk_user import (
-    TrackMeHandlerSplkWlkRead_v2 as handler_splk_wlk_user,
+    TrackMeHandlerSplkWlk_v2 as handler_splk_wlk_user,
 )
 from trackme_rest_handler_splk_wlk_power import (
-    TrackMeHandlerSplkWlkWrite_v2 as handler_splk_wlk_power,
+    TrackMeHandlerSplkWlk_v2 as handler_splk_wlk_power,
 )
 from trackme_rest_handler_splk_wlk_admin import (
-    TrackMeHandlerSplkWlkAdmin_v2 as handler_splk_wlk_admin,
+    TrackMeHandlerSplkWlk_v2 as handler_splk_wlk_admin,
 )
 from trackme_rest_handler_splk_data_sampling_user import (
-    TrackMeHandlerSplkDataSamplingRead_v2 as handler_spk_data_sampling_user,
+    TrackMeHandlerSplkDataSampling_v2 as handler_spk_data_sampling_user,
 )
 from trackme_rest_handler_splk_data_sampling_power import (
-    TrackMeHandlerSplkDataSamplingWrite_v2 as handler_spk_data_sampling_power,
+    TrackMeHandlerSplkDataSampling_v2 as handler_spk_data_sampling_power,
 )
 from trackme_rest_handler_splk_blocklist_user import (
-    TrackMeHandlerSplkBlocklistRead_v2 as handler_splk_blocklist_user,
+    TrackMeHandlerSplkBlocklist_v2 as handler_splk_blocklist_user,
 )
 from trackme_rest_handler_splk_blocklist_power import (
-    TrackMeHandlerSplkBlocklistWrite_v2 as handler_splk_blocklist_power,
+    TrackMeHandlerSplkBlocklist_v2 as handler_splk_blocklist_power,
 )
 from trackme_rest_handler_splk_dhm_user import (
-    TrackMeHandlerSplkDhmRead_v2 as handler_splk_dhm_user,
+    TrackMeHandlerSplkDhm_v2 as handler_splk_dhm_user,
 )
 from trackme_rest_handler_splk_dhm_power import (
-    TrackMeHandlerSplkDhmWrite_v2 as handler_splk_dhm_power,
+    TrackMeHandlerSplkDhm_v2 as handler_splk_dhm_power,
 )
 from trackme_rest_handler_splk_dsm_user import (
-    TrackMeHandlerSplkDsmRead_v2 as handler_splk_dsm_user,
+    TrackMeHandlerSplkDsm_v2 as handler_splk_dsm_user,
 )
 from trackme_rest_handler_splk_dsm_power import (
-    TrackMeHandlerSplkDsmWrite_v2 as handler_splk_dsm_power,
+    TrackMeHandlerSplkDsm_v2 as handler_splk_dsm_power,
 )
 from trackme_rest_handler_splk_disruption_user import (
-    TrackMeHandlerSplkDisruptionRead_v2 as handler_splk_disruption_user,
+    TrackMeHandlerSplkDisruption_v2 as handler_splk_disruption_user,
 )
 from trackme_rest_handler_splk_disruption_power import (
-    TrackMeHandlerSplkDisruptionWrite_v2 as handler_splk_disruption_power,
+    TrackMeHandlerSplkDisruption_v2 as handler_splk_disruption_power,
 )
 from trackme_rest_handler_splk_elastic_sources_user import (
-    TrackMeHandlerSplkElasticSourcesRead_v2 as handler_splk_elastic_sources_user,
+    TrackMeHandlerSplkElasticSources_v2 as handler_splk_elastic_sources_user,
 )
 from trackme_rest_handler_splk_elastic_sources_admin import (
-    TrackMeHandlerSplkElasticSourcesAdmin_v2 as handler_splk_elastic_sources_admin,
+    TrackMeHandlerSplkElasticSources_v2 as handler_splk_elastic_sources_admin,
 )
 from trackme_rest_handler_splk_hybrid_trackers_user import (
-    TrackMeHandlerSplkHybridTrackerRead_v2 as handler_splk_hybrid_trackers_user,
+    TrackMeHandlerSplkHybridTracker_v2 as handler_splk_hybrid_trackers_user,
 )
 from trackme_rest_handler_splk_hybrid_trackers_admin import (
-    TrackMeHandlerSplkHybridTrackerAdmin_v2 as handler_splk_hybrid_trackers_admin,
+    TrackMeHandlerSplkHybridTracker_v2 as handler_splk_hybrid_trackers_admin,
 )
 from trackme_rest_handler_splk_replica_trackers_user import (
-    TrackMeHandlerSplkReplicaTrackerRead_v2 as handler_splk_replica_trackers_user,
+    TrackMeHandlerSplkReplicaTracker_v2 as handler_splk_replica_trackers_user,
 )
 from trackme_rest_handler_splk_replica_trackers_admin import (
-    TrackMeHandlerSplkReplicaTrackerAdmin_v2 as handler_splk_replica_trackers_admin,
+    TrackMeHandlerSplkReplicaTracker_v2 as handler_splk_replica_trackers_admin,
 )
 from trackme_rest_handler_splk_identity_cards_user import (
-    TrackMeHandlerSplkIdentityCardsRead_v2 as handler_splk_identity_cards_user,
+    TrackMeHandlerSplkIdentityCards_v2 as handler_splk_identity_cards_user,
 )
 from trackme_rest_handler_splk_identity_cards_power import (
-    TrackMeHandlerSplkIdentityCardsWrite_v2 as handler_splk_identity_cards_power,
+    TrackMeHandlerSplkIdentityCards_v2 as handler_splk_identity_cards_power,
 )
 from trackme_rest_handler_splk_lagging_classes_user import (
-    TrackMeHandlerSplkLaggingClassesRead_v2 as handler_splk_lagging_classes_user,
+    TrackMeHandlerSplkLaggingClasses_v2 as handler_splk_lagging_classes_user,
 )
 from trackme_rest_handler_splk_lagging_classes_power import (
-    TrackMeHandlerSplkLaggingClassesWrite_v2 as handler_splk_lagging_classes_power,
+    TrackMeHandlerSplkLaggingClasses_v2 as handler_splk_lagging_classes_power,
 )
 from trackme_rest_handler_splk_logical_groups_user import (
-    TrackMeHandlerSplkLogicalGroupsRead_v2 as handler_splk_logical_groups_user,
+    TrackMeHandlerSplkLogicalGroups_v2 as handler_splk_logical_groups_user,
 )
 from trackme_rest_handler_splk_logical_groups_power import (
-    TrackMeHandlerSplkLogicalGroupsWrite_v2 as handler_splk_logical_groups_power,
+    TrackMeHandlerSplkLogicalGroups_v2 as handler_splk_logical_groups_power,
 )
 from trackme_rest_handler_splk_mhm_user import (
-    TrackMeHandlerSplkMhmRead_v2 as handler_splk_mhm_user,
+    TrackMeHandlerSplkMhm_v2 as handler_splk_mhm_user,
 )
 from trackme_rest_handler_splk_mhm_power import (
-    TrackMeHandlerSplkMhmWrite_v2 as handler_splk_mhm_power,
+    TrackMeHandlerSplkMhm_v2 as handler_splk_mhm_power,
 )
 from trackme_rest_handler_splk_outliers_engine_user import (
-    TrackMeHandlerSplkOutliersEngineRead_v2 as handler_splk_outliers_engine_user,
+    TrackMeHandlerSplkOutliersEngine_v2 as handler_splk_outliers_engine_user,
 )
 from trackme_rest_handler_splk_outliers_engine_power import (
-    TrackMeHandlerSplkOutliersEngineWrite_v2 as handler_splk_outliers_engine_power,
+    TrackMeHandlerSplkOutliersEngine_v2 as handler_splk_outliers_engine_power,
 )
 from trackme_rest_handler_splk_smart_status import (
     TrackMeHandlerSplkSmartStatus_v2 as handler_splk_smart_status,
 )
 from trackme_rest_handler_splk_tag_policies_user import (
-    TrackMeHandlerSplkTagPoliciesRead_v2 as handler_splk_lag_policies_user,
+    TrackMeHandlerSplkTagPolicies_v2 as handler_splk_lag_policies_user,
 )
 from trackme_rest_handler_splk_tag_policies_power import (
-    TrackMeHandlerSplkTagPoliciesWrite_v2 as handler_splk_lag_policies_power,
+    TrackMeHandlerSplkTagPolicies_v2 as handler_splk_lag_policies_power,
 )
 from trackme_rest_handler_splk_priority_policies_user import (
-    TrackMeHandlerSplkPriorityPoliciesRead_v2 as handler_splk_priority_policies_user,
+    TrackMeHandlerSplkPriorityPolicies_v2 as handler_splk_priority_policies_user,
 )
 from trackme_rest_handler_splk_priority_policies_power import (
-    TrackMeHandlerSplkPriorityPoliciesWrite_v2 as handler_splk_priority_policies_power,
+    TrackMeHandlerSplkPriorityPolicies_v2 as handler_splk_priority_policies_power,
 )
 from trackme_rest_handler_splk_sla_policies_user import (
-    TrackMeHandlerSplkSlaPoliciesRead_v2 as handler_splk_sla_policies_user,
+    TrackMeHandlerSplkSlaPolicies_v2 as handler_splk_sla_policies_user,
 )
 from trackme_rest_handler_splk_sla_policies_power import (
-    TrackMeHandlerSplkSlaPoliciesWrite_v2 as handler_splk_sla_policies_power,
+    TrackMeHandlerSplkSlaPolicies_v2 as handler_splk_sla_policies_power,
 )
 from trackme_rest_handler_vtenants_user import (
-    TrackMeHandlerVtenantsRead_v2 as handler_vtenants_user,
+    TrackMeHandlerVtenants_v2 as handler_vtenants_user,
 )
 from trackme_rest_handler_vtenants_power import (
-    TrackMeHandlerVtenantsWrite_v2 as handler_vtenants_power,
+    TrackMeHandlerVtenants_v2 as handler_vtenants_power,
 )
 from trackme_rest_handler_vtenants_admin import (
-    TrackMeHandlerVtenantsAdmin_v2 as handler_vtenants_admin,
+    TrackMeHandlerVtenants_v2 as handler_vtenants_admin,
 )
 from trackme_rest_handler_licensing_admin import (
-    TrackMeHandlerLicensingAdmin_v2 as handler_licensing_admin,
+    TrackMeHandlerLicensing_v2 as handler_licensing_admin,
 )
 from trackme_rest_handler_licensing_user import (
-    TrackMeHandlerLicensingRead_v2 as handler_licensing_user,
+    TrackMeHandlerLicensing_v2 as handler_licensing_user,
 )
 
 from trackme_rest_handler_splk_deleted_entities_user import (
-    TrackMeHandlerSplkDeletedEntitiesRead_v2 as handler_splk_deleted_entities_user,
+    TrackMeHandlerSplkDeletedEntities_v2 as handler_splk_deleted_entities_user,
 )
 
 from trackme_rest_handler_splk_deleted_entities_power import (
-    TrackMeHandlerSplkDeletedEntitiesPower_v2 as handler_splk_deleted_entities_power,
+    TrackMeHandlerSplkDeletedEntities_v2 as handler_splk_deleted_entities_power,
 )
 
 # Try importing the handlers that might fail
 try:
     from trackme_rest_handler_splk_soar_user import (
-        TrackMeHandlerSplkSoarRead_v2 as handler_splk_soar_user,
+        TrackMeHandlerSplkSoar_v2 as handler_splk_soar_user,
     )
     from trackme_rest_handler_splk_soar_admin import (
-        TrackMeHandlerSplkSoarAdmin_v2 as handler_splk_soar_admin,
+        TrackMeHandlerSplkSoar_v2 as handler_splk_soar_admin,
     )
 except ImportError:
     # Handle the import error
@@ -269,19 +271,11 @@ except ImportError:
     )
 
 from trackme_rest_handler_component_user import (
-    TrackMeHandlerComponentRead_v2 as handler_component_user,
+    TrackMeHandlerComponent_v2 as handler_component_user,
 )
 
 from trackme_rest_handler_component_power import (
-    TrackMeHandlerComponentPower_v2 as handler_component_power,
-)
-
-from trackme_rest_handler_notes_user import (
-    TrackMeHandlerNotesRead_v2 as handler_notes_user,
-)
-
-from trackme_rest_handler_notes_power import (
-    TrackMeHandlerNotesWrite_v2 as handler_notes_power,
+    TrackMeHandlerComponent_v2 as handler_component_power,
 )
 
 
@@ -387,12 +381,9 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_alerting_admin: {
                 "resource_group": "alerting/admin",
             },
-            handler_ack_user: {
+            handler_ack: {
                 "resource_group": "ack",
             },
-            handler_ack_power: {
-                "resource_group": "ack/write",
-            },            
             handler_audit: {
                 "resource_group": "audit",
             },
@@ -414,12 +405,6 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_maintenance_kdb_admin: {
                 "resource_group": "maintenance_kdb/admin",
             },
-            handler_bank_holidays_user: {
-                "resource_group": "bank_holidays",
-            },
-            handler_bank_holidays_admin: {
-                "resource_group": "bank_holidays/admin",
-            },
             handler_splk_flx_user: {
                 "resource_group": "splk_flx",
             },
@@ -468,6 +453,15 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_splk_disruption_power: {
                 "resource_group": "splk_disruption/write",
             },
+            handler_splk_cim_user: {
+                "resource_group": "splk_cim",
+            },
+            handler_splk_cim_power: {
+                "resource_group": "splk_cim/write",
+            },
+            handler_splk_cim_admin: {
+                "resource_group": "splk_cim/admin",
+            },
             handler_splk_flx_user: {
                 "resource_group": "splk_flx",
             },
@@ -597,12 +591,6 @@ class TrackMeApiAutoDocs(GeneratingCommand):
             handler_component_power: {
                 "resource_group": "component/write",
             },
-            handler_notes_user: {
-                "resource_group": "notes",
-            },
-            handler_notes_power: {
-                "resource_group": "notes/write",
-            },
         }
 
         #
@@ -654,7 +642,7 @@ class TrackMeApiAutoDocs(GeneratingCommand):
                             headers=headers,
                             data=json.dumps(request_data, indent=0),
                             verify=False,
-                            timeout=600,
+                            timeout=300,
                         )
                     elif resource_mode == "post":
                         response = requests.post(
@@ -662,7 +650,7 @@ class TrackMeApiAutoDocs(GeneratingCommand):
                             headers=headers,
                             data=json.dumps(request_data, indent=0),
                             verify=False,
-                            timeout=600,
+                            timeout=300,
                         )
                     elif resource_mode == "delete":
                         response = requests.delete(
@@ -670,7 +658,7 @@ class TrackMeApiAutoDocs(GeneratingCommand):
                             headers=headers,
                             data=json.dumps(request_data, indent=0),
                             verify=False,
-                            timeout=600,
+                            timeout=300,
                         )
 
                     response_json = json.loads(response.text)
