@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -77,7 +77,7 @@ class TrackMeGetCollection(GeneratingCommand):
         **Description:** The tenant identifier.""",
         require=True,
         default=None,
-        validate=validators.Match("tenant_id", r".+"),
+        validate=validators.Match("tenant_id", r".*"),
     )
 
     component = Option(
@@ -86,7 +86,7 @@ class TrackMeGetCollection(GeneratingCommand):
         **Description:** The tracker component name to be executed.""",
         require=True,
         default=None,
-        validate=validators.Match("component", r"^(?:dsm|dhm|mhm|flx|wlk|fqm)$"),
+        validate=validators.Match("component", r"^(?:dsm|dhm|mhm|cim|flx|wlk|fqm)$"),
     )
 
     mode = Option(
@@ -179,8 +179,6 @@ class TrackMeGetCollection(GeneratingCommand):
                 stats["count_high_enabled"] += 1
             if record.get("priority") == "critical":
                 stats["count_critical_enabled"] += 1
-            if record.get("priority") == "pending":
-                stats["count_pending_enabled"] += 1
             if record.get("object_state") == "green":
                 stats["count_green_enabled"] += 1
             if record.get("object_state") == "blue":
@@ -201,22 +199,6 @@ class TrackMeGetCollection(GeneratingCommand):
             ):
                 stats["count_red_other_priority_enabled"] += 1
 
-    def ensure_record_tenant_id(self, record):
-        """
-        Ensure a record has a valid tenant_id field set to the command's tenant_id argument.
-        If the record's tenant_id is missing, empty, or invalid, set it to self.tenant_id.
-        
-        :param record: A dictionary representing a single record.
-        """
-        record_tenant_id = record.get("tenant_id")
-        
-        # Check if tenant_id is missing, empty, or invalid
-        if not record_tenant_id or not str(record_tenant_id).strip():
-            record["tenant_id"] = self.tenant_id
-            logging.debug(
-                f'Record missing or empty tenant_id, set to command argument value, tenant_id="{self.tenant_id}"'
-            )
-
     def generate(self, **kwargs):
         # Start performance counter
         start = time.time()
@@ -224,12 +206,6 @@ class TrackMeGetCollection(GeneratingCommand):
         # Log the run time
         logging.info(f"trackmegetcomponent is starting")
 
-        # Validate tenant_id argument is not None or empty
-        if not self.tenant_id or not self.tenant_id.strip():
-            msg = f'tenant_id is required and cannot be empty, tenant_id="{self.tenant_id}"'
-            logging.error(msg)
-            raise Exception(msg)
-
         # Get request info and set logging level
         reqinfo = trackme_reqinfo(
             self._metadata.searchinfo.session_key, self._metadata.searchinfo.splunkd_uri
@@ -283,7 +259,6 @@ class TrackMeGetCollection(GeneratingCommand):
             "count_medium_enabled": 0,
             "count_high_enabled": 0,
             "count_critical_enabled": 0,
-            "count_pending_enabled": 0,
             "count_blue_enabled": 0,
             "count_orange_enabled": 0,
             "count_green_enabled": 0,
@@ -375,7 +350,7 @@ class TrackMeGetCollection(GeneratingCommand):
                     headers=header,
                     params=params,
                     verify=False,
-                    timeout=600,
+                    timeout=300,
                 )
 
                 if response.status_code not in (200, 201, 204):
@@ -388,9 +363,6 @@ class TrackMeGetCollection(GeneratingCommand):
 
                     # add the data to the data_records
                     for record in data:
-                        # Ensure record has valid tenant_id set to command argument
-                        self.ensure_record_tenant_id(record)
-                        
                         if self.mode == "records":
 
                             # the field anomaly_reason is a pipe separated string, turn it into a list
