@@ -66,17 +66,7 @@ from splunklib.searchcommands import (
 
 # Import trackme libs
 from trackme_libs import trackme_reqinfo
-from trackme_libs_utils import decode_unicode, get_uuid
-
-# import TrackMe get data libs
-from trackme_libs_get_data import (
-    search_kv_collection_restmode,
-    search_kv_collection_searchmode,
-    search_kv_collection_sdkmode,
-)
-
-# Import trackMe kvstore batch libs
-from trackme_libs_kvstore_batch import batch_update_worker
+from trackme_libs_utils import decode_unicode
 
 # import trackme libs persistent fields definition
 from collections_data import (
@@ -86,6 +76,7 @@ from collections_data import (
     persistent_fields_flx,
     persistent_fields_fqm,
     persistent_fields_wlk,
+    persistent_fields_cim,
 )
 
 
@@ -139,6 +130,8 @@ class TrackMePersistentHandler(StreamingCommand):
             component = "flx"
         elif collection_name.startswith("trackme_fqm_"):
             component = "fqm"
+        elif collection_name.startswith("trackme_cim_"):
+            component = "cim"
         elif collection_name.startswith("trackme_wlk_"):
             component = "wlk"
         else:
@@ -146,8 +139,6 @@ class TrackMePersistentHandler(StreamingCommand):
 
         return component
 
-
-
     def stream(self, records):
         # performance counter
         start_time = time.time()
@@ -158,14 +149,6 @@ class TrackMePersistentHandler(StreamingCommand):
         )
         log.setLevel(reqinfo["logging_level"])
 
-        # Max multi thread workers
-        max_multi_thread_workers = int(
-            reqinfo["trackme_conf"]["trackme_general"]["max_multi_thread_workers"]
-        )
-
-        # set instance_id
-        self.instance_id = get_uuid()
-
         # connect to the KVstore
         target_collection = f"kv_{self.collection}"
         collection = self.service.kvstore[target_collection]
@@ -190,30 +173,69 @@ class TrackMePersistentHandler(StreamingCommand):
         elif component == "fqm":
             for field in persistent_fields_fqm:
                 persistent_fields.append(field)
+        elif component == "cim":
+            for field in persistent_fields_cim:
+                persistent_fields.append(field)
         elif component == "wlk":
             for field in persistent_fields_wlk:
                 persistent_fields.append(field)
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_collection_records"
-
         # get all records
-        collection_records, collection_keys, collection_dict, last_page = (
-            search_kv_collection_sdkmode(
-                logging, self.service, target_collection, page=1, page_count=0, orderby="keyid"
-            )
+        get_collection_start = time.time()
+        collection_records = []
+        collection_records_keys = set()
+
+        end = False
+        skip_tracker = 0
+        while end == False:
+            process_collection_records = collection.data.query(skip=skip_tracker)
+            if len(process_collection_records) != 0:
+                for item in process_collection_records:
+                    if item.get("_key") not in collection_records_keys:
+                        collection_records.append(item)
+                        collection_records_keys.add(item.get("_key"))
+                skip_tracker += 5000
+            else:
+                end = True
+
+        logging.info(
+            f'context="perf", get collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", collection="{self.collection}"'
         )
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
+        # create a list of all keys for fast verification
+        collection_keys = []
+
+        # create a dictionary of all keys with their persistent fields
+        collection_dict = {}
+
+        for collection_record in collection_records:
+            collection_keys.append(collection_record.get("_key"))
+            collection_subrecord = {}
+
+            # add time of update of this record
+            try:
+                collection_subrecord["mtime"] = float(collection_record.get("mtime"))
+            except Exception as e:
+                collection_subrecord["mtime"] = float(time.time())
+
+            # loop and add persistent fields
+            for field in persistent_fields:
+                try:
+                    collection_subrecord[field] = collection_record.get(field)
+                except Exception as e:
+                    logging.debug(f'field="{field}" was not found in the record')
+
+            # for dsm/dhm, add data_last_time_seen
+            if component in ["dsm", "dhm"]:
+                try:
+                    collection_subrecord["data_last_time_seen"] = float(
+                        collection_record.get("data_last_time_seen")
+                    )
+                except:
+                    pass
+
+            # add to our dict
+            collection_dict[collection_record.get("_key")] = collection_subrecord
 
         #
         # Define Meta
@@ -240,13 +262,13 @@ class TrackMePersistentHandler(StreamingCommand):
             except Exception as e:
                 time_event = time.time()
 
-            logging.debug(f'instance_id="{self.instance_id}", inspecting record={json.dumps(record, indent=2)}')
+            logging.debug(f"inspecting record={json.dumps(record, indent=2)}")
 
             # always set an object_256 and add _key in the record
             record_object_value = decode_unicode(record["object"])
             record_alias = decode_unicode(record["alias"])
             logging.debug(
-                f'instance_id="{self.instance_id}", object="{record["object"]}", decoded_object="{record_object_value}", alias="{record["alias"]}", decoded_alias="{record_alias}"'
+                f'object="{record["object"]}", decoded_object="{record_object_value}", alias="{record["alias"]}", decoded_alias="{record_alias}"'
             )
 
             # add the _key in the record if there is none
@@ -256,7 +278,7 @@ class TrackMePersistentHandler(StreamingCommand):
                 ).hexdigest()
                 record["_key"] = object_256
                 logging.debug(
-                    f'instance_id="{self.instance_id}", adding _key="{object_256}" to record for object="{record_object_value}", alias="{record_alias}"'
+                    f'adding _key="{object_256}" to record for object="{record_object_value}", alias="{record_alias}"'
                 )
 
             # handle unicode for object and alias
@@ -284,10 +306,10 @@ class TrackMePersistentHandler(StreamingCommand):
                 try:
 
                     rejected_record_key = record.get(self.key)
-                    logging.debug(f'instance_id="{self.instance_id}", record key="{rejected_record_key}"')
+                    logging.debug(f'record key="{rejected_record_key}"')
 
                     rejected_record_dict = collection_dict.get(rejected_record_key)
-                    logging.debug(f'instance_id="{self.instance_id}", rejected_record_dict="{rejected_record_dict}"')
+                    logging.debug(f'rejected_record_dict="{rejected_record_dict}"')
 
                     if rejected_record_dict is not None:
                         kvstore_data_last_time_seen = rejected_record_dict.get(
@@ -299,7 +321,7 @@ class TrackMePersistentHandler(StreamingCommand):
                             "data_last_time_seen", None
                         )
                         logging.info(
-                            f'instance_id="{self.instance_id}", kvstore_data_last_time_seen="{kvstore_data_last_time_seen}"'
+                            f'kvstore_data_last_time_seen="{kvstore_data_last_time_seen}"'
                         )
 
                         if kvstore_data_last_time_seen:
@@ -324,28 +346,28 @@ class TrackMePersistentHandler(StreamingCommand):
                             ):
                                 rejected_record = True
                                 logging.warning(
-                                    f'instance_id="{self.instance_id}", collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", rejected record detected, epoch value in kVstore {kvstore_data_last_time_seen} is bigger than record submitted value {current_data_last_time_seen}, record="{json.dumps(record, indent=2)}"'
+                                    f'collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", rejected record detected, epoch value in kVstore {kvstore_data_last_time_seen} is bigger than record submitted value {current_data_last_time_seen}, record="{json.dumps(record, indent=2)}"'
                                 )
                             else:
                                 rejected_record = False
                                 logging.debug(
-                                    f'instance_id="{self.instance_id}", collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", rejected record not detected, epoch value in kVstore {kvstore_data_last_time_seen} and record submitted value {current_data_last_time_seen} are both None, record="{json.dumps(record, indent=2)}"'
+                                    f'collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", rejected record not detected, epoch value in kVstore {kvstore_data_last_time_seen} and record submitted value {current_data_last_time_seen} are both None, record="{json.dumps(record, indent=2)}"'
                                 )
                         else:
                             rejected_record = False
                             logging.debug(
-                                f'instance_id="{self.instance_id}", collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", object="{record.get("object")}", rejected record not detected, epoch value in kVstore {kvstore_data_last_time_seen} and record submitted value {current_data_last_time_seen} are both None, record="{json.dumps(record, indent=2)}"'
+                                f'collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", object="{record.get("object")}", rejected record not detected, epoch value in kVstore {kvstore_data_last_time_seen} and record submitted value {current_data_last_time_seen} are both None, record="{json.dumps(record, indent=2)}"'
                             )
 
                     else:
                         rejected_record = False
                         logging.warning(
-                            f'instance_id="{self.instance_id}", collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", object="{record.get("object")}", this object could not be found in the dictionnary, most likely because this sourcetype is corrupted and index non printable characters as its name!'
+                            f'collection="{target_collection}", component="{component}", record key="{record.get(self.key)}", object="{record.get("object")}", this object could not be found in the dictionnary, most likely because this sourcetype is corrupted and index non printable characters as its name!'
                         )
 
                 except Exception as e:
                     logging.error(
-                        f'instance_id="{self.instance_id}", collection="{target_collection}", component="{component}", failed to extract and convert data_last_time_seen, record key="{record.get(self.key)}", object="{record.get("object")}", exception message="{str(e)}"'
+                        f'collection="{target_collection}", component="{component}", failed to extract and convert data_last_time_seen, record key="{record.get(self.key)}", object="{record.get("object")}", exception message="{str(e)}"'
                     )
                     rejected_record = False
 
@@ -358,14 +380,14 @@ class TrackMePersistentHandler(StreamingCommand):
                     if mtime > float(tracker_runtime):
                         conflict_update = True
                         logging.info(
-                            f'instance_id="{self.instance_id}", record key="{record.get(self.key)}", conflict update detected, preserving persistent fields="{persistent_fields}", record="{json.dumps(record, indent=2)}"'
+                            f'record key="{record.get(self.key)}", conflict update detected, preserving persistent fields="{persistent_fields}", record="{json.dumps(record, indent=2)}"'
                         )
                     else:
                         conflict_update = False
 
                 except Exception as e:
                     logging.error(
-                        f'instance_id="{self.instance_id}", failed to extract and convert mtime="{mtime}", tracker_runtime="{tracker_runtime}", exception message="{str(e)}"'
+                        f'failed to extract and convert mtime="{mtime}", tracker_runtime="{tracker_runtime}", exception message="{str(e)}"'
                     )
                     conflict_update = False
 
@@ -380,7 +402,7 @@ class TrackMePersistentHandler(StreamingCommand):
 
                 # loop through the dict
                 for k in record:
-                    logging.debug(f'instance_id="{self.instance_id}", field="{k}", value="{record[k]}"')
+                    logging.debug(f'field="{k}", value="{record[k]}"')
 
                     # Exclude the event time, add existing fields
                     if k != "_time":
@@ -411,34 +433,31 @@ class TrackMePersistentHandler(StreamingCommand):
                 final_records.append(record)
 
         # log
-        logging.debug(f'instance_id="{self.instance_id}", final_records={json.dumps(final_records, indent=2)}')
+        logging.debug(f"final_records={json.dumps(final_records, indent=2)}")
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "kvstore_batch_update"
+        # batch update/insert
+        batch_update_collection_start = time.time()
 
-        # Execute batch update synchronously
-        batch_update_worker(
-            target_collection, collection, final_records, self.instance_id, task_instance_id, task_name=task_name, max_multi_thread_workers=max_multi_thread_workers
-        )
+        # process by chunk
+        chunks = [final_records[i : i + 500] for i in range(0, len(final_records), 500)]
+        for chunk in chunks:
+            try:
+                collection.data.batch_save(*chunk)
+            except Exception as e:
+                logging.error(f'KVstore batch failed with exception="{str(e)}"')
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
+            # yield
+            for record in chunk:
+                yield record
+
+        # perf counter for the batch operation
         logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated. no_records="{len(final_records)}", collection="{self.collection}"'
-        )        
-
-        # Yield records back to Splunk pipeline
-        for record in final_records:
-            yield record
+            f'context="perf", batch KVstore update terminated, no_records="{len(final_records)}", run_time="{round((time.time() - batch_update_collection_start), 3)}", collection="{self.collection}"'
+        )
 
         # perf counter for the entire call
         logging.info(
-            f'instance_id="{self.instance_id}", trackmepersistentfields has terminated, collection="{self.collection}", key="{self.key}", update_collection="{self.update_collection}", run_time="{round((time.time() - start_time), 3)}"'
+            f'trackmepersistentfields has terminated, collection="{self.collection}", key="{self.key}", update_collection="{self.update_collection}", run_time="{round((time.time() - start_time), 3)}"'
         )
 
 
