@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -520,7 +520,7 @@ class AdaptiveDelay(GeneratingCommand):
 
             ``` ML calculations for this object ```
             | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
+            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
             | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
             | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -540,7 +540,7 @@ class AdaptiveDelay(GeneratingCommand):
 
                 ``` ML calculations for this object ```
                 | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
+                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
                 | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
                 | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -562,7 +562,7 @@ class AdaptiveDelay(GeneratingCommand):
 
                 ``` ML calculations for this object ```
                 | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
+                | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
                 | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
                 | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -604,7 +604,7 @@ class AdaptiveDelay(GeneratingCommand):
 
             ``` ML calculations for this object ```
             | fit DensityFunction lag_event_sec lower_threshold=0.005 upper_threshold=0.005 by object
-            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\\d|\\.]*))|((?<UpperBound>[\\d|\\.]*):Infinity)"
+            | rex field=BoundaryRanges "(-Infinity:(?<LowerBound>[\d|\.]*))|((?<UpperBound>[\d|\.]*):Infinity)"
             | foreach LowerBound UpperBound [ eval <<FIELD>> = if(isnum('<<FIELD>>'), '<<FIELD>>', 0) ]
             | fields _time object lag_event_sec LowerBound UpperBound
 
@@ -726,7 +726,7 @@ class AdaptiveDelay(GeneratingCommand):
                 },
                 data=json.dumps(data),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code not in (200, 201, 204):
                 log_msg = f'tenant_id="{self.tenant_id}", component="splk-{self.component}", object="{entity_name}", updating lag policy has failed, response.status_code="{response.status_code}", response.text="{response.text}"'
