@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = ["Guilhem Marchand"]
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -208,7 +208,7 @@ class SplkFlxInactiveEntitiesInspector(GeneratingCommand):
                 headers=header,
                 params=params,
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -267,7 +267,7 @@ class SplkFlxInactiveEntitiesInspector(GeneratingCommand):
                 headers=header,
                 data=json.dumps(data, indent=1),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code not in (200, 201, 204):
                 error_msg = f'failed to retrieve the tenant metric index, response.status_code="{response.status_code}", response.text="{response.text}"'
@@ -330,7 +330,7 @@ class SplkFlxInactiveEntitiesInspector(GeneratingCommand):
                     }
                 ),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
 
             if response.status_code not in (200, 201, 204):
@@ -477,51 +477,8 @@ class SplkFlxInactiveEntitiesInspector(GeneratingCommand):
                 record.get("tracker_runtime")
             )
 
-            # get status (handle tracker-keyed JSON format from concurrent trackers)
-            status_value = record.get("status")
-            try:
-                if isinstance(status_value, str):
-                    try:
-                        status_by_tracker = json.loads(status_value)
-                        if isinstance(status_by_tracker, dict):
-                            # Tracker-keyed format: apply worst-status logic (2 > 3 > 1)
-                            status_values = list(status_by_tracker.values())
-                            if status_values:
-                                if 2 in status_values:
-                                    record_status = 2  # Red
-                                elif 3 in status_values:
-                                    record_status = 3  # Orange
-                                else:
-                                    record_status = 1  # Green
-                            else:
-                                record_status = 1  # Default to green if empty
-                        else:
-                            # Not a dict, treat as old format integer string
-                            record_status = int(status_value)
-                    except (json.JSONDecodeError, TypeError):
-                        # If parsing fails, treat as old format integer string
-                        record_status = int(status_value)
-                elif isinstance(status_value, dict):
-                    # Already a dict (tracker-keyed format)
-                    status_values = list(status_value.values())
-                    if status_values:
-                        if 2 in status_values:
-                            record_status = 2  # Red
-                        elif 3 in status_values:
-                            record_status = 3  # Orange
-                        else:
-                            record_status = 1  # Green
-                    else:
-                        record_status = 1  # Default to green if empty
-                else:
-                    # Simple integer value
-                    record_status = int(status_value)
-            except (ValueError, TypeError) as e:
-                logging.error(
-                    f'instance_id="{instance_id}", failed to parse status for object="{object_name}", '
-                    f'value="{status_value}", exception="{str(e)}"'
-                )
-                record_status = 1  # Default to green on error
+            # get status
+            record_status = int(record.get("status"))
 
             # get current_state
             record_current_state = record.get("current_state")
@@ -532,41 +489,7 @@ class SplkFlxInactiveEntitiesInspector(GeneratingCommand):
                 max_sec_inactive = 0
                 # If max_sec_inactive is 0, skip updating this record
             else:
-                # Handle tracker-keyed JSON format (from concurrent trackers)
-                try:
-                    if isinstance(max_sec_inactive, str):
-                        try:
-                            parsed = json.loads(max_sec_inactive)
-                            if isinstance(parsed, dict):
-                                # Tracker-keyed format: extract minimum value (excluding 0)
-                                non_zero_values = [float(v) for v in parsed.values() if float(v) > 0]
-                                if non_zero_values:
-                                    max_sec_inactive = min(non_zero_values)
-                                else:
-                                    # All values are 0, use 0 (disabled)
-                                    max_sec_inactive = 0
-                            else:
-                                # Not a dict, treat as simple numeric string
-                                max_sec_inactive = float(max_sec_inactive)
-                        except (json.JSONDecodeError, TypeError, ValueError):
-                            # Not JSON, treat as simple numeric string
-                            max_sec_inactive = float(max_sec_inactive)
-                    elif isinstance(max_sec_inactive, dict):
-                        # Already a dict (tracker-keyed format)
-                        non_zero_values = [float(v) for v in max_sec_inactive.values() if float(v) > 0]
-                        if non_zero_values:
-                            max_sec_inactive = min(non_zero_values)
-                        else:
-                            max_sec_inactive = 0
-                    else:
-                        # Simple numeric value
-                        max_sec_inactive = float(max_sec_inactive)
-                except (ValueError, TypeError) as e:
-                    logging.error(
-                        f'instance_id="{instance_id}", failed to parse max_sec_inactive for object="{object_name}", '
-                        f'value="{record.get("max_sec_inactive")}", exception="{str(e)}"'
-                    )
-                    max_sec_inactive = 0
+                max_sec_inactive = float(max_sec_inactive)
 
             #
             # update inactive entities status
