@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -66,7 +66,7 @@ from trackme_libs_splk_fqm import (
 from trackme_libs import trackme_reqinfo
 
 # Import trackMe utils libs
-from trackme_libs_utils import get_uuid
+from trackme_libs_utils import decode_unicode
 
 # import Splunk libs
 from splunklib.searchcommands import (
@@ -82,7 +82,6 @@ from trackme_libs_get_data import (
     get_full_kv_collection,
 )
 
-
 @Configuration(distributed=False)
 class TrackMeSplkFqmParse(StreamingCommand):
     tenant_id = Option(
@@ -119,24 +118,6 @@ class TrackMeSplkFqmParse(StreamingCommand):
         validate=validators.Match("default_threshold_global", r"^\d*\.?\d*$"),
     )
 
-    default_score_fields = Option(
-        doc="""
-        **Syntax:** **default_score_fields=****
-        **Description:** The default score (0-100) for field thresholds when breached, defaults to 100. (integer value)""",
-        require=False,
-        default=100,
-        validate=validators.Match("default_score_fields", r"^\d+$"),
-    )
-
-    default_score_global = Option(
-        doc="""
-        **Syntax:** **default_score_global=****
-        **Description:** The default score (0-100) for global entity thresholds when breached, defaults to 100. (integer value)""",
-        require=False,
-        default=100,
-        validate=validators.Match("default_score_global", r"^\d+$"),
-    )
-
     context = Option(
         doc="""
         **Syntax:** **context=****
@@ -171,6 +152,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
         default=None,
     )
 
+
     def get_thresholds_collection(self):
         # connect to the KVstore
         collection_name = f"kv_trackme_fqm_thresholds_tenant_{self.tenant_id}"
@@ -196,17 +178,6 @@ class TrackMeSplkFqmParse(StreamingCommand):
                             threshold_value = float(threshold_value)
                         except (TypeError, ValueError):
                             pass
-                        
-                        # Get score, default to 100 if not present (for backward compatibility)
-                        score = item.get("score")
-                        if score is None:
-                            score = 100
-                        else:
-                            try:
-                                score = int(score)
-                            except (TypeError, ValueError):
-                                score = 100
-                        
                         collection_records_dict[item.get("object_id")] = {
                             "_key": item.get("_key"),
                             "metric_name": item.get("metric_name"),
@@ -215,14 +186,13 @@ class TrackMeSplkFqmParse(StreamingCommand):
                             "value": threshold_value,
                             "condition_true": int(item.get("condition_true", 0)),
                             "comment": item.get("comment"),
-                            "score": score,
                         }
                 skip_tracker += 5000
             else:
                 end = True
 
         logging.info(
-            f'instance_id="{self.instance_id}", context="perf", get_thresholds_collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", collection="{collection_name}"'
+            f'context="perf", get_thresholds_collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", collection="{collection_name}"'
         )
 
         return collection_records_dict
@@ -255,11 +225,48 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 end = True
 
         logging.info(
-            f'instance_id="{self.instance_id}", context="perf", get_disruption_queue_collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", collection="{collection_name}"'
+            f'context="perf", get_disruption_queue_collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", collection="{collection_name}"'
         )
 
         return collection_records_dict, collection_records_keys
 
+    # batch KVstore update
+    def batch_kvstore_update(self, collection_name, collection_dict):
+        logging.debug(
+            f"calling batch_kvstore_update, collection_dict={json.dumps(collection_dict, indent=2)}"
+        )
+        # connect to the KVstore
+        collection = self.service.kvstore[collection_name]
+
+        # batch update/insert
+        batch_update_collection_start = time.time()
+
+        final_records = []
+        # Handle both dictionary and list inputs
+        if isinstance(collection_dict, dict):
+            # loop through the collection dict and add to the list
+            for key, value in collection_dict.items():
+                value["_key"] = key
+                final_records.append(value)
+        elif isinstance(collection_dict, list):
+            # If it's a list, use the records directly
+            final_records = collection_dict
+
+        # process by chunk
+        chunks = [final_records[i : i + 500] for i in range(0, len(final_records), 500)]
+        for chunk in chunks:
+            try:
+                collection.data.batch_save(*chunk)
+            except Exception as e:
+                logging.error(f'KVstore batch failed with exception="{str(e)}"')
+
+        # perf counter for the batch operation
+        logging.info(
+            f'context="perf", batch KVstore update terminated, no_records="{len(final_records)}", run_time="{round((time.time() - batch_update_collection_start), 3)}", collection="{collection_name}"'
+        )
+
+        return True
+
     def get_tenant_metric_idx(self):
         # Define an header for requests authenticated communications with splunkd
         header = {
@@ -280,17 +287,19 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 headers=header,
                 data=json.dumps(data, indent=1),
                 verify=False,
-                timeout=600,
+                timeout=300,
             )
             if response.status_code not in (200, 201, 204):
-                error_msg = f'instance_id="{self.instance_id}", failed to retrieve the tenant metric index, response.status_code="{response.status_code}", response.text="{response.text}"'
+                error_msg = f'failed to retrieve the tenant metric index, response.status_code="{response.status_code}", response.text="{response.text}"'
                 logging.error(error_msg)
                 raise Exception(error_msg)
             else:
                 response_data = json.loads(json.dumps(response.json(), indent=1))
                 tenant_trackme_metric_idx = response_data["trackme_metric_idx"]
         except Exception as e:
-            error_msg = f'instance_id="{self.instance_id}", failed to retrieve the tenant metric index, exception="{str(e)}"'
+            error_msg = (
+                f'failed to retrieve the tenant metric index, exception="{str(e)}"'
+            )
             logging.error(error_msg)
             raise Exception(error_msg)
 
@@ -310,17 +319,22 @@ class TrackMeSplkFqmParse(StreamingCommand):
         )
         log.setLevel(reqinfo["logging_level"])
 
-        # set instance_id
-        self.instance_id = get_uuid()
-
         # log info
         logging.info(
-            f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", context="{self.context}", TrackMeSplkFqmParse is starting'
+            f'tenant_id="{self.tenant_id}", context="{self.context}", TrackMeSplkFqmParse is starting'
         )
 
-        #
-        # some parameters inits
-        #
+        # get the tenant KVstore collection
+        tenant_collection_name = (
+            f"kv_trackme_fqm_tenant_{self.tenant_id}"
+        )
+        tenant_collection = self.service.kvstore[tenant_collection_name]
+        tenant_records, tenant_collection_keys, tenant_collection_dict = (
+            get_full_kv_collection(tenant_collection, tenant_collection_name)
+        )        
+        logging.debug(
+            f'tenant_id="{self.tenant_id}", tenant_collection_dict="{json.dumps(tenant_collection_dict, indent=2)}"'
+        )
 
         # get metric index
         metric_index = self.get_tenant_metric_idx()
@@ -328,36 +342,6 @@ class TrackMeSplkFqmParse(StreamingCommand):
         # counter
         count = 0
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_tenant_collection_records"
-
-        # get the tenant KVstore collection
-        tenant_collection_name = f"kv_trackme_fqm_tenant_{self.tenant_id}"
-        tenant_collection = self.service.kvstore[tenant_collection_name]
-        tenant_records, tenant_collection_keys, tenant_collection_dict = (
-            get_full_kv_collection(tenant_collection, tenant_collection_name)
-        )
-        logging.debug(
-            f'tenant_id="{self.tenant_id}", tenant_collection_dict="{json.dumps(tenant_collection_dict, indent=2)}"'
-        )
-
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_thresholds_collection_records"
-
         # get thresholds collection
         try:
             thresholds_collection = self.get_thresholds_collection()
@@ -367,23 +351,9 @@ class TrackMeSplkFqmParse(StreamingCommand):
         except Exception as e:
             thresholds_collection = {}
             logging.error(
-                f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", failed to retrieve the thresholds collection, exception="{str(e)}"'
+                f'tenant_id="{self.tenant_id}", failed to retrieve the thresholds collection, exception="{str(e)}"'
             )
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_disruption_queue_collection_records"
-
         # get disruption queue collection
         try:
             disruption_queue_collection, disruption_queue_collection_keys = (
@@ -396,17 +366,9 @@ class TrackMeSplkFqmParse(StreamingCommand):
             disruption_queue_collection = {}
             disruption_queue_collection_keys = {}
             logging.error(
-                f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", failed to retrieve the disruption queue collection, exception="{str(e)}"'
+                f'tenant_id="{self.tenant_id}", failed to retrieve the disruption queue collection, exception="{str(e)}"'
             )
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
         # Build header and target URL
         headers = CaseInsensitiveDict()
         headers["Authorization"] = f"Splunk {self._metadata.searchinfo.session_key}"
@@ -442,12 +404,6 @@ class TrackMeSplkFqmParse(StreamingCommand):
         # Dictionary to track meta entity aggregation data
         meta_entity_aggregation = {}
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_records"
-
         for record in records:
             # increment
             count += 1
@@ -484,17 +440,13 @@ class TrackMeSplkFqmParse(StreamingCommand):
 
             # if object_id is in tenant_collection_keys, get the monitored_state value from the dict
             if object_id in tenant_collection_keys:
-                monitored_state = tenant_collection_dict[object_id].get(
-                    "monitored_state", "enabled"
-                )
+                monitored_state = tenant_collection_dict[object_id].get("monitored_state", "enabled")
             else:
                 monitored_state = "enabled"
 
             # stop here if the monitored_state is disabled
             if monitored_state == "disabled":
-                logging.info(
-                    f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", object_id="{object_id}", monitored_state="{monitored_state}", skipping record'
-                )
+                logging.info(f'tenant_id="{self.tenant_id}", object_id="{object_id}", monitored_state="{monitored_state}", skipping record')
                 continue
 
             # define the alias as the value of the field fieldname
@@ -513,7 +465,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
             # calculate the percent_success as: count_success/count_total*100
             count_success = float(record.get("count_success", 0))
             count_total = float(record.get("count_total", 0))
-
+            
             if count_total > 0:
                 percent_success = round(count_success / count_total * 100, 2)
                 # Convert to int if it's a whole number to avoid .0
@@ -543,11 +495,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
 
             # set the threshold_success based on the dynamic_thresholds record, access to the value for the metric_name "fields_quality.percent_success"
             # if not set yet, set it to the default_threshold
-            if (
-                dynamic_thresholds
-                and dynamic_thresholds.get("metric_name")
-                == "fields_quality.percent_success"
-            ):
+            if dynamic_thresholds and dynamic_thresholds.get("metric_name") == "fields_quality.percent_success":
                 threshold_success = dynamic_thresholds["value"]
             else:
                 threshold_success = float(self.default_threshold_fields)
@@ -555,9 +503,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 threshold_success = int(threshold_success)
             yield_record["threshold_success"] = threshold_success
 
-            logging.debug(
-                f'tenant_id="{self.tenant_id}", object_id="{object_id}", object_value="{object_value}", threshold_success="{threshold_success}"'
-            )
+            logging.debug(f'tenant_id="{self.tenant_id}", object_id="{object_id}", object_value="{object_value}", threshold_success="{threshold_success}"')
 
             # set the fields_quality_summary field (JSON object)
             # determine field status based on percent_success vs threshold_success
@@ -565,11 +511,11 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 field_status = "success"
             else:
                 field_status = "failure"
-
+            
             # get field_values (list)
             field_values = record.get("field_values", [])
             # convert the list to a string
-            if isinstance(field_values, list):
+            if isinstance(field_values, list):  
                 field_values = ", ".join(field_values)
 
             # get distinct_value_count
@@ -577,7 +523,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 distinct_value_count = int(record.get("distinct_value_count", 0))
             except Exception as e:
                 distinct_value_count = 0
-
+            
             # create the fields_quality_summary JSON object
             fields_quality_summary = {
                 "@fieldname": record.get("fieldname", ""),
@@ -591,26 +537,22 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "percent_coverage": percent_coverage,
                 "percentage_success": percent_success,
                 "threshold": threshold_success,
-                "total_events": int(record.get("total_events", 0)),
+                "total_events": int(record.get("total_events", 0))
             }
-
+            
             # add regex_expression if available
             if "regex_expression" in record:
                 fields_quality_summary["regex_expression"] = record["regex_expression"]
-
+            
             # add metadata fields
             for key, value in metadata_fields.items():
                 fields_quality_summary[f"metadata.{key}"] = value
+            
+            yield_record["fields_quality_summary"] = json.dumps(fields_quality_summary, indent=2)
 
-            yield_record["fields_quality_summary"] = json.dumps(
-                fields_quality_summary, indent=2
-            )
+            logging.debug(f'tenant_id="{self.tenant_id}", object_id="{object_id}", object_value="{object_value}", fields_quality_summary="{json.dumps(fields_quality_summary, indent=2)}"')
 
-            logging.debug(
-                f'tenant_id="{self.tenant_id}", object_id="{object_id}", object_value="{object_value}", fields_quality_summary="{json.dumps(fields_quality_summary, indent=2)}"'
-            )
-
-            # create the metrics JSON object, based on:
+            # create the metrics JSON object, based on: 
             # count_total, count_success, count_failure, percent_coverage, distinct_value_count, total_events
             # with a prefix of "fields_quality."
             metrics_fields = {
@@ -619,9 +561,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "fields_quality.count_failure": int(record.get("count_failure", 0)),
                 "fields_quality.percent_coverage": percent_coverage,
                 "fields_quality.percent_success": percent_success,
-                "fields_quality.distinct_value_count": int(
-                    record.get("distinct_value_count", 0)
-                ),
+                "fields_quality.distinct_value_count": int(record.get("distinct_value_count", 0)),
                 "fields_quality.total_events": int(record.get("total_events", 0)),
             }
 
@@ -629,14 +569,12 @@ class TrackMeSplkFqmParse(StreamingCommand):
             yield_record["metrics"] = json.dumps(metrics_fields)
 
             # add a record a record to the metrics_list
-            metrics_list.append(
-                {
-                    "time": time.time(),
-                    "object": object_value,
-                    "object_id": object_id,
-                    "metrics": metrics_fields,
-                }
-            )
+            metrics_list.append({
+                "time": time.time(),
+                "object": object_value,
+                "object_id": object_id,
+                "metrics": metrics_fields,
+            })
 
             # add all other fields to the yield_record
             for key, value in record.items():
@@ -667,10 +605,8 @@ class TrackMeSplkFqmParse(StreamingCommand):
             ####################################
 
             # Create meta entity key based on metadata combination
-            meta_key = ":".join(
-                [str(record.get(field, "")) for field in object_metadata_list]
-            )
-
+            meta_key = ":".join([str(record.get(field, "")) for field in object_metadata_list])
+            
             if meta_key not in meta_entity_aggregation:
                 meta_entity_aggregation[meta_key] = {
                     "metadata_datamodel": record.get("metadata.datamodel"),
@@ -685,13 +621,13 @@ class TrackMeSplkFqmParse(StreamingCommand):
                     "total_count_total": 0,
                     "success_fields": [],
                     "failed_fields": [],
-                    "record_count": 0,
+                    "record_count": 0
                 }
-
+                
                 # Store all metadata fields from object_metadata_list for later use in meta entity object construction
                 for field in object_metadata_list:
                     meta_entity_aggregation[meta_key][field] = record.get(field, "")
-
+            
             # Aggregate field-level metrics
             meta_entity_aggregation[meta_key]["total_fields_checked"] += 1
             fieldname = record.get("fieldname", "")
@@ -699,22 +635,14 @@ class TrackMeSplkFqmParse(StreamingCommand):
             if percent_success >= threshold_success:
                 meta_entity_aggregation[meta_key]["total_fields_passed"] += 1
                 if fieldname:
-                    meta_entity_aggregation[meta_key]["success_fields"].append(
-                        fieldname
-                    )
+                    meta_entity_aggregation[meta_key]["success_fields"].append(fieldname)
             else:
                 meta_entity_aggregation[meta_key]["total_fields_failed"] += 1
                 if fieldname:
                     meta_entity_aggregation[meta_key]["failed_fields"].append(fieldname)
-            meta_entity_aggregation[meta_key]["total_count_success"] += int(
-                record.get("count_success", 0)
-            )
-            meta_entity_aggregation[meta_key]["total_count_failure"] += int(
-                record.get("count_failure", 0)
-            )
-            meta_entity_aggregation[meta_key]["total_count_total"] += int(
-                record.get("count_total", 0)
-            )
+            meta_entity_aggregation[meta_key]["total_count_success"] += int(record.get("count_success", 0))
+            meta_entity_aggregation[meta_key]["total_count_failure"] += int(record.get("count_failure", 0))
+            meta_entity_aggregation[meta_key]["total_count_total"] += int(record.get("count_total", 0))
 
             ####################################
             # End Processing meta entity aggregation
@@ -741,44 +669,20 @@ class TrackMeSplkFqmParse(StreamingCommand):
         for yield_record in yield_records:
             yield yield_record
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_meta_entity_records"
-
         #######################################
         # Process meta entity records
         #######################################
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_meta_entity_records"
-
         # Create meta entity records for each metadata combination
         for meta_key, meta_data in meta_entity_aggregation.items():
             # Calculate percentages
             total_fields_checked = meta_data["total_fields_checked"]
             total_fields_passed = meta_data["total_fields_passed"]
             total_fields_failed = meta_data["total_fields_failed"]
-
+            
             if total_fields_checked > 0:
-                percentage_passed = round(
-                    total_fields_passed / total_fields_checked * 100, 2
-                )
-                percentage_failed = round(
-                    total_fields_failed / total_fields_checked * 100, 2
-                )
+                percentage_passed = round(total_fields_passed / total_fields_checked * 100, 2)
+                percentage_failed = round(total_fields_failed / total_fields_checked * 100, 2)
                 # Convert to int if it's a whole number to avoid .0
                 if percentage_passed == int(percentage_passed):
                     percentage_passed = int(percentage_passed)
@@ -793,12 +697,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
             failed_fields = ",".join(meta_data.get("failed_fields", []))
 
             # Create meta entity object value using object_metadata_list
-            meta_object_value = (
-                ":".join(
-                    [str(meta_data.get(field, "")) for field in object_metadata_list]
-                )
-                + ":@global"
-            )
+            meta_object_value = ":".join([str(meta_data.get(field, "")) for field in object_metadata_list]) + ":@global"
             meta_object_id = hashlib.sha256(meta_object_value.encode()).hexdigest()
 
             # Ensure default threshold for meta entity
@@ -828,7 +727,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "tracker_name": self.tracker_name,
                 "max_sec_inactive": int(self.max_sec_inactive),
                 "success_fields": success_fields,
-                "failed_fields": failed_fields,
+                "failed_fields": failed_fields
             }
 
             # add index conditionally
@@ -850,11 +749,7 @@ class TrackMeSplkFqmParse(StreamingCommand):
             # Create fields_quality_summary for meta entity
             meta_fields_quality_summary = {
                 "@fieldname": "@global",
-                "@fieldstatus": (
-                    "success"
-                    if percentage_passed >= float(self.default_threshold_global)
-                    else "failure"
-                ),
+                "@fieldstatus": "success" if percentage_passed >= float(self.default_threshold_global) else "failure",
                 "count_failure": meta_data["total_count_failure"],
                 "count_success": meta_data["total_count_success"],
                 "count_total": meta_data["total_count_total"],
@@ -868,13 +763,11 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "success_fields": success_fields,
                 "failed_fields": failed_fields,
             }
-
+            
             # Add all metadata fields to the fields_quality_summary
             for field in object_metadata_list:
                 meta_fields_quality_summary[field] = meta_data.get(field, "")
-            meta_yield_record["fields_quality_summary"] = json.dumps(
-                meta_fields_quality_summary, indent=2
-            )
+            meta_yield_record["fields_quality_summary"] = json.dumps(meta_fields_quality_summary, indent=2)
 
             # Create metrics for meta entity
             meta_metrics_fields = {
@@ -890,43 +783,27 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "success_fields": success_fields,
                 "failed_fields": failed_fields,
             }
-
+            
             # Add all metadata fields to the metrics
             for field in object_metadata_list:
                 meta_metrics_fields[field] = meta_data.get(field, "")
             meta_yield_record["metrics"] = json.dumps(meta_metrics_fields)
 
             # Add meta entity to metrics list for processing
-            metrics_list.append(
-                {
-                    "time": time.time(),
-                    "object": meta_object_value,
-                    "object_id": meta_object_id,
-                    "metrics": meta_metrics_fields,
-                }
-            )
+            metrics_list.append({
+                "time": time.time(),
+                "object": meta_object_value,
+                "object_id": meta_object_id,
+                "metrics": meta_metrics_fields,
+            })
 
             # Yield the meta entity record
             yield meta_yield_record
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
         #######################################
         # Process the thresholds records update
         #######################################
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_thresholds_records"
-
         # Prepare separate lists for thresholds
         # field_thresholds_object_ids = [] # This line is removed as it's now initialized at the start of the stream function
         # global_thresholds_object_id = None # This line is removed as it's now initialized at the start of the stream function
@@ -935,14 +812,6 @@ class TrackMeSplkFqmParse(StreamingCommand):
         endpoint = f"{self._metadata.searchinfo.splunkd_uri}/services/trackme/v2/splk_fqm/write/fqm_thresholds_add"
 
         if field_thresholds_object_ids and self.context == "live":
-            # Get score, default to 100 if not provided (for backward compatibility)
-            try:
-                score_fields = int(self.default_score_fields)
-                if score_fields < 0 or score_fields > 100:
-                    score_fields = 100
-            except (TypeError, ValueError):
-                score_fields = 100
-            
             data = {
                 "tenant_id": self.tenant_id,
                 "metric_name": "fields_quality.percent_success",
@@ -950,37 +819,26 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "operator": ">=",
                 "condition_true": 1,
                 "comment": "default threshold",
-                "score": score_fields,
                 "keys_list": ",".join(field_thresholds_object_ids),
             }
-            logging.info(
-                f"Posting field thresholds: keys_list={data['keys_list']} value={data['value']}"
-            )
+            logging.info(f"Posting field thresholds: keys_list={data['keys_list']} value={data['value']}")
             try:
                 response = session.post(
                     endpoint,
                     data=json.dumps(data),
                     verify=False,
-                    timeout=600,
+                    timeout=300,
                 )
                 response.raise_for_status()
                 logging.info(
-                    f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", default field thresholds added successfully for {len(field_thresholds_object_ids)} entities, http_status="{response.status_code}"'
+                    f'tenant_id="{self.tenant_id}", default field thresholds added successfully for {len(field_thresholds_object_ids)} entities, http_status="{response.status_code}"'
                 )
             except Exception as e:
                 logging.error(
-                    f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", failed to add the default field thresholds, exception="{str(e)}"'
+                    f'tenant_id="{self.tenant_id}", failed to add the default field thresholds, exception="{str(e)}"'
                 )
 
         if global_thresholds_object_id and self.context == "live":
-            # Get score, default to 100 if not provided (for backward compatibility)
-            try:
-                score_global = int(self.default_score_global)
-                if score_global < 0 or score_global > 100:
-                    score_global = 100
-            except (TypeError, ValueError):
-                score_global = 100
-            
             data = {
                 "tenant_id": self.tenant_id,
                 "metric_name": "fields_quality.percent_success",
@@ -988,48 +846,31 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 "operator": ">=",
                 "condition_true": 1,
                 "comment": "default threshold (meta entity)",
-                "score": score_global,
                 "keys_list": ",".join(global_thresholds_object_id),
             }
-            logging.info(
-                f"Posting global threshold: keys_list={data['keys_list']} value={data['value']}"
-            )
+            logging.info(f"Posting global threshold: keys_list={data['keys_list']} value={data['value']}")
             try:
                 response = session.post(
                     endpoint,
                     data=json.dumps(data),
                     verify=False,
-                    timeout=600,
+                    timeout=300,
                 )
                 response.raise_for_status()
                 logging.info(
-                    f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", default field thresholds added successfully for {len(global_thresholds_object_id)} entities, http_status="{response.status_code}"'
+                    f'tenant_id="{self.tenant_id}", default field thresholds added successfully for {len(global_thresholds_object_id)} entities, http_status="{response.status_code}"'
                 )
             except Exception as e:
                 logging.error(
-                    f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", failed to add the default field thresholds, exception="{str(e)}"'
+                    f'tenant_id="{self.tenant_id}", failed to add the default field thresholds, exception="{str(e)}"'
                 )
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
         #######################################
         # Process the metrics records update
         #######################################
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_metrics_records"
-
         if metrics_list and self.context == "live":
-            # trackme_fqm_gen_metrics_from_list(self.tenant_id, metrics_list)
+            #trackme_fqm_gen_metrics_from_list(self.tenant_id, metrics_list)
 
             logging.debug(f'metrics_list="{json.dumps(metrics_list, indent=2)}"')
 
@@ -1041,22 +882,16 @@ class TrackMeSplkFqmParse(StreamingCommand):
                 )
 
             except Exception as e:
-                error_msg = f'Failed to process metrics_list with exception="{str(e)}"'
+                error_msg = (
+                    f'Failed to process metrics_list with exception="{str(e)}"'
+                )
                 logging.error(error_msg)
                 # do not raise an exception, continue
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id="{self.instance_id}", task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
-
         # log info
         run_time = round(time.time() - start, 3)
         logging.info(
-            f'instance_id="{self.instance_id}", tenant_id="{self.tenant_id}", context="{self.context}", TrackMeSplkFqmParse has terminated successfully, turn debug mode on for more details, results_count="{count}", run_time={run_time}'
+            f'tenant_id="{self.tenant_id}", context="{self.context}", TrackMeSplkFqmParse has terminated successfully, turn debug mode on for more details, results_count="{count}", run_time={run_time}'
         )
 
 
