@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -19,7 +19,6 @@ import os
 import random
 import sys
 import time
-import concurrent.futures
 from logging.handlers import RotatingFileHandler
 
 # Third-party imports
@@ -66,23 +65,7 @@ from splunklib.searchcommands import (
 )
 
 # Import trackme libs
-from trackme_libs import trackme_reqinfo, trackme_vtenant_account
-
-# Import trackme libs
-from trackme_libs_utils import get_uuid
-
-# import TrackMe get data libs
-from trackme_libs_get_data import (
-    search_kv_collection_restmode,
-    search_kv_collection_searchmode,
-    search_kv_collection_sdkmode,
-)
-
-# Import trackMe kvstore batch libs
-from trackme_libs_kvstore_batch import batch_update_worker
-
-# Import collections data for default values
-from collections_data import vtenant_account_default
+from trackme_libs import trackme_reqinfo
 
 
 @Configuration(distributed=False)
@@ -104,32 +87,36 @@ class SplkOutliersSetRules(StreamingCommand):
         validate=validators.Match("component", r"^(?:dsm|dhm|flx|fqm|wlk)$"),
     )
 
-    def get_impact_score(self, vtenant_account, field_name, default_value):
-        """
-        Helper function to get impact score from vtenant_account with fallback to default.
-        
-        Args:
-            vtenant_account: Dictionary containing virtual tenant account configuration
-            field_name: Name of the impact score field to retrieve
-            default_value: Default value to use if field is not found
-        
-        Returns:
-            Integer impact score value
-        """
-        if vtenant_account and isinstance(vtenant_account, dict):
-            value = vtenant_account.get(field_name)
-            if value is not None:
-                try:
-                    return int(value)
-                except (ValueError, TypeError):
-                    pass
-        # Fallback to vtenant_account_default if available
-        default = vtenant_account_default.get(field_name, default_value)
-        try:
-            return int(default)
-        except (ValueError, TypeError):
-            return default_value
+    def get_collection_records(self, collection, collection_name):
+        # get all records
+        get_collection_start = time.time()
+        collection_records = []
+        collection_records_keys = set()
 
+        end = False
+        skip_tracker = 0
+        while end == False:
+            process_collection_records = collection.data.query(skip=skip_tracker)
+            if len(process_collection_records) != 0:
+                for item in process_collection_records:
+                    if item.get("_key") not in collection_records_keys:
+                        collection_records.append(item)
+                        collection_records_keys.add(item.get("_key"))
+                skip_tracker += 5000
+            else:
+                end = True
+
+        # turn this into a dict
+        collection_data_dict = {}
+        for record in collection_records:
+            key = record["object"]
+            collection_data_dict[key] = record
+
+        logging.info(
+            f'context="perf", get data collection records, no_records="{len(collection_records)}", run_time="{round((time.time() - get_collection_start), 3)}", tenant_id="{self.tenant_id}", component="{self.component}"'
+        )
+
+        return collection_records, collection_records_keys, collection_data_dict
 
     def stream(self, records):
         # Start performance counter
@@ -141,26 +128,10 @@ class SplkOutliersSetRules(StreamingCommand):
         )
         log.setLevel(reqinfo["logging_level"])
 
-        # Get virtual tenant account
-        vtenant_conf = trackme_vtenant_account(
-            self._metadata.searchinfo.session_key,
-            self._metadata.searchinfo.splunkd_uri,
-            self.tenant_id,
-        )
-
-        # Max multi thread workers
-        max_multi_thread_workers = int(
-            reqinfo["trackme_conf"]["trackme_general"]["max_multi_thread_workers"]
-        )
-
-        # set instance_id
-        self.instance_id = get_uuid()
-
         # Get app level config
         splk_outliers_detection = reqinfo["trackme_conf"]["splk_outliers_detection"]
 
         # Assign
-        splk_outliers_score_default = self.get_impact_score(vtenant_conf, "impact_score_outliers_default", 36)
         splk_outliers_detection_disable_default = splk_outliers_detection[
             "splk_outliers_detection_disable_default"
         ]
@@ -233,12 +204,6 @@ class SplkOutliersSetRules(StreamingCommand):
         # Outliers rules collection
         #
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_outliers_rules_collection_records"
-
         collection_outliers_name = (
             f"kv_trackme_{self.component}_outliers_entity_rules_tenant_{self.tenant_id}"
         )
@@ -249,34 +214,12 @@ class SplkOutliersSetRules(StreamingCommand):
             collection_outliers_records,
             collection_outliers_records_keys,
             collection_outliers_dict,
-            last_page,
-        ) = search_kv_collection_sdkmode(
-            logging,
-            self.service,
-            collection_outliers_name,
-            page=1,
-            page_count=0,
-            orderby="keyid",
-        )
-
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
+        ) = self.get_collection_records(collection_outliers, collection_outliers_name)
 
         #
         # Data collection
         #
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "get_data_collection_records"
-
         collection_data_name = f"kv_trackme_{self.component}_tenant_{self.tenant_id}"
         collection_data = self.service.kvstore[collection_data_name]
 
@@ -285,33 +228,11 @@ class SplkOutliersSetRules(StreamingCommand):
             collection_data_records,
             collection_data_records_keys,
             collection_data_dict,
-            last_page,
-        ) = search_kv_collection_sdkmode(
-            logging,
-            self.service,
-            collection_data_name,
-            page=1,
-            page_count=0,
-            orderby="keyid",
-        )
-
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
+        ) = self.get_collection_records(collection_data, collection_data_name)
 
         # final records to be batched processed in the KVstore
         final_records = []
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "process_records"
-
         # Loop in the results
         for record in records:
             # check if outliers models are defined already
@@ -342,7 +263,7 @@ class SplkOutliersSetRules(StreamingCommand):
                             check_for_creation = True
                         except Exception as e:
                             logging.info(
-                                f'instance_id={self.instance_id}, object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
+                                f'object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
                             )
 
             # for other components, we create models if these are not defined yet
@@ -366,7 +287,6 @@ class SplkOutliersSetRules(StreamingCommand):
                                 "model_"
                                 + str(random.getrandbits(48)): {
                                     "is_disabled": 0,
-                                    "score": splk_outliers_score_default,
                                     "kpi_metric": kpi_metric,
                                     "kpi_span": "10m",
                                     "method_calculation": splk_outliers_calculation_default,
@@ -444,7 +364,7 @@ class SplkOutliersSetRules(StreamingCommand):
 
                         final_records.append(new_kvrecord)
                         logging.info(
-                            f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
+                            f'tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
                         )
 
                     # for splk-flx/splk-fqm/splk-wlk
@@ -466,7 +386,7 @@ class SplkOutliersSetRules(StreamingCommand):
                                 record_definition_is_valid = True
                             except Exception as e:
                                 logging.info(
-                                    f'instance_id={self.instance_id}, object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
+                                    f'object="{record_object}", failed to extract outliers_metrics definition, outliers_metrics="{record_outliers_metrics}", exception="{str(e)}"'
                                 )
 
                         # if record_outliers_metrics is an empty dict, record_definition_is_valid must be False
@@ -480,7 +400,6 @@ class SplkOutliersSetRules(StreamingCommand):
                             # Assuming defaults are defined earlier in the code
                             defaults_outliers_settings = {
                                 "is_disabled": 0,
-                                "score": splk_outliers_score_default,
                                 "kpi_span": "10m",
                                 "method_calculation": splk_outliers_calculation_default,
                                 "period_calculation": splk_outliers_detection_period_default,
@@ -742,25 +661,6 @@ class SplkOutliersSetRules(StreamingCommand):
                                     ],
                                 )
 
-                                # score
-                                splk_outliers_score = kpi_dict.get(
-                                    "score",
-                                    defaults_outliers_settings["score"],
-                                )
-                                # Validate score (must be integer between 0 and 100)
-                                try:
-                                    splk_outliers_score = int(splk_outliers_score)
-                                    if splk_outliers_score < 0 or splk_outliers_score > 100:
-                                        # Handle invalid value here
-                                        splk_outliers_score = defaults_outliers_settings[
-                                            "score"
-                                        ]
-                                except (ValueError, TypeError):
-                                    # Handle invalid value here
-                                    splk_outliers_score = defaults_outliers_settings[
-                                        "score"
-                                    ]
-
                                 # Constructing the new entity outlier dictionary more efficiently
                                 new_entity_outliers[
                                     "model_" + str(random.getrandbits(48))
@@ -788,7 +688,6 @@ class SplkOutliersSetRules(StreamingCommand):
                                     "extract_boundaries_macro": splk_outliers_boundaries_extraction_macro,
                                     "fit_extra_parameters": splk_outliers_fit_extra_attributes,
                                     "apply_extra_parameters": splk_outliers_apply_extra_attributes,
-                                    "score": splk_outliers_score,
                                     "ml_model_gen_search": "pending",
                                     "ml_model_render_search": "pending",
                                     "ml_model_summary_search": "pending",
@@ -819,12 +718,12 @@ class SplkOutliersSetRules(StreamingCommand):
 
                             final_records.append(new_kvrecord)
                             logging.info(
-                                f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
+                                f'tenant_id="{self.tenant_id}", Outliers rules new record created, record="{json.dumps(new_kvrecord, indent=4)}"'
                             )
 
                 except Exception as e:
                     logging.error(
-                        f'instance_id={self.instance_id}, tenant_id="{self.tenant_id}", Outliers rules creation failed with exception="{str(e)}"'
+                        f'tenant_id="{self.tenant_id}", Outliers rules creation failed with exception="{str(e)}"'
                     )
 
             # yield original record
@@ -836,42 +735,28 @@ class SplkOutliersSetRules(StreamingCommand):
 
             yield yield_record
 
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated.'
-        )
+        # batch update/insert
+        if len(final_records) > 0:
+            batch_update_collection_start = time.time()
 
-        # set task
-        #
-        task_start = time.time()
-        task_instance_id = get_uuid()
-        task_name = "kvstore_batch_update"
+            # process by chunk
+            chunks = [
+                final_records[i : i + 500] for i in range(0, len(final_records), 500)
+            ]
+            for chunk in chunks:
+                try:
+                    collection_outliers.data.batch_save(*chunk)
+                except Exception as e:
+                    logging.error(f'KVstore batch failed with exception="{str(e)}"')
 
-        # Execute batch update synchronously
-        batch_update_worker(
-            collection_outliers_name,
-            collection_outliers,
-            final_records,
-            self.instance_id,
-            task_instance_id,
-            task_name=task_name,
-            max_multi_thread_workers=max_multi_thread_workers,
-        )
-
-        # end task
-        #
-        task_end = time.time()
-        task_run_time = round((task_end - task_start), 3)
-        logging.info(
-            f'instance_id={self.instance_id}, task="{task_name}", task_instance_id={task_instance_id}, task_run_time="{task_run_time}", task_end=1, task has terminated. no_records="{len(final_records)}", collection="{collection_outliers_name}"'
-        )
+            # perf counter for the batch operation
+            logging.info(
+                f'context="perf", batch KVstore update terminated, no_records="{len(final_records)}", run_time="{round((time.time() - batch_update_collection_start), 3)}", tenant_id="{self.tenant_id}", component="{self.component}"'
+            )
 
         # Log the run time
         logging.info(
-            f'instance_id={self.instance_id}, trackmesplkoutlierssetrules has terminated, tenant_id="{self.tenant_id}", component="{self.component}", run_time={round(time.time() - start, 3)}'
+            f'trackmesplkoutlierssetrules has terminated, tenant_id="{self.tenant_id}", component="{self.component}", run_time={round(time.time() - start, 3)}'
         )
 
 
