@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -107,9 +107,6 @@ class TrackMeHandleTags(GeneratingCommand):
         )
         log.setLevel(reqinfo["logging_level"])
 
-        # log start
-        logging.info(f'tenant_id="{self.tenant_id}", component="{self.component}", Starting tracker')
-
         # target
         target_url = f"{self._metadata.searchinfo.splunkd_uri}/services/trackme/v2/splk_tag_policies/write/tag_policies_apply"
 
@@ -223,7 +220,7 @@ class TrackMeHandleTags(GeneratingCommand):
                     },
                     data=json.dumps(post_data),
                     verify=False,
-                    timeout=600,
+                    timeout=300,
                 )
                 response_json = response.json()
 
@@ -272,9 +269,6 @@ class TrackMeHandleTags(GeneratingCommand):
                     "_raw": response.json(),
                 }
 
-                # log end
-                logging.info(f'tenant_id="{self.tenant_id}", component="{self.component}", The tracker has terminated successfully, run_time="{round((time.time() - start), 3)}", response="{json.dumps(response.json(), indent=2)}"')
-
             except Exception as e:
                 # Call the component register
                 trackme_register_tenant_object_summary(
