@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = ["Guilhem Marchand"]
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -365,7 +365,7 @@ class SplkWlkGetReportsDef(StreamingCommand):
                 app=record_app,
                 port=parsed_url.port,
                 autologin=True,
-                timeout=600,
+                timeout=300,
             )
 
             # get the list of remote apps to test the connectivity effectively
@@ -410,7 +410,7 @@ class SplkWlkGetReportsDef(StreamingCommand):
                 app=record_app,
                 host=parsed_url.hostname,
                 port=parsed_url.port,
-                timeout=600,
+                timeout=300,
             )
 
             remote_apps = [app.label for app in service.apps]
@@ -578,7 +578,7 @@ class SplkWlkGetReportsDef(StreamingCommand):
             search_string = f"""\
                 search index=_internal sourcetype=splunkd_ui_access splunkd servicesNS "saved/searches" method=POST {self.filters_get_last_updates}
                 | regex uri="/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/[^/ ]*$" 
-                | rex field=uri "/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/(?<search_encoded>[^/\\? ]*)" 
+                | rex field=uri "/[^/]*/splunkd/__raw/servicesNS/[^/]*/[^/]*/saved/searches/(?<search_encoded>[^/\? ]*)" 
                 | eval savedsearch_name=urldecode(search_encoded) 
                 | rename user as user 
                 | fields _time savedsearch_name user
