@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -99,12 +99,10 @@ def disruption_queue_update(collection_object, disruption_record):
     else:
 
         try:
-            # Create a copy of the disruption record to avoid modifying the original
-            disruption_record_copy = disruption_record.copy()
-            # remove the _key field from the copy
-            disruption_record_copy.pop("_key", None)
+            # remove the _key field from the disruption record
+            disruption_record.pop("_key", None)
             collection_object.data.update(
-                disruption_record_key, json.dumps(disruption_record_copy)
+                disruption_record_key, json.dumps(disruption_record)
             )
             return True
         except Exception as e:
