@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -45,384 +45,6 @@ from trackme_libs import (
 # and rely on callers themselves
 
 
-
-def search_kv_collection_restmode(
-    logger,
-    headers,
-    splunkd_uri,
-    collection_name,
-    page=1,
-    page_count=0,
-    key_filter=None,
-    object_filter=None,
-    orderby="keyid",
-):
-    """
-    Get records from a KVstore collection using REST API.
-
-    :param headers: The headers to use for the request.
-    :param splunkd_uri: The Splunkd URI.
-    :param collection_name: The name of the collection to query.
-    :param page: The page number to retrieve.
-    :param page_count: The number of records to retrieve per page.
-    :param key_filter: The key filter to apply to the query.
-    :param object_filter: The object filter to apply to the query.
-    :param orderby: The order by field to use for the query.
-
-    :return: A tuple containing the records, keys, a dictionary of the records, and last_page.
-    """
-
-    # check orderby argument
-    if orderby not in ["keyid", "object"]:
-        raise ValueError(f'invalid orderby argument="{orderby}"')
-
-    start_time = time.time()
-    collection_dict = {}
-
-    try:
-        # Create a session for connection pooling
-        with requests.Session() as session:
-            session.headers.update(headers)
-            session.verify = False
-
-            # Build base URL
-            url = f"{splunkd_uri}/servicesNS/nobody/trackme/storage/collections/data/{collection_name}"
-
-            # Add filter if specified
-            if key_filter:
-                url = f"{url}/{key_filter}"
-            elif object_filter:
-                query_dict = {"object": {"$eq": object_filter}}
-                query = f"?{urlencode({'query': json.dumps(query_dict)})}"
-                url = f"{url}{query}"
-
-            # If pagination is needed, use it directly in the request
-            if page_count > 0:
-                skip = (page - 1) * page_count
-                params = {
-                    "output_mode": "json",
-                    "skip": skip,
-                    "limit": page_count,
-                }
-
-                # Make the request
-                response = session.get(
-                    url,
-                    params=params,
-                    timeout=600,
-                )
-                response.raise_for_status()
-                response_json = response.json()
-
-                # Process results efficiently
-                for item in response_json:
-                    if orderby == "keyid":
-                        key = item.get("_key")
-                        if key:  # Only process items with valid keys
-                            collection_dict[key] = item
-                    elif orderby == "object":
-                        object = item.get("object")
-                        if object:  # Only process items with valid objects
-                            collection_dict[object] = item
-
-            else:
-                # For non-paginated requests, fetch all records in chunks
-                chunk_size = 10000  # KVstore's default limit
-                skip = 0
-                while True:
-                    params = {
-                        "output_mode": "json",
-                        "skip": skip,
-                        "limit": chunk_size,
-                    }
-
-                    # Make the request
-                    response = session.get(
-                        url,
-                        params=params,
-                        timeout=600,
-                    )
-                    response.raise_for_status()
-                    response_json = response.json()
-
-                    # If no more records, break the loop
-                    if not response_json:
-                        break
-
-                    # Process results efficiently
-                    for item in response_json:
-                        if orderby == "keyid":
-                            key = item.get("_key")
-                            if key:  # Only process items with valid keys
-                                collection_dict[key] = item
-                        elif orderby == "object":
-                            object = item.get("object")
-                            if object:  # Only process items with valid objects
-                                collection_dict[object] = item
-
-                    # If we got less than chunk_size records, we've reached the end
-                    if len(response_json) < chunk_size:
-                        break
-
-                    # Move to next chunk
-                    skip += chunk_size
-
-            # Convert to required formats only once
-            collection_records = list(collection_dict.values())
-            collection_records_keys = set(collection_dict.keys())
-
-            # Handle pagination
-            if page_count == 0:
-                last_page = 1
-            else:
-                # Get total count for pagination
-                count_url = f"{splunkd_uri}/servicesNS/nobody/trackme/storage/collections/data/{collection_name}/count"
-                if object_filter:
-                    count_url += f"?{urlencode({'query': json.dumps({'object': {'$eq': object_filter}})})}"
-
-                count_response = session.get(
-                    count_url,
-                    params={"output_mode": "json"},
-                    timeout=600,
-                )
-                count_response.raise_for_status()
-                total_count = count_response.json().get("count", 0)
-                last_page = (total_count + page_count - 1) // page_count
-
-    except Exception as e:
-        msg = f'REST query failed with exception="{str(e)}"'
-        logging.error(msg)
-        raise Exception(msg)
-
-    logging.info(
-        f'context="perf", search_kv_collection_rest, KVstore select terminated, no_records="{len(collection_records)}", run_time="{round((time.time() - start_time), 3)}", collection="{collection_name}"'
-    )
-
-    return collection_records, collection_records_keys, collection_dict, last_page
-
-
-def search_kv_collection_searchmode(
-    logger,
-    service,
-    collection_name,
-    page=1,
-    page_count=0,
-    key_filter=None,
-    object_filter=None,
-    orderby="keyid",
-):
-    """
-    Get records from a KVstore collection using a Splunk search.
-
-    :param service: The Splunk service object.
-    :param collection_name: The name of the collection to query.
-    :param page: The page number to retrieve.
-    :param page_count: The number of records to retrieve per page.
-    :param key_filter: The key filter to apply to the query.
-    :param object_filter: The object filter to apply to the query.
-    :param orderby: The order by field to use for the query.
-
-    :return: A tuple containing the records, keys, a dictionary of the records, and last_page.
-    """
-
-    # check orderby argument
-    if orderby not in ["keyid", "object"]:
-        raise ValueError(f'invalid orderby argument="{orderby}"')
-
-    start_time = time.time()
-    collection_dict = {}
-
-    try:
-        # Build the search command efficiently
-        search_parts = [f'| inputlookup {collection_name.replace("kv_", "")}']
-
-        # Add filter if specified
-        if key_filter:
-            search_parts.append(f'where keyid="{key_filter}"')
-        elif object_filter:
-            search_parts.append(f'where object="{object_filter}"')
-
-        # Add pagination if needed
-        if page_count > 0:
-            search_parts.append(f"| head {page_count} | tail {page_count}")
-
-        # Complete the search
-        search_parts.append("| eval keyid=_key")
-        search = " ".join(search_parts)
-
-        # Optimize search parameters
-        kwargs_search = {
-            "earliest_time": "-5m",
-            "latest_time": "now",
-            "preview": "false",
-            "output_mode": "json",
-            "count": 0,
-        }
-
-        # Execute search and process results
-        reader = run_splunk_search(
-            service,
-            search,
-            kwargs_search,
-            24,  # max_retries
-            5,  # retry_delay
-        )
-
-        # Process results efficiently
-        for item in reader:
-            if isinstance(item, dict):
-                # orderby=keyid
-                if orderby == "keyid":
-                    key = item.get("keyid")
-                    if key:  # Only process items with valid keys
-                        collection_dict[key] = item
-                elif orderby == "object":
-                    object = item.get("object")
-                    if object:  # Only process items with valid objects
-                        collection_dict[object] = item
-
-        # Convert to required formats only once
-        collection_records = list(collection_dict.values())
-        collection_records_keys = set(collection_dict.keys())
-
-        # Handle pagination
-        if page_count == 0:
-            last_page = 1
-        else:
-            # Get total count for pagination
-            count_search = f'| inputlookup {collection_name.replace("kv_", "")}'
-            if key_filter:
-                count_search += f' where keyid="{key_filter}"'
-            elif object_filter:
-                count_search += f' where object="{object_filter}"'
-            count_search += " | stats count"
-
-            count_reader = run_splunk_search(
-                service,
-                count_search,
-                kwargs_search,
-                24,
-                5,
-            )
-
-            total_count = 0
-            for item in count_reader:
-                if isinstance(item, dict) and "count" in item:
-                    total_count = int(item["count"])
-                    break
-
-            last_page = (total_count + page_count - 1) // page_count
-
-    except Exception as e:
-        msg = f'main search failed with exception="{str(e)}"'
-        logging.error(msg)
-        raise Exception(msg)
-
-    logging.info(
-        f'context="perf", search_kv_collection, KVstore select terminated, no_records="{len(collection_records)}", run_time="{round((time.time() - start_time), 3)}", collection="{collection_name}"'
-    )
-
-    return collection_records, collection_records_keys, collection_dict, last_page
-
-
-def search_kv_collection_sdkmode(
-    logger,
-    service,
-    collection_name,
-    page=1,
-    page_count=0,
-    key_filter=None,
-    object_filter=None,
-    orderby="keyid",
-):
-    """
-    Get records from a KVstore collection using a Splunk search.
-
-    :param service: The Splunk service object.
-    :param collection_name: The name of the collection to query.
-    :param page: The page number to retrieve.
-    :param page_count: The number of records to retrieve per page.
-    :param key_filter: The key filter to apply to the query.
-    :param object_filter: The object filter to apply to the query.
-    :param orderby: The order by field to use for the query.
-
-    :return: A tuple containing the records, keys, a dictionary of the records, and last_page.
-    """
-
-    # check orderby argument
-    if orderby not in ["keyid", "object"]:
-        raise ValueError(f'invalid orderby argument="{orderby}"')
-
-    start_time = time.time()
-    collection_dict = {}
-
-    # connect to the collection
-    collection = service.kvstore[collection_name]
-
-    # add filter, if any
-    if key_filter:
-        query_string = {"keyid": key_filter}
-    elif object_filter:
-        query_string = {"object": object_filter}
-    else:
-        query_string = {}
-
-    try:
-        if query_string:
-            # For filtered queries, we can fetch all matching records at once
-            process_collection_records = collection.data.query(
-                query=json.dumps(query_string)
-            )
-            for item in process_collection_records:
-                if orderby == "keyid":
-                    collection_dict[item.get("_key")] = item
-                elif orderby == "object":
-                    collection_dict[item.get("object")] = item
-        else:
-            # For unfiltered queries, we need to use chunked fetching
-            chunk_size = 10000  # KVstore's default limit
-            skip_tracker = 0
-            while True:
-                process_collection_records = collection.data.query(
-                    limit=chunk_size, skip=skip_tracker
-                )
-                if not process_collection_records:
-                    break
-
-                for item in process_collection_records:
-                    if orderby == "keyid":
-                        collection_dict[item.get("_key")] = item
-                    elif orderby == "object":
-                        collection_dict[item.get("object")] = item
-                skip_tracker += chunk_size
-
-        # Convert to list and set only once at the end
-        collection_records = list(collection_dict.values())
-        collection_records_keys = set(collection_dict.keys())
-
-        # Handle pagination
-        if page_count == 0:
-            last_page = 1
-        else:
-            total_record_count = len(collection_records)
-            last_page = (total_record_count + page_count - 1) // page_count
-            # Apply pagination to the records
-            start_index = (page - 1) * page_count
-            end_index = page * page_count
-            collection_records = collection_records[start_index:end_index]
-
-    except Exception as e:
-        msg = f'main search failed with exception="{str(e)}"'
-        logging.error(msg)
-        raise Exception(msg)
-
-    logging.info(
-        f'context="perf", search_kv_collection, KVstore select terminated, no_records="{len(collection_records)}", run_time="{round((time.time() - start_time), 3)}", collection="{collection_name}"'
-    )
-
-    return collection_records, collection_records_keys, collection_dict, last_page
-
-
 def search_kv_collection(
     service, collection_name, page=1, page_count=0, key_filter=None, object_filter=None
 ):
@@ -834,7 +456,7 @@ def get_collection_documents_count(server_rest_uri, session_key, collection_name
             url,
             headers=header,
             verify=False,
-            timeout=600,
+            timeout=300,
         )
         if response.status_code not in (
             200,
