@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -61,26 +61,6 @@ def trackme_sla_gen_metrics(tenant_id, metrics_idx, records):
             sla_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             sla_logger.propagate = False
-        else:
-            # Find the RotatingFileHandler among existing handlers
-            filehandler = None
-            for handler in sla_logger.handlers:
-                if isinstance(handler, RotatingFileHandler):
-                    filehandler = handler
-                    break
-            
-            # If no RotatingFileHandler found, create one
-            if filehandler is None:
-                filehandler = RotatingFileHandler(
-                    f"{splunkhome}/var/log/splunk/trackme_sla_metrics.log",
-                    mode="a",
-                    maxBytes=100000000,
-                    backupCount=1,
-                )
-                formatter = JSONFormatter()
-                logging.Formatter.converter = time.gmtime
-                filehandler.setFormatter(formatter)
-                sla_logger.addHandler(filehandler)
 
         for record in records:
             sla_logger.info(
