@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -68,27 +68,6 @@ def trackme_fqm_gen_metrics(
             fqm_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             fqm_logger.propagate = False
-        else:
-            # Find the RotatingFileHandler among existing handlers
-            filehandler = None
-            for handler in fqm_logger.handlers:
-                if isinstance(handler, RotatingFileHandler):
-                    filehandler = handler
-                    break
-            
-            # If no RotatingFileHandler found, create one
-            if filehandler is None:
-                filehandler = RotatingFileHandler(
-                    f"{splunkhome}/var/log/splunk/trackme_fqm_metrics.log",
-                    mode="a",
-                    maxBytes=100000000,
-                    backupCount=1,
-                )
-                fqm_logger.addHandler(filehandler)
-            
-            # Update formatter with current timestamp
-            formatter = JSONFormatter(timestamp=timestamp)
-            filehandler.setFormatter(formatter)
 
         fqm_logger.info(
             "Metrics - group=fqm_metrics",
@@ -129,23 +108,6 @@ def trackme_fqm_gen_metrics_from_list(
             fqm_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             fqm_logger.propagate = False
-        else:
-            # Find the RotatingFileHandler among existing handlers
-            filehandler = None
-            for handler in fqm_logger.handlers:
-                if isinstance(handler, RotatingFileHandler):
-                    filehandler = handler
-                    break
-            
-            # If no RotatingFileHandler found, create one
-            if filehandler is None:
-                filehandler = RotatingFileHandler(
-                    f"{splunkhome}/var/log/splunk/trackme_fqm_metrics.log",
-                    mode="a",
-                    maxBytes=100000000,
-                    backupCount=1,
-                )
-                fqm_logger.addHandler(filehandler)
 
         for metrics_item in metrics_list:
             timestamp = float(metrics_item.get("time"))
@@ -198,34 +160,6 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
     splk_fqm_metrics_success_overtime = None
     splk_fqm_search_sample_events = None
 
-    # metadata search constraint (set to * by default to avoid prevent results in case of no metadata fields)
-    metadata_search_constraint = "*"
-
-    # Extract metadata fields from fields_quality_summary to build search constraint
-    try:
-        if "fields_quality_summary" in entity_info and entity_info["fields_quality_summary"]:
-            # Parse the JSON string if it's a string, otherwise use as-is if it's already a dict
-            if isinstance(entity_info["fields_quality_summary"], str):
-                fields_quality_data = json.loads(entity_info["fields_quality_summary"])
-            else:
-                fields_quality_data = entity_info["fields_quality_summary"]
-            
-            # Extract metadata fields and build constraint
-            metadata_constraints = []
-            for key, value in fields_quality_data.items():
-                if key.startswith("metadata."):
-                    # Format as "metadata.fieldname"="value"
-                    constraint = f'"{key}"="{value}"'
-                    metadata_constraints.append(constraint)
-            
-            # Join all constraints with spaces
-            if metadata_constraints:
-                metadata_search_constraint = " ".join(metadata_constraints)
-                
-    except (json.JSONDecodeError, KeyError, TypeError) as e:
-        logging.warning(f"Failed to extract metadata constraints from fields_quality_summary: {str(e)}")
-        pass
-
     try:
         ########
         # mstats
@@ -242,7 +176,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         splk_fqm_metrics_report = remove_leading_spaces(
             f"""\
                 | mstats latest(_value) as latest_value, avg(_value) as avg_value, max(_value) as max_value, perc95(_value) as perc95_value, stdev(_value) as stdev_value where `trackme_metrics_idx({tenant_id})` metric_name=* tenant_id="{tenant_id}" object_category="splk-fqm" object_id="{entity_info["_key"]}" by index, object, metric_name
-                | foreach *_value [ eval <<FIELD>> = if(match(metric_name, "\\.status"), round('<<FIELD>>', 0), round('<<FIELD>>', 3)) ]
+                | foreach *_value [ eval <<FIELD>> = if(match(metric_name, "\.status"), round('<<FIELD>>', 0), round('<<FIELD>>', 3)) ]
             """
         )
 
@@ -259,7 +193,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
                 | mcatalog values(metric_name) as metrics where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-fqm" object_id="{entity_info["_key"]}" metric_name=*
                 | mvexpand metrics
                 | rename metrics as metric_name
-                | rex field=metric_name "^trackme\\.splk\\.fqm\\.(?<label>.*)"
+                | rex field=metric_name "^trackme\.splk\.fqm\.(?<label>.*)"
                 | eval order=if(metric_name=="trackme.splk.fqm.status", 0, 1)
                 | sort 0 order
                 | fields - order
@@ -269,7 +203,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         # charts successes and failures
         splk_fqm_chart_values_search = remove_leading_spaces(
             f"""\
-                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                 | trackmefieldsqualityextract
                 | where fieldname="{entity_info.get("fieldname")}"
                 | fillnull value="null" value
@@ -280,7 +214,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         # charts description
         splk_fqm_chart_description_search = remove_leading_spaces(
             f"""\
-                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                 | trackmefieldsqualityextract
                 | where fieldname="{entity_info.get("fieldname")}"
                 | top limit=15 description
@@ -290,7 +224,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         # chart status
         splk_fqm_chart_status_search = remove_leading_spaces(
             f"""\
-                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                 | trackmefieldsqualityextract
                 | where fieldname="{entity_info.get("fieldname")}"
                 | top status
@@ -356,14 +290,14 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         if fqm_type == "global":
             splk_fqm_search_sample_events_raw = remove_leading_spaces(
                 f"""\
-                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                     | trackmefieldsqualityextract
                 """
             )
         else:
             splk_fqm_search_sample_events_raw = remove_leading_spaces(
                 f"""\
-                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                     | trackmefieldsqualityextract
                     | where fieldname="{entity_info.get("fieldname")}"
                 """
@@ -377,7 +311,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         if fqm_type == "global":
             splk_fqm_search_sample_not_matching_regex_events_raw = remove_leading_spaces(
                 f"""\
-                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint}| sort 0 _time
+                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                     | trackmefieldsqualityextract
                     | where description="Field exists but value does not match the required pattern."
                     | table _time, metadata.index, metadata.sourcetype, metadata.datamodel, metadata.nodename, fieldname, value, regex_expression
@@ -390,7 +324,7 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
         else:
             splk_fqm_search_sample_not_matching_regex_events_raw = remove_leading_spaces(
                 f"""\
-                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" {metadata_search_constraint} | sort 0 _time
+                    index={entity_info.get("tracker_index")} sourcetype=trackme:fields_quality source="trackme:quality:{entity_info.get("tracker_name")}" | sort 0 _time
                     | trackmefieldsqualityextract
                     | where fieldname="{entity_info.get("fieldname")}"
                     | where description="Field exists but value does not match the required pattern."
@@ -424,7 +358,6 @@ def splk_fqm_return_searches(tenant_id, fqm_type, entity_info):
             "splk_fqm_search_sample_events_raw": splk_fqm_search_sample_events_raw,
             "splk_fqm_search_sample_not_matching_regex_events": splk_fqm_search_sample_not_matching_regex_events,
             "splk_fqm_search_sample_not_matching_regex_events_raw": splk_fqm_search_sample_not_matching_regex_events_raw,
-            "metadata_search_constraint": metadata_search_constraint,
         }
 
         # return
