@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -61,26 +61,6 @@ def trackme_ingest_version(index, source, sourcetype, event):
             version_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             version_logger.propagate = False
-        else:
-            # Find the RotatingFileHandler among existing handlers
-            filehandler = None
-            for handler in version_logger.handlers:
-                if isinstance(handler, RotatingFileHandler):
-                    filehandler = handler
-                    break
-            
-            # If no RotatingFileHandler found, create one
-            if filehandler is None:
-                filehandler = RotatingFileHandler(
-                    f"{splunkhome}/var/log/splunk/trackme_wlk_version.log",
-                    mode="a",
-                    maxBytes=100000000,
-                    backupCount=1,
-                )
-                formatter = JSONFormatter()
-                logging.Formatter.converter = time.gmtime
-                filehandler.setFormatter(formatter)
-                version_logger.addHandler(filehandler)
 
         version_logger.info(
             "TrackMe State Events",
@@ -129,25 +109,6 @@ def trackme_wlk_gen_metrics(
             wlk_logger.addHandler(filehandler)
             # Prevent propagation to root logger
             wlk_logger.propagate = False
-        else:
-            # Find the RotatingFileHandler among existing handlers
-            filehandler = None
-            for handler in wlk_logger.handlers:
-                if isinstance(handler, RotatingFileHandler):
-                    filehandler = handler
-                    break
-            
-            # If no RotatingFileHandler found, create one
-            if filehandler is None:
-                filehandler = RotatingFileHandler(
-                    f"{splunkhome}/var/log/splunk/trackme_wlk_metrics.log",
-                    mode="a",
-                    maxBytes=100000000,
-                    backupCount=1,
-                )
-                formatter = JSONFormatter()
-                filehandler.setFormatter(formatter)
-                wlk_logger.addHandler(filehandler)
 
         wlk_logger.info(
             "Metrics - group=wlk_metrics",
@@ -220,7 +181,7 @@ def splk_wlk_return_searches(tenant_id, entity_info):
             | mcatalog values(metric_name) as metrics where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-wlk" object_id="{entity_info["object_id"]}" metric_name=*
             | mvexpand metrics
             | rename metrics as metric_name
-            | rex field=metric_name "^trackme\\.splk.wlk\\.(?<label>.*)"
+            | rex field=metric_name "^trackme\.splk.wlk\.(?<label>.*)"
             | eval order=if(metric_name=="trackme.splk.wlk.status", 0, 1)
             | sort 0 order
             | fields - order
@@ -234,7 +195,7 @@ def splk_wlk_return_searches(tenant_id, entity_info):
             | eval orig_time=_time | bucket _time span=5m
             | eval alert_actions=if((isnull(alert_actions) OR (alert_actions == "")), "none", alert_actions)
             ``` in some error cases, we need to manage extractions and status ```
-            | rex field=savedsearch_id "^(?<user_alt>[^\\;]*)\\;(?<app_alt>[^\\;]*)\\;(?<savedsearch_name_alt>.*)"
+            | rex field=savedsearch_id "^(?<user_alt>[^\;]*)\;(?<app_alt>[^\;]*)\;(?<savedsearch_name_alt>.*)"
             | eval user=coalesce(user, user_alt), app=coalesce(app, app_alt), savedsearch_name=coalesce(savedsearch_name, savedsearch_name_alt)
             | search savedsearch_name="{entity_info["savedsearch_name"]}"
             | eval errmsg=case(len(errmsg)>0, errmsg, match(log_level, "(?i)error") AND len(message)>0, message)
